@@ -24,7 +24,7 @@ email                : markey@web.de
 #include "EngineController.h"
 //#include "equalizersetup.h"
 #include "MainWindow.h"
-#include "mediabrowser.h"
+//#include "mediabrowser.h"
 #include "Meta.h"
 #include "meta/MetaConstants.h"
 #include "metadata/tplugins.h"
@@ -426,7 +426,6 @@ App::initCliArgs() //static
     options.add("debug", ki18n("Print verbose debugging information"));
     options.add("m");
     options.add("toggle-playlist-window", ki18n("Toggle the Playlist-window"));
-    options.add("wizard", ki18n( "Run first-run wizard" ));
     options.add("cwd <directory>", ki18n( "Base for relative filenames/URLs" ));
     options.add("cdplay <device>", ki18n("Play an AudioCD from <device> or system:/media/<device>"));
     KCmdLineArgs::addCmdLineOptions( options );   //add our own options
@@ -561,29 +560,11 @@ App::continueInit()
     bool restoreSession = args->count() == 0 || args->isSet( "append" ) || args->isSet( "queue" )
                                 || Amarok::config().readEntry( "AppendAsDefault", false );
 
-    PERF_LOG( "Starting moodserver" )
-    // Make this instance so it can start receiving signals
-            //FIXME: REENABLE When the moodserver is ported.
-//     MoodServer::instance();
-    PERF_LOG( "Done starting mood server" )
-
-    // Remember old folder setup, so we can detect changes after the wizard was used
-    //const QStringList oldCollectionFolders = MountPointManager::instance()->collectionFolders();
-
-
-    // Is this needed in Amarok 2?
-    if( Amarok::config().readEntry( "First Run", true ) || args->isSet( "wizard" ) )
-    {
-        std::cout << "STARTUP\n" << std::flush; //hide the splashscreen
-        Amarok::config().writeEntry( "First Run", false );
-        Amarok::config().sync();
-    }
-
     PERF_LOG( "Creating MainWindow" )
     m_mainWindow = new MainWindow();
     PERF_LOG( "Done creating MainWindow" )
 
-    m_tray           = new Amarok::TrayIcon( mainWindow() );
+    m_tray = new Amarok::TrayIcon( mainWindow() );
 
     PERF_LOG( "Start init of MainWindow" )
     mainWindow()->init(); //creates the playlist, browsers, etc.
@@ -759,15 +740,6 @@ void App::setUseRatings( bool use )
     emit useRatings( use );
 }
 
-void App::setMoodbarPrefs( bool show, bool moodier, int alter, bool withMusic )
-{
-    AmarokConfig::setShowMoodbar( show );
-    AmarokConfig::setMakeMoodier( moodier );
-    AmarokConfig::setAlterMood( alter );
-    AmarokConfig::setMoodsWithMusic( withMusic );
-    emit moodbarPrefs( show, moodier, alter, withMusic );
-}
-
 KIO::Job *App::trashFiles( const KUrl::List &files )
 {
     KIO::Job *job = KIO::trash( files );
@@ -785,12 +757,14 @@ void App::slotTrashResult( KJob *job )
 void App::quit()
 {
     emit prepareToQuit();
+    /*
     if( MediaBrowser::instance() && MediaBrowser::instance()->blockQuit() )
     {
         // don't quit yet, as some media devices still have to finish transferring data
         QTimer::singleShot( 100, this, SLOT( quit() ) );
         return;
     }
+    */
     KApplication::quit();
 }
 
@@ -994,8 +968,6 @@ namespace Amarok
 
     void setUseScores( bool use ) { App::instance()->setUseScores( use ); }
     void setUseRatings( bool use ) { App::instance()->setUseRatings( use ); }
-    void setMoodbarPrefs( bool show, bool moodier, int alter, bool withMusic )
-    { App::instance()->setMoodbarPrefs( show, moodier, alter, withMusic ); }
     KIO::Job *trashFiles( const KUrl::List &files ) { return App::instance()->trashFiles( files ); }
 }
 
