@@ -64,7 +64,6 @@ class AMAROK_EXPORT App : public KUniqueApplication, public EngineObserver
     signals:
         void useScores( bool use );
         void useRatings( bool use );
-        void moodbarPrefs( bool show, bool moodier, int alter, bool withMusic );
         void prepareToQuit();
     protected: /* for OSD, tray, and dcop */
         void engineStateChanged( Phonon::State state, Phonon::State oldState = Phonon::StoppedState );
@@ -83,7 +82,6 @@ class AMAROK_EXPORT App : public KUniqueApplication, public EngineObserver
         void slotConfigEqualizer();
         void setUseScores( bool use );
         void setUseRatings( bool use );
-        void setMoodbarPrefs( bool show, bool moodier, int alter, bool withMusic );
         KIO::Job *trashFiles( const KUrl::List &files );
         void quit();
 
