@@ -177,7 +177,7 @@ EngineController::installDistroCodec()
         if( !installScript.isNull() ) //just a sanity check
         {
             KGuiItem installButton( i18n( "Install MP3 Support" ) );
-            if(KMessageBox::questionYesNo(MainWindow::self()
+            if(KMessageBox::questionYesNo( The::mainWindow()
             , i18n("Amarok currently cannot play MP3 files. Do you want to install support for MP3?")
             , i18n( "No MP3 Support" )
             , installButton
@@ -233,7 +233,10 @@ EngineController::play() //SLOT
     {
         m_media->play();
     }
-    else play( The::playlistModel()->activeTrack() );
+    else
+    {
+        play( The::playlistModel()->activeTrack() );
+    }
 }
 
 void
@@ -256,6 +259,7 @@ EngineController::play( const Meta::TrackPtr& track, uint offset )
     else
     {
         playUrl( track->playableUrl(), offset );
+        emit trackChanged( track );
     }
 }
 
@@ -325,9 +329,13 @@ EngineController::playPause() //SLOT
     if( m_media->state() == Phonon::PlayingState )
     {
         pause();
+        emit trackPlayPause( Paused );
     }
     else
+    {
         play();
+        emit trackPlayPause( Playing );
+    }
 }
 
 void
@@ -339,6 +347,7 @@ EngineController::seek( int ms ) //SLOT
     {
         m_media->seek( static_cast<qint64>( ms ) );
         trackPositionChangedNotify( ms, true ); /* User seek */
+        emit trackSeeked( ms );
     }
     else
         debug() << "Stream is not seekable.";
@@ -505,6 +514,7 @@ EngineController::slotTrackEnded()
             }
             m_media->setCurrentSource( m_currentTrack->playableUrl() );
             m_media->play();
+            emit trackChanged( m_currentTrack );
         }
     }
 }
