@@ -33,20 +33,17 @@ namespace Phonon { class AudioOutput; class MediaObject; class VolumeFaderEffect
 /**
  * This class captures Amarok specific behaviour for some common features.
  * Accessing the engine directly is perfectly legal but on your own risk.
- * TODO: Hide proxy stuff!
  */
 
 class AMAROK_EXPORT EngineController : public QObject, public EngineSubject
 {
     Q_OBJECT
 
+    friend class EngineControllerSingleton;
+
 public:
     typedef QMap<QString, bool>  ExtensionCache;
 
-    //NOTE: Use The::EngineController, this just exists to make the static work properly.
-    EngineController();
-    ~EngineController();
-
     static bool              canDecode( const KUrl& );
     static ExtensionCache&   extensionCache() { return s_extensionCache; }
 
@@ -71,6 +68,13 @@ public:
     bool loaded() { return phononMediaObject()->state() != Phonon::StoppedState; }
     bool getAudioCDContents(const QString &device, KUrl::List &urls);
     bool isStream();
+    enum PlayerStatus
+    {
+        Playing  = 0,
+        Paused   = 1,
+        Stopped  = 2,
+        Error   = -1
+    };
 
 public slots:
     void play();
@@ -91,8 +95,10 @@ public slots:
     void mute();
 
 signals:
-    void statusText( const QString& );
+    void trackPlayPause( int );
     void trackFinished();
+    void trackChanged( Meta::TrackPtr );
+    void trackSeeked( int ); //return relative time in million second
 
 protected:
     void playUrl( const KUrl &url, uint offset );
@@ -110,6 +116,9 @@ private slots:
     void slotStopFadeout(); //called after the fade-out has finished
 
 private:
+    EngineController();
+    ~EngineController();
+
     static ExtensionCache s_extensionCache;
 
     Q_DISABLE_COPY( EngineController );
