@@ -20,6 +20,7 @@
 
 #include <config-amarok.h>    //HAVE_LIBVISUAL definition
 
+#include "ActionClasses.h"
 #include "Amarok.h"
 #include "Debug.h"
 #include "EngineController.h" //for actions in ctor
@@ -36,12 +37,10 @@
 #include "collectionbrowser/CollectionWidget.h"
 #include "context/ContextScene.h"
 #include "context/ContextView.h"
-//#include "context/CoverBling.h"
 #include "context/plasma/plasma.h"
 #include "covermanager/CoverManager.h" // for actions
 #include "filebrowser/FileBrowser.h"
-#include "k3bexporter.h"
-#include "mediabrowser.h"
+//#include "mediabrowser.h"
 #include "PaletteHandler.h"
 #include "playlist/PlaylistGraphicsView.h"
 #include "playlist/PlaylistModel.h"
@@ -131,6 +130,7 @@ MainWindow::~MainWindow()
     delete m_playlistFiles;
     delete m_contextView;
     delete m_corona;
+    delete ScriptManager::instance();
 }
 
 
@@ -227,7 +227,7 @@ MainWindow::init()
 
         #define addBrowserMacro( Type, name, text, icon ) { \
             Debug::Block block( name ); \
-             m_browsers->addWidget( KIcon( icon ), text, new Type( name ) ); \
+             m_browsers->addWidget( KIcon( icon ), text, new Type( name , m_browsers ) ); \
              m_browserNames.append( name ); }
 
         #define addInstBrowserMacro( Type, name, text, icon ) { \
@@ -306,17 +306,23 @@ MainWindow::slotSetFilter( const QString &filter ) //SLOT
 }
 
 void
-MainWindow::slotShrinkBrowsers( int index ) const
+MainWindow::slotShrinkBrowsers( int index )
 {
+    DEBUG_BLOCK
+
     // Because QSplitter sucks and will not recompute sizes if a pane is shrunk and not hidden.
     if( index == -1 )
     {
+        m_splitterState = m_splitter->saveState();
+
         QList<int> sizes;
         sizes << m_browsers->sideBarWidget()->width() // browser bar
               << m_splitter->sizes()[1] + m_splitter->sizes()[0] - m_browsers->sideBarWidget()->width() // context view
               << m_splitter->sizes()[2]; // playlist
         m_splitter->setSizes( sizes );
     }
+    else
+        m_splitter->restoreState( m_splitterState );
 }
 
 void
@@ -403,7 +409,7 @@ void MainWindow::savePlaylist() const
 void
 MainWindow::slotBurnPlaylist() const //SLOT
 {
-    K3bExporter::instance()->exportCurrentPlaylist();
+    //K3bExporter::instance()->exportCurrentPlaylist();
 }
 
 void
@@ -634,11 +640,12 @@ MainWindow::createActions()
     connect( action, SIGNAL( triggered(bool) ), this, SLOT( savePlaylist() ) );
     ac->addAction( "playlist_save", action );
 
-
+    /*
     action = new KAction( KIcon( "tools-media-optical-burn-amarok" ), i18n( "Burn Current Playlist" ), this );
     connect( action, SIGNAL( triggered(bool) ), SLOT( slotBurnPlaylist() ) );
     action->setEnabled( K3bExporter::isAvailable() );
     ac->addAction( "playlist_burn", action );
+    */
 
     action = new KAction( KIcon( "media-album-cover-manager-amarok" ), i18n( "Cover Manager" ), this );
     connect( action, SIGNAL( triggered(bool) ), SLOT( slotShowCoverManager() ) );
@@ -841,9 +848,11 @@ MainWindow::createActions()
     new Amarok::RandomAction( ac );
     new Amarok::FavorAction( ac );
 
+    /*
     PERF_LOG( "MainWindow::createActions 9" )
     if( K3bExporter::isAvailable() )
         new Amarok::BurnMenuAction( ac );
+    */
 
     ac->addAssociatedWidget( this );
     foreach (QAction* action, ac->actions())
@@ -1053,3 +1062,8 @@ void MainWindow::paintEvent( QPaintEvent * e )
 }
 
 
+namespace The {
+    MainWindow* mainWindow() { return MainWindow::s_instance; }
+}
+
+
