@@ -23,7 +23,8 @@
 
 class ContextWidget;
 class MainToolbar;
-class MediaBrowser;
+class MainWindow;
+//class MediaBrowser;
 class PlaylistFileProvider;
 class SearchWidget;
 class SideBar;
@@ -39,11 +40,14 @@ namespace Context {
 }
 
 class KMenu;
-
 class QMenuBar;
 class QSplitter;
 class QTimer;
 
+namespace The {
+        AMAROK_EXPORT MainWindow* mainWindow();
+}
+
 /**
   * @class MainWindow
   * @short The MainWindow widget class.
@@ -52,6 +56,8 @@ class QTimer;
   */
 class AMAROK_EXPORT MainWindow : public KXmlGuiWindow
 {
+    friend MainWindow* The::mainWindow();
+
     Q_OBJECT
 
     public:
@@ -67,9 +73,6 @@ class AMAROK_EXPORT MainWindow : public KXmlGuiWindow
         //takes into account minimized, multiple desktops, etc.
         bool isReallyShown() const;
 
-        //instance is declared in KXMLGUI
-        static MainWindow *self() { return s_instance; }
-
         void activate();
 
         SideBar *sideBar() const { return m_browsers; }
@@ -93,7 +96,7 @@ class AMAROK_EXPORT MainWindow : public KXmlGuiWindow
         void playAudioCD();
 
     private slots:
-        void slotShrinkBrowsers( int index ) const;
+        void slotShrinkBrowsers( int index );
         void savePlaylist() const;
         void exportPlaylist() const;
         void slotBurnPlaylist() const;
@@ -150,8 +153,9 @@ class AMAROK_EXPORT MainWindow : public KXmlGuiWindow
         MainToolbar   *m_controlBar;
         QTimer        *m_timer;  //search filter timer
         QStringList    m_lastfmTags;
-        MediaBrowser  *m_currMediaBrowser;
+        //MediaBrowser  *m_currMediaBrowser;
         QSplitter     *m_splitter;
+        QByteArray     m_splitterState;
 
         ContextWidget *m_contextWidget;
         Context::ContextScene *m_corona;
@@ -172,3 +176,4 @@ class AMAROK_EXPORT MainWindow : public KXmlGuiWindow
 
 
 #endif //AMAROK_PLAYLISTWINDOW_H
+
