@@ -1,37 +1,36 @@
-/***************************************************************************
- *                                                                         *
- *   This program is free software; you can redistribute it and/or modify  *
- *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; either version 2 of the License, or     *
- *   (at your option) any later version.                                   *
- *                                                                         *
- ***************************************************************************/
-//
-// C++ Implementation: mediadevicepluginmanager
-//
-// Description:
-//
-//
-// Authors: Jeff Mitchell <kde-dev@emailgoeshere.com>, (C) 2005, 2006
-//          Martin Aumueller <aumuell@reserv.at>, (C) 2006
-//
+/******************************************************************************
+ * Copyright (c) 2005,2006 Jeff Mitchell <kde-dev@emailgoeshere.com>          *
+ *           (c) 2006 Martin Aumueller <aumuell@reserv.at>                    *
+ *                                                                            *
+ * This program is free software; you can redistribute it and/or              *
+ * modify it under the terms of the GNU General Public License as             *
+ * published by the Free Software Foundation; either version 2 of             *
+ * the License, or (at your option) any later version.                        *
+ *                                                                            *
+ * This program is distributed in the hope that it will be useful,            *
+ * but WITHOUT ANY WARRANTY; without even the implied warranty of             *
+ * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the              *
+ * GNU General Public License for more details.                               *
+ *                                                                            *
+ * You should have received a copy of the GNU General Public License          *
+ * along with this program.  If not, see <http://www.gnu.org/licenses/>.      *
+ ******************************************************************************/
 
 #include "MediaDevicePluginManager.h"
 
-#include "amarok.h"
-#include "debug.h"
+#include "Amarok.h"
+#include "Debug.h"
 #include "deviceconfiguredialog.h"
 #include "hintlineedit.h"
 #include "mediabrowser.h"
 #include "MediaDeviceCache.h"
 #include "plugin/pluginconfig.h"
-#include "pluginmanager.h"
-#include "ContextStatusBar.h"
+#include "PluginManager.h"
+#include "StatusBar.h"
 
 #include <KApplication>
 #include <KComboBox>
 #include <KConfig>
-#include <KIconLoader>
 #include <KLineEdit>
 #include <KLocale>
 #include <KPushButton>
@@ -43,7 +42,7 @@
 #include <QGroupBox>
 #include <QHeaderView>
 #include <QLabel>
-#include <QMessageBox>
+#include <KMessageBox>
 #include <QTextDocument>
 #include <QTableWidget>
 #include <QToolTip>
@@ -130,9 +129,9 @@ MediaDevicePluginManager::slotGenericVolumes()
     const QStringList addedList = mdvmd->getAddedList();
     const QStringList removedList = mdvmd->getRemovedList();
     delete mdvmd;
-    foreach( QString udi, addedList )
+    foreach( const QString &udi, addedList )
         MediaBrowser::instance()->deviceAdded( udi );
-    foreach( QString udi, removedList )
+    foreach( const QString &udi, removedList )
         MediaBrowser::instance()->deviceRemoved( udi );
     detectDevices();
 }
@@ -200,7 +199,7 @@ MediaDevicePluginManager::slotSolidDeviceAdded( const QString &udi )
     }
     else
     {
-        debug() << "device wasn't PMP, or was volume but not enabled" << endl;
+        debug() << "device was not PMP, or was volume but not enabled" << endl;
     }
 }
 
@@ -286,7 +285,7 @@ MediaDevicePluginManager::slotNewDevice()
         {
             //abort!  Can't have the same device defined twice...should never
             //happen due to name checking earlier...right?
-            Amarok::ContextStatusBar::instance()->longMessageThreadSafe( i18n("Sorry, you cannot define two devices\n"
+            The::statusBar()->longMessageThreadSafe( i18n("Sorry, you cannot define two devices\n"
                                                                        "with the same name and mountpoint!") );
         }
         else
@@ -378,7 +377,7 @@ ManualDeviceAdder::slotButtonClicked( int button )
     }
     else
     {
-        Amarok::ContextStatusBar::instance()->longMessageThreadSafe( i18n("Sorry, every device must have a name and\n"
+        The::statusBar()->longMessageThreadSafe( i18n("Sorry, every device must have a name and\n"
                                                                    "you cannot define two devices with the\n"
                                                                    "same name. These names must be unique\n"
                                                                    "across autodetected devices as well.\n") );
@@ -398,7 +397,7 @@ ManualDeviceAdder::slotComboChanged( const QString &string )
             MediaBrowser::instance()->getInternalPluginName( string ) == "njb-mediadevice" )
     {
         m_mountPointOldText = m_mdaMountPoint->text();
-        m_mdaMountPoint->setText( "No mount point needed" );
+        m_mdaMountPoint->setText( i18n("No mount point needed") );
         m_mdaMountPoint->setEnabled(false);
     }
     else if( m_mdaMountPoint->isEnabled() == false )
@@ -437,7 +436,7 @@ ManualDeviceAdder::getId( bool recreate )
     }
     if( m_mdaName->text().count( '|' ) )
     {
-        Amarok::ContextStatusBar::instance()->longMessageThreadSafe( i18n( "The device name cannot contain the '|' character" ) );
+        The::statusBar()->longMessageThreadSafe( i18n( "The device name cannot contain the '|' character" ) );
         return QString();
     }
     m_newId = "manual|" + m_mdaName->text() + '|' +
@@ -500,13 +499,13 @@ MediaDeviceConfig::MediaDeviceConfig( QString udi, QWidget *parent, const char *
                 if( !device.parent().product().isEmpty() )
                     table += row.arg( Qt::escape( i18n( "Product:" ) ),
                         Qt::escape( device.parent().product() ) );
-                Solid::StorageAccess *sa = device.as<Solid::StorageAccess>();
-                if( sa )
+                Solid::StorageAccess *ssa = device.as<Solid::StorageAccess>();
+                if( ssa )
                     table += row.arg( Qt::escape( i18n( "Mount Point:" ) ),
-                            ( sa->isAccessible() ?
-                                Qt::escape( sa->filePath() ) :
+                            ( ssa->isAccessible() ?
+                                Qt::escape( ssa->filePath() ) :
                                 Qt::escape( i18n( "Not Mounted" ) ) ) );
-            } 
+            }
         }
     }
 
@@ -519,7 +518,8 @@ MediaDeviceConfig::MediaDeviceConfig( QString udi, QWidget *parent, const char *
     Q_UNUSED( label_devicename );
     QLabel* m_label_details = new QLabel( "<qt>(<a href='details'>" + i18n( "Details" ) + "</a>)</qt>", this );
     m_label_details->setTextInteractionFlags( Qt::LinksAccessibleByMouse | Qt::LinksAccessibleByKeyboard );
-    connect( m_label_details, SIGNAL( linkActivated( const QString & ) ), this, SLOT( slotDetailsActivated( const QString & ) ) );
+    debug() << "Making link activated, m_label_details = " << m_label_details;
+    connect( m_label_details, SIGNAL( linkActivated(const QString &) ), this, SLOT( slotDetailsActivated(const QString &) ) );
 
     QLabel* label_plugin = new QLabel( i18n("Plugin:"), this );
     Q_UNUSED( label_plugin );
@@ -567,7 +567,7 @@ MediaDeviceConfig::MediaDeviceConfig( QString udi, QWidget *parent, const char *
 MediaDeviceConfig::~MediaDeviceConfig()
 {
     DEBUG_BLOCK
-    debug() << "null here?";
+    debug() << "null here? m_label_details = " << m_label_details;
     disconnect( m_label_details, SIGNAL( linkActivated(const QString &) ), this, SLOT( slotDetailsActivated(const QString &) ) );
     debug() << "or here?";
     disconnect( m_removeButton, SIGNAL(clicked()), this, SLOT(slotDeleteDevice()) );
@@ -690,11 +690,13 @@ MediaDeviceVolumeMarkerDialog::slotOk()
                 }
             }
             else
-                QMessageBox::critical( this, i18n( "Well, we tried..." ),
-                        i18n( "Could not create the marking file at %1.\n"
-                              "Ensure that you have the correct permissions\n"
-                              "to create that file.",
-                              QString( mountPoint + "/.is_audio_player" ) ) );
+                KMessageBox::sorry( this,
+                                    i18n( "Could not create the marking file at %1.\n"
+                                          "Ensure that you have the correct permissions\n"
+                                          "to create that file.",
+                                          QString( mountPoint + "/.is_audio_player" ) ),
+                                    i18n( "Well, we tried..." )
+                                  );
         }
         else
         {
@@ -702,11 +704,13 @@ MediaDeviceVolumeMarkerDialog::slotOk()
             bool success = QFile::remove( mountPoint + "/.is_audio_player" );
             if( !success )
             {
-                QMessageBox::critical( this, i18n( "Well, we tried..." ),
-                        i18n( "Could not remove the marking file at %1.\n"
-                              "Ensure that you have the correct permissions\n"
-                              "to remove that file.",
-                              QString( mountPoint + "/.is_audio_player" ) ) );
+                KMessageBox::sorry( this,
+                                    i18n( "Could not remove the marking file at %1.\n"
+                                          "Ensure that you have the correct permissions\n"
+                                          "to remove that file.",
+                                          QString( mountPoint + "/.is_audio_player" ) ),
+                                    i18n( "Well, we tried..." )
+                                  );
             }
             else
             {
