@@ -53,6 +53,8 @@ namespace Amarok
         return QImage( KStandardDirs::locate( "data", QString( "amarok/images/b_%1.png" ).arg( iconName ) ), "PNG" )
                                                       .scaled( 10, 10, Qt::IgnoreAspectRatio, Qt::SmoothTransformation );
     }
+
+    TrayIcon* TrayIcon::s_instance = 0;
 }
 
 
@@ -67,6 +69,8 @@ Amarok::TrayIcon::TrayIcon( QWidget *playerWidget )
 {
     DEBUG_BLOCK
 
+    s_instance = this;
+
     PERF_LOG( "Beginning TrayIcon Constructor" );
     KActionCollection* const ac = Amarok::actionCollection();
 
@@ -107,11 +111,6 @@ Amarok::TrayIcon::event( QEvent *e )
         TrackToolTip::instance()->show( static_cast<QHelpEvent*>(e)->globalPos() );
         return true;
 
-    case QEvent::Leave:
-        DEBUG_LINE_INFO
-        TrackToolTip::instance()->hide();
-        return false;
-
     case QEvent::Drop:
         #define e static_cast<QDropEvent*>(e)
         {
