@@ -159,6 +159,8 @@ CollectionManager::startFullScan()
 void
 CollectionManager::checkCollectionChanges()
 {
+    DEBUG_BLOCK
+
     foreach( const CollectionPair &pair, d->collections )
     {
         pair.first->startIncrementalScan();
@@ -374,7 +376,7 @@ CollectionManager::relatedArtists( Meta::ArtistPtr artist, int maxArtists )
     {
         qm->addFilter( QueryMaker::valArtist, artist, true, true );
     }
-    qm->startArtistQuery();
+    qm->setQueryType( QueryMaker::Artist );
     qm->limitMaxResultSize( maxArtists );
     BlockingQuery bq( qm );
     bq.startQuery();
