@@ -19,7 +19,7 @@
 #include "authentication/contentfetcher.h"
 #include "daapcollection.h"
 #include "daapmeta.h"
-#include "debug.h"
+#include "Debug.h"
 
 #include <QByteArray>
 #include <QDateTime>
@@ -378,6 +378,7 @@ Reader::parseSongList( const QByteArray &data )
         }
         genrePtr->addTrack( track );
         track->setGenre( genrePtr );
+        trackMap.insert( track->url(), TrackPtr::staticCast( track ) );
     }
 
     m_memColl->acquireWriteLock();
@@ -480,7 +481,7 @@ Reader::parse( QDataStream &raw, uint containerLength, bool first )
                 }
                 break;
             default:
-                warning() << tag << " doesn't work";
+                warning() << tag << " does not work";
             break;
         }
         index += tagLength + 8;
@@ -515,7 +516,6 @@ WorkerThread::WorkerThread( const QByteArray &data, Reader *reader, DaapCollecti
     connect( this, SIGNAL( done( ThreadWeaver::Job* ) ), coll, SLOT( loadedDataFromServer() ) );
     connect( this, SIGNAL( failed( ThreadWeaver::Job* ) ), coll, SLOT( parsingFailed() ) );
     connect( this, SIGNAL( done( ThreadWeaver::Job* ) ), this, SLOT( deleteLater() ) );
-    connect( this, SIGNAL( done( ThreadWeaver::Job* ) ), this, SLOT( deleteLater() ) );
 }
 
 WorkerThread::~WorkerThread()
