@@ -21,9 +21,17 @@
 #ifndef IPODMETA_H
 #define IPODMETA_H
 
+#include "Debug.h"
 #include "Meta.h"
 
+extern "C" {
+#include <gpod/itdb.h>
+}
+
+#include <QMultiMap>
+
 class IpodCollection;
+class PopupDropperAction;
 
 namespace Meta
 {
@@ -42,8 +50,15 @@ typedef KSharedPtr<IpodGenre> IpodGenrePtr;
 typedef KSharedPtr<IpodComposer> IpodComposerPtr;
 typedef KSharedPtr<IpodYear> IpodYearPtr;
 
+typedef QMultiMap<IpodArtistPtr, IpodTrackPtr> IpodArtistMap;
+typedef QMultiMap<IpodAlbumPtr, IpodTrackPtr> IpodAlbumMap;
+typedef QMultiMap<IpodGenrePtr, IpodTrackPtr> IpodGenreMap;
+typedef QMultiMap<IpodComposerPtr, IpodTrackPtr> IpodComposerMap;
+typedef QMultiMap<IpodYearPtr, IpodTrackPtr> IpodYearMap;
+
 class IpodTrack : public Meta::Track
 {
+
     public:
         IpodTrack( IpodCollection *collection, const QString &format);
         virtual ~IpodTrack();
@@ -64,6 +79,12 @@ class IpodTrack : public Meta::Track
         virtual ComposerPtr composer() const;
         virtual YearPtr year() const;
 
+        Itdb_Track* getIpodTrack() const;
+        void setIpodTrack ( Itdb_Track *ipodtrack );
+
+	QList<Itdb_Playlist*> getIpodPlaylists() const;
+	void addIpodPlaylist ( Itdb_Playlist *ipodplaylist );
+
         virtual void setAlbum ( const QString &newAlbum );
         virtual void setArtist ( const QString &newArtist );
         virtual void setGenre ( const QString &newGenre );
@@ -84,6 +105,7 @@ class IpodTrack : public Meta::Track
 
         virtual int length() const;
 
+        void setFileSize( int newFileSize );
         virtual int filesize() const;
         virtual int sampleRate() const;
 
@@ -107,9 +129,9 @@ class IpodTrack : public Meta::Track
 
         virtual QString type() const;
 
-        virtual void beginMetaDataUpdate() {}    //read only
-        virtual void endMetaDataUpdate() {}      //read only
-        virtual void abortMetaDataUpdate() {}    //read only
+        virtual void beginMetaDataUpdate() { DEBUG_BLOCK }    //read only
+        virtual void endMetaDataUpdate();
+        virtual void abortMetaDataUpdate() { DEBUG_BLOCK }    //read only
 
         virtual void subscribe ( Observer *observer );
         virtual void unsubscribe ( Observer *observer );
@@ -117,13 +139,34 @@ class IpodTrack : public Meta::Track
         virtual bool inCollection() const;
         virtual Collection* collection() const;
 
+	virtual bool hasCapabilityInterface( Meta::Capability::Type type ) const;
+	virtual Meta::Capability* asCapabilityInterface( Meta::Capability::Type type );
+
         //IpodTrack specific methods
+    
+    public:
+        // These methods are for MemoryMatcher to use
         void setAlbum( IpodAlbumPtr album );
         void setArtist( IpodArtistPtr artist );
         void setComposer( IpodComposerPtr composer );
         void setGenre( IpodGenrePtr genre );
         void setYear( IpodYearPtr year );
 
+        // These methods are for IpodTrack-specific usage
+        // NOTE: these methods/data may turn out to be unneeded
+        IpodArtistMap getIpodArtistMap() const { return m_ipodArtistMap; }
+        IpodAlbumMap getIpodAlbumMap() const { return m_ipodAlbumMap; }
+        IpodGenreMap getIpodGenreMap() const { return m_ipodGenreMap; }
+        IpodComposerMap getIpodComposerMap() const { return m_ipodComposerMap; }
+        IpodYearMap getIpodYearMap() const { return m_ipodYearMap; }
+
+        void setIpodArtistMap( const IpodArtistMap &ipodArtistMap ) { m_ipodArtistMap = ipodArtistMap; }
+        void setIpodAlbumMap( const IpodAlbumMap &ipodAlbumMap ) { m_ipodAlbumMap = ipodAlbumMap; }
+        void setIpodGenreMap( const IpodGenreMap &ipodGenreMap ) { m_ipodGenreMap = ipodGenreMap; }
+        void setIpodComposerMap( const IpodComposerMap &ipodComposerMap ) { m_ipodComposerMap = ipodComposerMap; }
+        void setIpodYearMap( const IpodYearMap &ipodYearMap ) { m_ipodYearMap = ipodYearMap; }
+
+    
         void setLength( int length );
 	void setPlayableUrl( QString Url ) { m_playableUrl = Url; }
 
@@ -136,10 +179,22 @@ class IpodTrack : public Meta::Track
         IpodComposerPtr m_composer;
         IpodYearPtr m_year;
 
+        // For IpodTrack-specific use
+
+        IpodArtistMap m_ipodArtistMap;
+        IpodAlbumMap m_ipodAlbumMap;
+        IpodGenreMap m_ipodGenreMap;
+        IpodComposerMap m_ipodComposerMap;
+        IpodYearMap m_ipodYearMap;
+
+        Itdb_Track *m_ipodtrack;
+	QList<Itdb_Playlist*> m_ipodplaylists;
+
         QString m_comment;
         QString m_name;
         QString m_type;
         int m_bitrate;
+        int m_filesize;
         int m_length;
         int m_discNumber;
         int m_samplerate;
@@ -164,6 +219,7 @@ class IpodArtist : public Meta::Artist
 
         //IpodArtist specific methods
         void addTrack( IpodTrackPtr track );
+        void remTrack( IpodTrackPtr track );
 
     private:
         QString m_name;
@@ -190,6 +246,7 @@ class IpodAlbum : public Meta::Album
 
         //IpodAlbum specific methods
         void addTrack( IpodTrackPtr track );
+        void remTrack( IpodTrackPtr track );
         void setAlbumArtist( IpodArtistPtr artist );
         void setIsCompilation( bool compilation );
 
@@ -213,7 +270,7 @@ class IpodGenre : public Meta::Genre
 
         //IpodGenre specific methods
         void addTrack( IpodTrackPtr track );
-
+        void remTrack( IpodTrackPtr track );
     private:
         QString m_name;
         TrackList m_tracks;
@@ -232,6 +289,7 @@ class IpodComposer : public Meta::Composer
 
         //IpodComposer specific methods
         void addTrack( IpodTrackPtr track );
+        void remTrack( IpodTrackPtr track );
 
     private:
         QString m_name;
@@ -251,6 +309,7 @@ class IpodYear : public Meta::Year
 
         //IpodYear specific methods
         void addTrack( IpodTrackPtr track );
+        void remTrack( IpodTrackPtr track );
 
     private:
         QString m_name;
