@@ -1,6 +1,11 @@
-/******************************************************************************************
- * copyright            : (C) 2008 Alejandro Wainzinger <aikawarazuni@gmail.com>          *
- ******************************************************************************************/
+/**************************************************************************
+ * Ported to Collection Framework: *
+ * copyright            : (C) 2008 Alejandro Wainzinger <aikawarazuni@gmail.com>
+ *
+ * Original Work: *
+ * copyright            : (C) 2005, 2006 by Martin Aumueller <aumuell@reserv.at>
+ * copyright            : (C) 2004 by Christian Muehlhaeuser <chris@chris.de>
+ *******************************************************************************/
 
 /***************************************************************************
  *                                                                         *
@@ -17,12 +22,14 @@
 
 #include "IpodCollection.h"
 #include "IpodMeta.h"
+#include "../../../statusbar/StatusBar.h"
 #include "Debug.h"
 
 #include "File.h" // for KIO file handling
 #include "taglib_audiblefile.h"
 
 #include <KIO/Job>
+#include <KIO/DeleteJob>
 #include "kjob.h"
 #include <KUniqueApplication> // needed for KIO processes
 #include <KUrl>
@@ -42,37 +49,35 @@ IpodHandler::IpodHandler( IpodCollection *mc, const QString& mountPoint, QObject
     , m_memColl( mc )
     , m_mountPoint( mountPoint )
 {
-DEBUG_BLOCK
+    DEBUG_BLOCK
 
 //    initializeIpod();
 
+        GError *err = 0;
 
+    // Assuming database exists for now, later will port init db code
+    m_itdb = itdb_parse( QFile::encodeName( m_mountPoint ),  &err );
 
- GError *err = 0;
- 
- m_itdb = itdb_parse( QFile::encodeName( m_mountPoint ),  &err );
- if (  err )
- {
-     g_error_free( err );
-     if (  m_itdb )
-     {
-         itdb_free(  m_itdb );
-         m_itdb = 0;
-     }
+    if ( err )
+    {
+        g_error_free( err );
+        if ( m_itdb )
+        {
+            itdb_free( m_itdb );
+            m_itdb = 0;
+        }
 
- }
+    }
 
- qsrand( QTime::currentTime().msec() ); // random number used for folder number generation
+    qsrand( QTime::currentTime().msec() ); // random number used for folder number generation
 
 
 }
 
 IpodHandler::~IpodHandler()
 {
-        if (  m_itdb )
+        if ( m_itdb )
             itdb_free( m_itdb );
-
-//        m_files.clear();
 }
 
 
@@ -144,10 +149,6 @@ IpodHandler::initializeIpod()
 
     debug() << "Init 5";
 
-//    The::statusBar()->longMessage(
-//            i18n("Media Device: Initialized iPod mounted at %1", mountPoint() ),
-//            KDE::StatusBar::Information );
-
     return true;
 }
 
@@ -246,8 +247,7 @@ IpodHandler::detectModel()
             gchar *fwid = itdb_device_get_sysinfo( m_itdb->device, "FirewireGuid" );
             if( !fwid )
             {
-//                The::statusBar()->longMessage(
-//                                            i18n("Your iPod's Firewire GUID is required for correctly updating its music database, but it is not known. See http://amarok.kde.org/wiki/Media_Device:IPod for more information." ) );
+
             }
             else
                g_free( fwid );
@@ -256,8 +256,6 @@ IpodHandler::detectModel()
     else
     {
         debug() << "iPod type detection failed, no video support";
-//        The::statusBar()->longMessage(
-//                i18n("iPod type detection failed: no support for iPod Shuffle, for artwork or video") );
         guess = true;
     }
 
@@ -291,7 +289,6 @@ IpodHandler::detectModel()
 bool
 IpodHandler::pathExists( const QString &ipodPath, QString *realPath )
 {
-    DEBUG_BLOCK
     QDir curDir( mountPoint() );
     QString curPath = mountPoint();
     QStringList components = ipodPath.split( ":" );
@@ -317,13 +314,9 @@ IpodHandler::pathExists( const QString &ipodPath, QString *realPath )
 
     for( ; it != components.end(); ++it )
     {
-        debug() << "curPath before concat: " << curPath;
         curPath += '/' + *it;
-        debug() << "curPath after concat: " << curPath;
     }
 
-    //debug() << ipodPath << ( found ? "" : " not" ) << " found, actually " << curPath;
-
     if( realPath )
         *realPath = curPath;
 
@@ -333,14 +326,13 @@ IpodHandler::pathExists( const QString &ipodPath, QString *realPath )
 bool
 IpodHandler::writeITunesDB( bool threaded )
 {
-
+DEBUG_BLOCK
     if(!m_itdb)
         return false;
 
     if(m_dbChanged)
     {
         bool ok = false;
-//         if( !threaded || MediaBrowser::instance()->isQuitting() )
         if( !threaded )
         {
             if( !m_itdb )
@@ -384,12 +376,7 @@ IpodHandler::writeITunesDB( bool threaded )
         }
         else
         {
-//            ThreadManager::instance()->queueJob( new IpodWriteDBJob( this, m_itdb, m_isShuffle, &ok ) );
-//            while( ThreadManager::instance()->isJobPending( "IpodWriteDBJob" ) )
-//            {
-//                kapp->processEvents();
-//                usleep( 10000 );
-//            }
+
         }
 
         if( ok )
@@ -399,13 +386,12 @@ IpodHandler::writeITunesDB( bool threaded )
         else
         {
             debug() << "Failed to write iPod database";
-//            The::statusBar()->longMessage(
-//                    i18n("Media device: failed to write iPod database"),
-//                    KDE::StatusBar::Error );
         }
 
         return ok;
     }
+
+    debug() << "writeItunesDB is returning true";
     return true;
 }
 
@@ -421,6 +407,27 @@ IpodHandler::itunesDir(const QString &p) const
     return base + p;
 }
 
+bool
+IpodHandler::deleteTrackFromDevice( const Meta::IpodTrackPtr &track )
+{
+    DEBUG_BLOCK
+    Itdb_Track *ipodtrack = track->getIpodTrack();
+
+    // delete file
+    KUrl url;
+    url.setPath( realPath( ipodtrack->ipod_path ) );
+    deleteFile( url );
+
+    // remove it from the ipod database, ipod playlists and all
+
+    if( removeDBTrack( ipodtrack ) )
+        if( writeITunesDB( false ) )
+            return true;
+
+    return false;
+
+}
+
 // Currently Porting copyTrackToDevice
 void
 IpodHandler::copyTrackToDevice( const Meta::TrackPtr &track )
@@ -484,44 +491,72 @@ IpodHandler::copyTrackToDevice( const Meta::TrackPtr &track )
     }
 */
     insertTrackIntoDB( url, track );
-    debug() << "Trying to write iTunes database";
-    writeITunesDB( false ); // false, since not threaded, implement later
+    if( !m_trackCreated )
+    {
+        debug() << "Track failed to create, aborting database write!";
+    }
+//    debug() << "Trying to write iTunes database";
+//    writeITunesDB( false ); // false, since not threaded, implement later
     //delete podcastInfo;
+
+
     return;
 }
 
 void
 IpodHandler::insertTrackIntoDB( const KUrl &url, const Meta::TrackPtr &track )
 {
-    updateTrackInDB( url, track );
+    DEBUG_BLOCK
+    Itdb_Track *ipodtrack = itdb_track_new();
+
+    updateTrackInDB( url, track, ipodtrack ); // get information from track
+
+    if( m_trackCreated )
+    {
+
+    debug() << "Adding " << QString::fromUtf8( ipodtrack->artist) << " - " << QString::fromUtf8( ipodtrack->title );
+
+    addTrackInDB( ipodtrack );
+
+        // add track to collection
+    addIpodTrackToCollection( ipodtrack );
+    }
+    else
+        debug() << "Failed to create track, aborting insertion!";
 }
 
 void
-IpodHandler::updateTrackInDB( const KUrl &url, const Meta::TrackPtr &track )
+IpodHandler::updateTrackInDB( const KUrl &url, const Meta::TrackPtr &track, Itdb_Track *existingIpodTrack )
 {
     DEBUG_BLOCK
     if( !m_itdb )
         return;
 
+    m_trackCreated = true;
+
     QString pathname = url.path();
 
     Itdb_Track *ipodtrack = 0;
-//    if( item )
-//        ipodtrack = item->m_track;
-    if( !ipodtrack )
-        ipodtrack = itdb_track_new();
-    
+    if( !existingIpodTrack )
+    {
+        // NOTE: This should never happen!
+        debug() << "No track passed in, failure!";
+        m_trackCreated = false;
+        return;
+    }
+    else
+        ipodtrack = existingIpodTrack;
+
     if( !ipodtrack )
     {
         return;
     }
-    
+
     QString type = pathname.section('.', -1).toLower();
 
     debug() << "Path before put in ipod_path: " << pathname;
 
     ipodtrack->ipod_path = g_strdup( ipodPath(pathname).toLatin1() );
-    //debug() << "on iPod: " << ipodtrack->ipod_path << ", podcast=" << podcastInfo;
     debug() << "on iPod: " << ipodtrack->ipod_path;
 
     if( !track->name().isEmpty() )
@@ -683,121 +718,100 @@ IpodHandler::updateTrackInDB( const KUrl &url, const Meta::TrackPtr &track )
     }
 */
 
-    // NOTE: legacy code
-    /*
-    if( item )
-    {
-        MediaItem *parent = dynamic_cast<MediaItem *>(item->parent());
-        if( parent )
-        {
-            parent->takeItem( item );
-            if( parent->childCount() == 0 && !isSpecialItem( parent ) )
-            {
-                MediaItem *pp = dynamic_cast<MediaItem *>(parent->parent());
-                delete parent;
-                if( pp && pp->childCount() == 0 && !isSpecialItem( pp ) )
-                    delete pp;
-            }
-        }
-    }
-    */
-        itdb_track_add(m_itdb, ipodtrack, -1);
+    debug() << "Adding " << QString::fromUtf8( ipodtrack->artist) << " - " << QString::fromUtf8( ipodtrack->title );
+
+
+}
+
+void
+IpodHandler::addTrackInDB( Itdb_Track *ipodtrack )
+{
+    DEBUG_BLOCK
+
+            debug() << "Adding " << QString::fromUtf8( ipodtrack->artist) << " - " << QString::fromUtf8( ipodtrack->title );
+    itdb_track_add(m_itdb, ipodtrack, -1);
 
         // TODO: podcasts NYI
         // if(podcastInfo)
-        if( false )
+    if( false )
+    {
+        Itdb_Playlist *podcasts = itdb_playlist_podcasts(m_itdb);
+        if(!podcasts)
         {
-            Itdb_Playlist *podcasts = itdb_playlist_podcasts(m_itdb);
-            if(!podcasts)
-            {
-                podcasts = itdb_playlist_new("Podcasts", false);
-                itdb_playlist_add(m_itdb, podcasts, -1);
-                itdb_playlist_set_podcasts(podcasts);
-            //    addPlaylistToView( podcasts );
-            }
-            itdb_playlist_add_track(podcasts, ipodtrack, -1);
+            podcasts = itdb_playlist_new("Podcasts", false);
+            itdb_playlist_add(m_itdb, podcasts, -1);
+            itdb_playlist_set_podcasts(podcasts);
         }
-        else
-        {
+        itdb_playlist_add_track(podcasts, ipodtrack, -1);
+    }
+    else
+    {
             // gtkpod 0.94 does not like if not all songs in the db are on the master playlist
             // but we try anyway
-            Itdb_Playlist *mpl = itdb_playlist_mpl(m_itdb);
-            if( !mpl )
-            {
-                mpl = itdb_playlist_new( "iPod", false );
-                itdb_playlist_add( m_itdb, mpl, -1 );
-                itdb_playlist_set_mpl( mpl );
-                //addPlaylistToView( mpl );
-            }
-            itdb_playlist_add_track(mpl, ipodtrack, -1);
+        Itdb_Playlist *mpl = itdb_playlist_mpl(m_itdb);
+        if( !mpl )
+        {
+            mpl = itdb_playlist_new( "iPod", false );
+            itdb_playlist_add( m_itdb, mpl, -1 );
+            itdb_playlist_set_mpl( mpl );
         }
+        itdb_playlist_add_track(mpl, ipodtrack, -1);
+    }
+}
 
+bool
+IpodHandler::removeDBTrack( Itdb_Track *track )
+{
+    if(!m_itdb)
+        return false;
 
-//    return addTrackToView( ipodtrack, item );
+    if(!track)
+        return false;
+
+    if(track->itdb != m_itdb)
+    {
+        return false;
+    }
+
+    m_dbChanged = true;
+
+    Itdb_Playlist *mpl = itdb_playlist_mpl(m_itdb);
+    while(itdb_playlist_contains_track(mpl, track))
+    {
+        itdb_playlist_remove_track(mpl, track);
+    }
+
+    GList *cur = m_itdb->playlists;
+    while(cur)
+    {
+        Itdb_Playlist *pl = (Itdb_Playlist *)cur->data;
+        while(itdb_playlist_contains_track(pl, track))
+        {
+            itdb_playlist_remove_track(pl, track);
+        }
+        cur = cur->next;
+    }
+
+    // also frees track's memory
+    itdb_track_remove(track);
+
+    return true;
 }
 
 bool
 IpodHandler::kioCopyTrack( const KUrl &src, const KUrl &dst )
 {
     DEBUG_BLOCK
-    m_wait = true;
 
     KIO::FileCopyJob *job = KIO::file_copy( src, dst,
                                             -1 /* permissions */,
                                             KIO::HideProgressInfo );
-//    connect( job, SIGNAL( result( KIO::Job * ) ),
-//
+
     connect( job, SIGNAL( result( KJob * ) ),
              this,  SLOT( fileTransferred( KJob * ) ) );
 
-    bool tryToRemove = false;
-
-    while ( m_wait )
-    {
-        // TODO: this isn't implemented yet
-
-        if( m_isCanceled )
-        {
-            job->kill( KJob::EmitResult );
-            tryToRemove = true;
-            m_wait = false;
-        }
-        else
-        {
-            usleep(10000);
-            KApplication::kApplication()->processEvents( QEventLoop::ExcludeUserInputEvents );
-        }
-
-    }
-
-
-    if( !tryToRemove )
-    {
-        if(m_copyFailed)
-        {
-            tryToRemove = true;
-            // TODO: make debug more verbose like statusbar
-            debug() << "Copying file failed";
-        }
-        else
-        {
-            MetaFile::Track track2(dst);
-            if( !track2.isPlayable() && track2.filesize()==0 )
-            {
-                tryToRemove = true;
-                // probably s.th. went wrong
-                // TODO: make debug more verbose like statusbar
-                debug() << "Reading tags during file copy failed";
-
-            }
-        }
-    }
-
-    if( tryToRemove )
-    {
-        QFile::remove( dst.path() );
-        return false;
-    }
+    The::statusBar()->newProgressOperation( job ).setDescription(  i18n(  "Transferring Tracks to iPod" )  );
+    job->start();
 
     return true;
 }
@@ -818,6 +832,30 @@ IpodHandler::fileTransferred( KJob *job )  //SLOT
         m_wait = false;
 }
 
+void
+IpodHandler::deleteFile( const KUrl &url )
+{
+    debug() << "deleting " << url.prettyUrl();
+
+    KIO::DeleteJob *job = KIO::del( url, KIO::HideProgressInfo );
+    connect( job, SIGNAL( result( KJob * ) ),
+             this,  SLOT( fileDeleted( KJob * ) ) );
+
+    The::statusBar()->newProgressOperation( job ).setDescription(  i18n(  "Deleting Tracks from iPod" ) );
+    job->start();
+
+    return;
+}
+
+void
+IpodHandler::fileDeleted( KJob *job )  //SLOT
+{
+    if(job->error())
+    {
+        debug() << "file deletion failed: " << job->errorText();
+    }
+}
+
 KUrl
 IpodHandler::determineURLOnDevice( const Meta::TrackPtr &track )
 {
@@ -836,18 +874,13 @@ IpodHandler::determineURLOnDevice( const Meta::TrackPtr &track )
     QString realpath;
     do
     {
-        //int num = std::rand() % 1000000;
         int num = qrand() % 1000000;
         int music_dirs = itdb_musicdirs_number(m_itdb) > 1 ? itdb_musicdirs_number(m_itdb) : 20;
         int dir = num % music_dirs;
         QString dirname;
-        // NOTE: unsure if the sprintf replacement works as intended
-       // dirname.sprintf( "%s:Music:f%02d", itunesDir().toLatin1(), dir );
         debug() << "itunesDir(): " << itunesDir();
-        // NOTE: hack employed due to // turning to ::
-       // dirname = QString( "%1Music:F%2" ).arg( itunesDir() ).arg( QString::number( dir, 10 ), 2, QLatin1Char( '0' ) );
         dirname = QString( "%1Music:F%2" ).arg(  "iPod_Control:" ).arg( QString::number( dir, 10 ), 2, QLatin1Char( '0' ) );
-        
+
         debug() << "Copying to dirname: " << dirname;
         if( !pathExists( dirname ) )
         {
@@ -856,7 +889,6 @@ IpodHandler::determineURLOnDevice( const Meta::TrackPtr &track )
             qdir.mkdir( realdir );
         }
         QString filename;
-        //filename.sprintf( ":kpod%07d.%s", num, type.toLatin1() );
         filename = QString( ":kpod%1.%2" ).arg( QString::number( num, 10 ), 7, QLatin1Char( '0' ) ).arg(type);
         trackpath = dirname + filename;
     }
@@ -896,6 +928,209 @@ IpodHandler::realPath(const char *ipodPath)
     return path;
 }
 
+void
+IpodHandler::addIpodTrackToCollection( Itdb_Track *ipodtrack )
+{
+    TrackMap trackMap = m_memColl->trackMap();
+    ArtistMap artistMap = m_memColl->artistMap();
+    AlbumMap albumMap = m_memColl->albumMap();
+    GenreMap genreMap = m_memColl->genreMap();
+    ComposerMap composerMap = m_memColl->composerMap();
+    YearMap yearMap = m_memColl->yearMap();
+
+
+    QString format( ipodtrack->filetype );
+    IpodTrackPtr track( new IpodTrack( m_memColl, format ) );
+
+    /* 1-liner info retrieval */
+
+    getBasicIpodTrackInfo( ipodtrack, track );
+
+    /* map-related info retrieval */
+    setupArtistMap( ipodtrack, track, artistMap );
+    setupAlbumMap( ipodtrack, track, albumMap );
+    setupGenreMap( ipodtrack, track, genreMap );
+    setupComposerMap( ipodtrack, track, composerMap );
+    setupYearMap( ipodtrack, track, yearMap );
+
+    /* trackmap also soon to be subordinated */
+    
+    trackMap.insert( track->url(), TrackPtr::staticCast( track ) );
+
+    track->setIpodTrack( ipodtrack ); // convenience pointer
+    // NOTE: not supporting adding track that's already on a playlist
+    //ipodTrackMap.insert( ipodtrack, track ); // map for playlist formation
+
+    // Finally, assign the created maps to the collection
+
+    m_memColl->acquireWriteLock();
+    m_memColl->setTrackMap(  trackMap );
+    m_memColl->setArtistMap(  artistMap );
+    m_memColl->setAlbumMap(  albumMap );
+    m_memColl->setGenreMap(  genreMap );
+    m_memColl->setComposerMap(  composerMap );
+    m_memColl->setYearMap(  yearMap );
+    m_memColl->releaseLock();
+
+    return;
+
+}
+
+void
+IpodHandler::getBasicIpodTrackInfo( Itdb_Track *ipodtrack, Meta::IpodTrackPtr track )
+{
+    /* 1-liner info retrieval */
+
+    track->setTitle( QString::fromUtf8( ipodtrack->title ) );
+    track->setLength( ( ipodtrack->tracklen ) / 1000 );
+    track->setTrackNumber( ipodtrack->track_nr );
+    track->setComment( QString::fromUtf8(  ipodtrack->comment ) );
+    track->setDiscNumber( ipodtrack->cd_nr );
+    track->setBitrate( ipodtrack->bitrate );
+    track->setBpm( ipodtrack->BPM );
+    track->setFileSize( ipodtrack->size );
+
+    QString path = QString( ipodtrack->ipod_path ).split( ":" ).join( "/" );
+    path = m_mountPoint + path;
+    track->setPlayableUrl( path );
+
+    return;
+}
+
+void
+IpodHandler::setupArtistMap( Itdb_Track *ipodtrack, Meta::IpodTrackPtr track, ArtistMap &artistMap )
+{
+    QString artist ( QString::fromUtf8( ipodtrack->artist ) );
+    IpodArtistPtr artistPtr;
+
+    if (  artistMap.contains(  artist ) )
+    {
+        artistPtr = IpodArtistPtr::staticCast(  artistMap.value(  artist ) );
+    }
+    else
+    {
+        artistPtr = IpodArtistPtr(  new IpodArtist(  artist ) );
+        artistMap.insert(  artist,  ArtistPtr::staticCast(  artistPtr ) );
+    }
+
+    artistPtr->addTrack(  track );
+    track->setArtist(  artistPtr );
+}
+
+void
+IpodHandler::setupAlbumMap( Itdb_Track *ipodtrack, Meta::IpodTrackPtr track, AlbumMap &albumMap )
+{
+    QString album( QString::fromUtf8( ipodtrack->album ) );
+    IpodAlbumPtr albumPtr;
+
+    if ( albumMap.contains( album ) )
+        albumPtr = IpodAlbumPtr::staticCast(  albumMap.value(  album ) );
+
+    else
+    {
+        albumPtr = IpodAlbumPtr(  new IpodAlbum(  album ) );
+        albumMap.insert(  album,  AlbumPtr::staticCast(  albumPtr ) );
+    }
+
+    albumPtr->addTrack(  track );
+    track->setAlbum(  albumPtr );
+}
+
+void
+IpodHandler::setupGenreMap( Itdb_Track *ipodtrack, Meta::IpodTrackPtr track, GenreMap &genreMap )
+{
+    QString genre = ipodtrack->genre;
+    IpodGenrePtr genrePtr;
+
+    if (  genreMap.contains(  genre ) )
+        genrePtr = IpodGenrePtr::staticCast(  genreMap.value(  genre ) );
+
+    else
+    {
+        genrePtr = IpodGenrePtr(  new IpodGenre(  genre ) );
+        genreMap.insert(  genre,  GenrePtr::staticCast(  genrePtr ) );
+    }
+
+    genrePtr->addTrack( track );
+    track->setGenre( genrePtr );
+}
+
+void
+IpodHandler::setupComposerMap( Itdb_Track *ipodtrack, Meta::IpodTrackPtr track, ComposerMap &composerMap )
+{
+    QString composer ( QString::fromUtf8( ipodtrack->composer ) );
+    IpodComposerPtr composerPtr;
+
+    if ( composerMap.contains( composer ) )
+    {
+        composerPtr = IpodComposerPtr::staticCast( composerMap.value( composer ) );
+    }
+    else
+    {
+        composerPtr = IpodComposerPtr( new IpodComposer( composer ) );
+        composerMap.insert( composer, ComposerPtr::staticCast( composerPtr ) );
+    }
+
+    composerPtr->addTrack( track );
+    track->setComposer( composerPtr );
+}
+
+void
+IpodHandler::setupYearMap( Itdb_Track *ipodtrack, Meta::IpodTrackPtr track, YearMap &yearMap )
+{
+    QString year;
+    year = year.setNum( ipodtrack->year );
+    IpodYearPtr yearPtr;
+    if (  yearMap.contains(  year ) )
+        yearPtr = IpodYearPtr::staticCast(  yearMap.value(  year ) );
+    else
+    {
+        yearPtr = IpodYearPtr(  new IpodYear(  year ) );
+        yearMap.insert(  year,  YearPtr::staticCast(  yearPtr ) );
+    }
+    yearPtr->addTrack(  track );
+    track->setYear(  yearPtr );
+}
+/*
+void
+IpodHandler::setupMetadataMap( Itdb_Track *ipodtrack, Meta::IpodTrackPtr track, DataMapPtr datamap, Metadata metadata)
+{
+    switch( metadata )
+    {
+        case Artist:
+            return;
+        case Album:
+            AlbumMapPtr albumMap = AlbumMapPtr::dynamicCast( datamap );
+            QString album( QString::fromUtf8( ipodtrack->album ) );
+            IpodAlbumPtr albumPtr;
+
+            if ( albumMap->contains( album ) )
+                albumPtr = IpodAlbumPtr::staticCast(  albumMap->value(  album ) );
+
+            else
+            {
+                albumPtr = IpodAlbumPtr(  new IpodAlbum(  album ) );
+                albumMap->insert(  album,  AlbumPtr::staticCast(  albumPtr ) );
+            }
+
+            albumPtr->addTrack(  track );
+            track->setAlbum(  albumPtr );
+            return;
+        case Genre:
+            return;
+        case Composer:
+            return;
+        case Year:
+            return;
+
+        default:
+            return;
+    }
+}
+*/
+
+
+
 void
 IpodHandler::parseTracks()
 {
@@ -908,109 +1143,55 @@ IpodHandler::parseTracks()
     ComposerMap composerMap;
     YearMap yearMap;
 
+    QMap<Itdb_Track*, IpodTrackPtr> ipodTrackMap;
+
     GList *cur;
 
-//    int debugtest = 0;
 /* iterate through tracklist and add to appropriate map */
     for ( cur = m_itdb->tracks; cur; cur = cur->next )
     {
         /* ipodtrack - provides libgpod itdb info */
         /* track - the new track whose data is being set up */
         Itdb_Track *ipodtrack = ( Itdb_Track * )cur->data;
+
         QString format( ipodtrack->filetype );
         IpodTrackPtr track( new IpodTrack( m_memColl, format ) );
 
-        /* 1-liner info retrieval */
-
-        track->setTitle( QString::fromUtf8( ipodtrack->title ) );
-        track->setLength( ( ipodtrack->tracklen ) / 1000 );
-        track->setTrackNumber( ipodtrack->track_nr );
-        track->setComment( QString::fromUtf8(  ipodtrack->comment ) );
-        track->setDiscNumber( ipodtrack->cd_nr );
-        track->setBitrate( ipodtrack->bitrate );
-        track->setBpm( ipodtrack->BPM );
-
-        QString path = QString( ipodtrack->ipod_path ).split( ":" ).join( "/" );
-        path = m_mountPoint + path;
-        track->setPlayableUrl( path );
+        getBasicIpodTrackInfo( ipodtrack, track );
 
         /* map-related info retrieval */
-        QString album( QString::fromUtf8( ipodtrack->album ) );
-        IpodAlbumPtr albumPtr;
 
-        if ( albumMap.contains( album ) )
-            albumPtr = IpodAlbumPtr::staticCast(  albumMap.value(  album ) );
+        setupArtistMap( ipodtrack, track, artistMap );
+        setupAlbumMap( ipodtrack, track, albumMap );
+        setupGenreMap( ipodtrack, track, genreMap );
+        setupComposerMap( ipodtrack, track, composerMap );
+        setupYearMap( ipodtrack, track, yearMap );
 
-        else
-        {
-            albumPtr = IpodAlbumPtr(  new IpodAlbum(  album ) );
-            albumMap.insert(  album,  AlbumPtr::staticCast(  albumPtr ) );
-        }
+        /* TrackMap stuff to be subordinated later */
 
-        albumPtr->addTrack(  track );
-        track->setAlbum(  albumPtr );
-
-        QString artist ( QString::fromUtf8( ipodtrack->artist ) );
-        IpodArtistPtr artistPtr;
-
-        if (  artistMap.contains(  artist ) )
-        {
-            artistPtr = IpodArtistPtr::staticCast(  artistMap.value(  artist ) );
-        }
-        else
-        {
-            artistPtr = IpodArtistPtr(  new IpodArtist(  artist ) );
-            artistMap.insert(  artist,  ArtistPtr::staticCast(  artistPtr ) );
-        }
-
-        artistPtr->addTrack(  track );
-        track->setArtist(  artistPtr );
-
-        QString composer ( QString::fromUtf8( ipodtrack->composer ) );
-        IpodComposerPtr composerPtr;
-
-        if ( composerMap.contains( composer ) )
-        {
-            composerPtr = IpodComposerPtr::staticCast( composerMap.value( composer ) );
-        }
-        else
-        {
-            composerPtr = IpodComposerPtr( new IpodComposer( composer ) );
-            composerMap.insert( composer, ComposerPtr::staticCast( composerPtr ) );
-        }
-
-        QString year;
-        year = year.setNum( ipodtrack->year );
-        IpodYearPtr yearPtr;
-        if (  yearMap.contains(  year ) )
-            yearPtr = IpodYearPtr::staticCast(  yearMap.value(  year ) );
-        else
-        {
-            yearPtr = IpodYearPtr(  new IpodYear(  year ) );
-            yearMap.insert(  year,  YearPtr::staticCast(  yearPtr ) );
-        }
-        yearPtr->addTrack(  track );
-        track->setYear(  yearPtr );
-
-        QString genre = ipodtrack->genre;
-        IpodGenrePtr genrePtr;
-
-        if (  genreMap.contains(  genre ) )
-            genrePtr = IpodGenrePtr::staticCast(  genreMap.value(  genre ) );
-
-        else
-        {
-            genrePtr = IpodGenrePtr(  new IpodGenre(  genre ) );
-            genreMap.insert(  genre,  GenrePtr::staticCast(  genrePtr ) );
-        }
-
-        genrePtr->addTrack( track );
-        track->setGenre( genrePtr );
         trackMap.insert( track->url(), TrackPtr::staticCast( track ) );
 
-
+        track->setIpodTrack( ipodtrack ); // convenience pointer
+        ipodTrackMap.insert( ipodtrack, track ); // map for playlist formation
     }
 
+    // Iterate through ipod's playlists to set track's playlists
+
+    GList *member = 0;
+
+    for ( cur = m_itdb->playlists; cur; cur = cur->next )
+    {
+        Itdb_Playlist *ipodplaylist = ( Itdb_Playlist * ) cur->data;
+        for ( member = ipodplaylist->members; member; member = member->next )
+        {
+            Itdb_Track *ipodtrack = ( Itdb_Track * )member->data;
+            IpodTrackPtr track = ipodTrackMap.value( ipodtrack );
+            track->addIpodPlaylist( ipodplaylist );
+        }
+    }
+
+    // Finally, assign the created maps to the collection
+
     m_memColl->acquireWriteLock();
     m_memColl->setTrackMap(  trackMap );
     m_memColl->setArtistMap(  artistMap );
