@@ -19,16 +19,22 @@
 #ifndef NEPOMUKALBUM_H_
 #define NEPOMUKALBUM_H_
 
+#include "NepomukCollection.h"
+
 #include "Meta.h"
 
+#include <QPixmap>
 #include <QString>
 
+class NepomukCollection;
+
 namespace Meta
 {
+
 class NepomukAlbum : public Album
 {
     public:
-        NepomukAlbum( const QString &name, const QString &artist );
+        NepomukAlbum( NepomukCollection *collection, const QString &name, const QString &artist );
         virtual ~NepomukAlbum() {};
 
         virtual QString name() const;
@@ -41,10 +47,28 @@ class NepomukAlbum : public Album
         virtual bool hasAlbumArtist() const;
         virtual ArtistPtr albumArtist() const;
 
+        virtual bool hasImage( int size = 1 ) const;
+        //virtual bool canUpdateImage() const { return true; }
+        virtual QPixmap image( int size = 1, bool withShadow = false );
+        //virtual void setImage( const QImage &image );
+        //virtual void removeImage();
+
+        // for plugin internal use only
+
+        void emptyCache();
+        QString findImage() const;
+        QString findOrCreateScaledImage( QString path, int size ) const;
+        QString findImageInDir() const;
 
     private:
+        NepomukCollection *m_collection;
+        TrackList m_tracks;
         QString m_name;
         QString m_artist;
+        bool m_tracksLoaded;
+        mutable bool m_hasImage;
+        mutable bool m_hasImageChecked;
+        mutable QString m_imagePath;
 };
 
 }
