@@ -14,7 +14,7 @@
  *  You should have received a copy of the GNU General Public License
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
- */
+*/
 
 #include "DatabaseUpdater.h"
 
@@ -50,6 +50,12 @@ DatabaseUpdater::update()
         createTables();
         m_collection->query( "INSERT INTO admin(key, version) VALUES ('DB_VERSION', 1);" );
     }
+    else if( dbVersion > DB_VERSION )
+    {
+        cleanPermanentTables();
+        createTables();
+        m_collection->query( "INSERT INTO admin(key, version) VALUES( 'DB_VERSION', 1);" );
+    }
 }
 
 void
