@@ -41,6 +41,8 @@ class ScanManager : public QObject
         bool isDirInCollection( QString path );
         bool isFileInCollection( const QString &url );
 
+        void setBlockScan( bool blockScan );
+
     public slots:
         void startFullScan();
         void startIncrementalScan();
@@ -54,6 +56,7 @@ class ScanManager : public QObject
     private:
         QStringList getDirsToScan() const;
         void handleRestart();
+        void cleanTables();
 
     private:
         SqlCollection *m_collection;
@@ -63,6 +66,7 @@ class ScanManager : public QObject
 
         int m_restartCount;
         bool m_isIncremental;
+        bool m_blockScan;
 };
 
 class XmlParseJob : public ThreadWeaver::Job
@@ -78,6 +82,9 @@ class XmlParseJob : public ThreadWeaver::Job
 
         void setIsIncremental( bool incremental );
 
+    signals:
+        void incrementProgress();
+
     private:
         SqlCollection *m_collection;
         bool m_isIncremental;
