@@ -23,12 +23,13 @@
 #include "Debug.h"
 #include "covermanager/CoverFetcher.h"
 #include "covermanager/CoverFetchingActions.h"
-#include "mediadevice/CopyToDeviceAction.h"
+//#include "mediadevice/CopyToDeviceAction.h"
 #include "meta/CustomActionsCapability.h"
 #include "meta/EditCapability.h"
 #include "meta/OrganiseCapability.h"
+#include "meta/UpdateCapability.h"
 #include "MetaUtility.h"
-#include "ScriptManager.h"
+//#include "ScriptManager.h"
 #include "servicebrowser/lastfm/SimilarArtistsAction.h"
 #include "SqlRegistry.h"
 #include "SqlCollection.h"
@@ -98,6 +99,21 @@ class OrganiseCapabilityImpl : public Meta::OrganiseCapability
         KSharedPtr<SqlTrack> m_track;
 };
 
+class UpdateCapabilitySql : public Meta::UpdateCapability
+{
+    Q_OBJECT
+    public:
+        UpdateCapabilitySql( SqlTrack *track )
+    : Meta::UpdateCapability()
+                , m_track( track ) {}
+
+        virtual void collectionUpdated() const { m_track->collection()->collectionUpdated(); }
+
+
+    private:
+        KSharedPtr<SqlTrack> m_track;
+};
+
 QString
 SqlTrack::getTrackReturnValues()
 {
@@ -583,7 +599,7 @@ SqlTrack::finishedPlaying( double playedFraction )
     {
         m_firstPlayed = m_lastPlayed;
     }
-    ScriptManager::instance()->requestNewScore( url(), score(), playCount(), length(), playedFraction * 100 /*scripts expect it as a percent, not a fraction*/, QString() );
+//    ScriptManager::instance()->requestNewScore( url(), score(), playCount(), length(), playedFraction * 100 /*scripts expect it as a percent, not a fraction*/, QString() );
     updateStatisticsInDb();
     notifyObservers();
 }
@@ -647,6 +663,8 @@ SqlTrack::hasCapabilityInterface( Meta::Capability::Type type ) const
         case Meta::Capability::CustomActions:
         case Meta::Capability::Organisable:
             return true;
+        case Meta::Capability::Updatable:
+            return true;
 
         default:
             return false;
@@ -666,7 +684,7 @@ SqlTrack::asCapabilityInterface( Meta::Capability::Type type )
             QList<PopupDropperAction*> actions;
             //TODO These actions will hang around until m_collection is destructed.
             // Find a better parent to avoid this memory leak.
-            actions.append( new CopyToDeviceAction( m_collection, this ) );
+            //actions.append( new CopyToDeviceAction( m_collection, this ) );
 
             return new CustomActionsCapability( actions );
         }
@@ -676,6 +694,9 @@ SqlTrack::asCapabilityInterface( Meta::Capability::Type type )
             return new OrganiseCapabilityImpl( this );
         }
 
+        case Meta::Capability::Updatable:
+            return new UpdateCapabilitySql( this );
+
         default:
             return 0;
     }
@@ -688,6 +709,7 @@ SqlArtist::SqlArtist( SqlCollection* collection, int id, const QString &name ) :
     ,m_name( name )
     ,m_id( id )
     ,m_tracksLoaded( false )
+    ,m_albumsLoaded( false )
     ,m_mutex( QMutex::Recursive )
 {
     //nothing to do (yet)
@@ -713,7 +735,7 @@ SqlArtist::tracks()
     else if( m_collection )
     {
         QueryMaker *qm = m_collection->queryMaker();
-        qm->startTrackQuery();
+        qm->setQueryType( QueryMaker::Track );
         addMatchTo( qm );
         BlockingQuery bq( qm );
         bq.startQuery();
@@ -736,7 +758,7 @@ SqlArtist::albums()
     else if( m_collection )
     {
         QueryMaker *qm = m_collection->queryMaker();
-        qm->startAlbumQuery();
+        qm->setQueryType( QueryMaker::Album );
         addMatchTo( qm );
         BlockingQuery bq( qm );
         bq.startQuery();
@@ -787,7 +809,7 @@ SqlArtist::asCapabilityInterface( Meta::Capability::Type type )
         case Meta::Capability::CustomActions:
         {
             QList<PopupDropperAction *> actions;
-            actions.append( new CopyToDeviceAction( m_collection, this ) );
+            //actions.append( new CopyToDeviceAction( m_collection, this ) );
             actions.append( new SimilarArtistsAction( m_collection, this ) );
             return new CustomActionsCapability( actions );
         }
@@ -875,7 +897,7 @@ SqlAlbum::tracks()
     else if( m_collection )
     {
         QueryMaker *qm = m_collection->queryMaker();
-        qm->startTrackQuery();
+        qm->setQueryType( QueryMaker::Track );
         addMatchTo( qm );
         BlockingQuery bq( qm );
         bq.startQuery();
@@ -1249,7 +1271,7 @@ SqlAlbum::asCapabilityInterface( Meta::Capability::Type type )
         case Meta::Capability::CustomActions:
         {
             QList<PopupDropperAction*> actions;
-            actions.append( new CopyToDeviceAction( m_collection, this ) );
+            //actions.append( new CopyToDeviceAction( m_collection, this ) );
             actions.append( new CompilationAction( m_collection, this ) );
             PopupDropperAction* separator = new PopupDropperAction( m_collection );
             separator->setSeparator( true );
@@ -1305,7 +1327,7 @@ SqlComposer::tracks()
     else if( m_collection )
     {
         QueryMaker *qm = m_collection->queryMaker();
-        qm->startTrackQuery();
+        qm->setQueryType( QueryMaker::Track );
         addMatchTo( qm );
         BlockingQuery bq( qm );
         bq.startQuery();
@@ -1349,7 +1371,7 @@ SqlGenre::tracks()
     else if( m_collection )
     {
         QueryMaker *qm = m_collection->queryMaker();
-        qm->startTrackQuery();
+        qm->setQueryType( QueryMaker::Track );
         addMatchTo( qm );
         BlockingQuery bq( qm );
         bq.startQuery();
@@ -1393,7 +1415,7 @@ SqlYear::tracks()
     else if( m_collection )
     {
         QueryMaker *qm = m_collection->queryMaker();
-        qm->startTrackQuery();
+        qm->setQueryType( QueryMaker::Track );
         addMatchTo( qm );
         BlockingQuery bq( qm );
         bq.startQuery();
