@@ -23,8 +23,11 @@
 #include "Meta.h"
 
 #include <QByteArray>
+#include <QHash>
+#include <QMap>
 #include <QMutex>
 #include <QStringList>
+#include <QVariant>
 
 class SqlCollection;
 
@@ -36,6 +39,8 @@ class SqlTrack : public Meta::Track
     public:
         /** returns a string of all database values that can be fetched for a track */
         static QString getTrackReturnValues();
+        /** returns the number of return values in getTrackReturnValues() */
+        static int getTrackReturnValueCount();
         static TrackPtr getTrack( int deviceid, const QString &rpath, SqlCollection *collection );
 
         SqlTrack( SqlCollection *collection, const QStringList &queryResult );
@@ -116,6 +121,8 @@ class SqlTrack : public Meta::Track
         //SqlTrack specific methods
         int deviceid() const { return m_deviceid; }
         QString rpath() const { return m_rpath; }
+        int trackId() const { return m_trackId; }
+        SqlCollection* sqlCollection() const { return m_collection; }
 
     protected:
         void commitMetaDataChanges();
@@ -131,6 +138,7 @@ class SqlTrack : public Meta::Track
 
         int m_deviceid;
         QString m_rpath;
+        int m_trackId;
 
         int m_length;
         int m_filesize;
@@ -152,8 +160,7 @@ class SqlTrack : public Meta::Track
         Meta::YearPtr m_year;
 
         bool m_batchUpdate;
-        class MetaCache;
-        MetaCache *m_cache;
+        QVariantMap m_cache;
 };
 
 class SqlArtist : public Meta::Artist
@@ -212,8 +219,8 @@ class SqlAlbum : public Meta::Album
         virtual bool hasAlbumArtist() const;
         virtual Meta::ArtistPtr albumArtist() const;
 
-        //updating album images is possible or local tracks, but let's ignore it for now
-        virtual bool hasImage( int size = 1) const;
+        //updating album images is possible for local tracks, but let's ignore it for now
+        virtual bool hasImage( int size = 1 ) const;
         virtual bool canUpdateImage() const { return true; }
         virtual QPixmap image( int size = 1, bool withShadow = false );
         virtual void setImage( const QImage &image );
@@ -230,13 +237,19 @@ class SqlAlbum : public Meta::Album
 
     private:
         QByteArray md5sum( const QString& artist, const QString& album, const QString& file ) const;
-        QString findAmazonImage( int size ) const;
+        QString createScaledImage( QString path, int size ) const;
+        QString findCachedImage( int size ) const;
+        QString findImage( int size );
+        void updateImage( const QString path ) const; // Updates the database to ensure the album has the correct path
 
     private:
         SqlCollection* m_collection;
         QString m_name;
         int m_id;
         int m_artistId;
+        mutable bool m_hasImage;
+        mutable bool m_hasImageChecked;
+        mutable QHash<int, QString> m_images; // Cache mapping size -> path. hash used for O(1) insertion and O(1) lookup
         bool m_tracksLoaded;
         Meta::ArtistPtr m_artist;
         Meta::TrackList m_tracks;
