@@ -46,7 +46,6 @@
 #include <QHash>
 #include <QSet>
 
-#include <kconfig.h>
 #include <KIcon>
 #include <KLineEdit>
 #include <KMenu>
@@ -54,6 +53,8 @@
 
 CollectionTreeView::CollectionTreeView( QWidget *parent)
     : QTreeView( parent )
+    , m_filterModel( 0 )
+    , m_treeModel( 0 )
     , m_pd( 0 )
     , m_appendAction( 0 )
     , m_loadAction( 0 )
@@ -68,16 +69,13 @@ CollectionTreeView::CollectionTreeView( QWidget *parent)
     setSortingEnabled( true );
     sortByColumn( 0, Qt::AscendingOrder );
     setSelectionMode( QAbstractItemView::ExtendedSelection );
+    setSelectionBehavior( QAbstractItemView::SelectRows );
 
     setDragDropMode( QAbstractItemView::DragOnly ); // implement drop when time allows
 
     //setAnimated( true );
     setAlternatingRowColors( true );
 
-    m_treeModel = 0;
-    m_filterModel = 0;
-
-
     //transparency
     /*QPalette p = palette();
     QColor c = p.color( QPalette::Base );
@@ -90,6 +88,8 @@ CollectionTreeView::CollectionTreeView( QWidget *parent)
 
     setPalette( p );*/
 
+    setStyleSheet("QTreeView::item { margin-top: 1px; margin-bottom: 1px; }"); //ensure a bit of space around the cover icons
+
     The::paletteHandler()->updateTreeView( this );
 
     connect( this, SIGNAL( collapsed( const QModelIndex & ) ), SLOT( slotCollapsed( const QModelIndex & ) ) );
@@ -117,12 +117,10 @@ void CollectionTreeView::setModel(QAbstractItemModel * model)
 }
 
 
-
 CollectionTreeView::~CollectionTreeView()
 {
-    //we don't know what collection this is as this class is used with many different collections...
-    //KConfigGroup config = Amarok::config( "Collection Browser" );
-    //config.writeEntry( "TreeCategory", m_treeModel->levels() );
+    DEBUG_BLOCK
+
     delete m_treeModel;
     delete m_filterModel;
 }
@@ -175,7 +173,8 @@ CollectionTreeView::contextMenuEvent( QContextMenuEvent* event )
         indices = tmp;
     }
 
-    PopupDropperActionList actions = createActions( indices );
+    PopupDropperActionList actions = createBasicActions( indices );
+    actions += createExtendedActions( indices );
 
     KMenu menu;
 
@@ -254,6 +253,7 @@ void CollectionTreeView::mouseDoubleClickEvent( QMouseEvent *event )
 
 void CollectionTreeView::mousePressEvent( QMouseEvent *e )
 {
+    DEBUG_BLOCK
     QTreeView::mousePressEvent( e );
 }
 
@@ -262,6 +262,8 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
 {
     DEBUG_BLOCK
 
+    //setSelectionMode( QAbstractItemView::NoSelection );
+
     // When a parent item is dragged, startDrag() is called a bunch of times. Here we prevent that:
     m_dragMutex.lock();
         if( m_ongoingDrag )
@@ -289,7 +291,7 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
             indices = tmp;
         }
 
-        PopupDropperActionList actions = createActions( indices );
+        PopupDropperActionList actions = createBasicActions( indices );
 
         QFont font;
         font.setPointSize( 16 );
@@ -310,7 +312,24 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
                 m_currentItems.insert( static_cast<CollectionTreeItem*>( index.internalPointer() ) );
         }
 
-       /* if ( !( m_currentCopyDestination.empty() && m_currentMoveDestination.empty() ) ) {
+        PopupDropperItem* subItem;
+        
+        PopupDropper * morePud = The::popupDropperFactory()->createPopupDropper( 0 );
+
+        debug() << "Created morePud at address " << morePud;
+
+
+        actions = createExtendedActions( indices );
+
+
+        foreach( PopupDropperAction * action, actions ) {
+            debug() << "1 adding action " << action->objectName();
+            morePud->addItem( The::popupDropperFactory()->createItem( action ), false );
+        }
+
+
+        
+       /*if ( !( m_currentCopyDestination.empty() && m_currentMoveDestination.empty() ) ) {
             if ( m_cmSeperator == 0 ) {
                 m_cmSeperator = new PopupDropperAction( this );
                 m_cmSeperator->setSeparator ( true );
@@ -322,10 +341,10 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
         m_pd->addItem( pdi, false );
         }*/
 
-        PopupDropperItem* subItem;
 
 
-        if ( !m_currentCopyDestination.empty() ) {
+
+       /* if ( !m_currentCopyDestination.empty() ) {
             debug() << "got copy actions";
             //KMenu *copyMenu = new KMenu( i18n( "Copy to Collection" ), &menu );
             PopupDropper * copyPud = The::popupDropperFactory()->createPopupDropper( 0 );
@@ -333,7 +352,8 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
                 debug() << "2 adding action " << action->objectName();
                 copyPud->addItem( The::popupDropperFactory()->createItem( action ), false );
             }
-            subItem = m_pd->addSubmenu( &copyPud, The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ), "collection",  i18n( "Copy to Collection" )  );
+            debug() << "Using morePud at address " << morePud;
+            subItem = morePud->addSubmenu( &copyPud, The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ), "collection",  i18n( "Copy to Collection" )  );
             subItem->setFont( font );
         }
 
@@ -344,16 +364,21 @@ CollectionTreeView::startDrag(Qt::DropActions supportedActions)
                 debug() << "3 adding action " << action->objectName();
                 movePud->addItem( The::popupDropperFactory()->createItem( action ), false );
             }
-            subItem = m_pd->addSubmenu( &movePud, The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ), "collection",  i18n( "Move to Collection" )  );
+            subItem = morePud->addSubmenu( &movePud, The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ), "collection",  i18n( "Move to Collection" )  );
             subItem->setFont( font );
-        }
+        }*/
 
+        subItem = m_pd->addSubmenu( &morePud, The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ), "more",  i18n( "More.." )  );
+        subItem->setFont( font );
+        
         m_pd->show();
     }
 
     QTreeView::startDrag( supportedActions );
     debug() << "After the drag!";
 
+    //setSelectionMode( QAbstractItemView::ExtendedSelection );
+
     if( m_pd )
     {
         debug() << "clearing PUD";
@@ -652,17 +677,19 @@ void CollectionTreeView::slotFilterNow()
     m_treeModel->slotFilter();
 }
 
-PopupDropperActionList CollectionTreeView::createActions( const QModelIndexList & indices )
+PopupDropperActionList CollectionTreeView::createBasicActions( const QModelIndexList & indices )
 {
+    
     PopupDropperActionList actions;
 
     if( !indices.isEmpty() )
     {
 
+        
         if ( m_appendAction == 0 ) {
             m_appendAction = new PopupDropperAction( The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ), "append", KIcon( "media-track-add-amarok" ), i18n( "&Append to Playlist" ), this );
 
-             connect( m_appendAction, SIGNAL( triggered() ), this, SLOT( slotAppendChildTracks() ) );
+            connect( m_appendAction, SIGNAL( triggered() ), this, SLOT( slotAppendChildTracks() ) );
         }
 
         actions.append( m_appendAction );
@@ -675,6 +702,20 @@ PopupDropperActionList CollectionTreeView::createActions( const QModelIndexList
 
         actions.append( m_loadAction );
 
+    }
+
+    return actions;
+
+}
+
+PopupDropperActionList CollectionTreeView::createExtendedActions( const QModelIndexList & indices )
+{
+    PopupDropperActionList actions;
+
+    if( !indices.isEmpty() )
+    {
+
+
         if ( m_editAction == 0 ) {
             m_editAction = new PopupDropperAction( The::svgHandler()->getRenderer( "amarok/images/pud_items.svg" ), "edit", KIcon( "media-track-edit-amarok" ), i18n( "&Edit Track Details" ), this );
             connect( m_editAction, SIGNAL( triggered() ), this, SLOT( slotEditTracks() ) );
@@ -875,7 +916,6 @@ Collection * CollectionTreeView::getCollection( const QModelIndexList & indices
 
 void CollectionTreeView::mouseReleaseEvent( QMouseEvent * event )
 {
-    Q_UNUSED( event )
 
     if( m_pd )
     {
@@ -883,6 +923,8 @@ void CollectionTreeView::mouseReleaseEvent( QMouseEvent * event )
         m_pd->hide();
     }
     m_pd = 0;
+
+    QTreeView::mouseReleaseEvent( event );
 }
 
 void CollectionTreeView::slotPlayChildTracks() {
@@ -891,7 +933,7 @@ void CollectionTreeView::slotPlayChildTracks() {
 
 void CollectionTreeView::slotAppendChildTracks()
 {
-    playChildTracks( m_currentItems, Playlist::Append );
+    playChildTracks( m_currentItems, Playlist::AppendAndPlay );
 }
 
 void CollectionTreeView::slotEditTracks()
