@@ -207,7 +207,7 @@ CollectionScanner::scanFiles( const QStringList& entries )
 {
     typedef QPair<QString, QString> CoverBundle;
 
-    QStringList validImages;    validImages    << "jpg" << "png" << "gif" << "jpeg";
+    QStringList validImages;    validImages    << "jpg" << "png" << "gif" << "jpeg" << "bmp";
     QStringList validPlaylists; validPlaylists << "m3u" << "pls";
 
     QList<CoverBundle> covers;
