@@ -22,7 +22,6 @@
 #include "Amarok.h"
 #include "amarokconfig.h"
 #include <config-amarok.h>  
-#include "moodbar.h"
 
 #include <KStandardDirs>
 
@@ -32,8 +31,6 @@ GeneralConfig::GeneralConfig( QWidget* parent )
 {
     setupUi( this ); 
 
-    slotUpdateMoodFrame();
-
     QStringList browsers;
     browsers << "konqueror" << "firefox" << "opera" << "galeon" << "epiphany" << "safari" << "mozilla";
 
@@ -54,28 +51,27 @@ GeneralConfig::GeneralConfig( QWidget* parent )
         browsers.prepend( i18n( "Default KDE Browser" ) );
 #endif
 
-    kComboBox_browser->insertItems( -1, browsers );
-    kLineEdit_customBrowser->setText( AmarokConfig::externalBrowser() );
+    kcfg_ExternalBrowser->insertItems( -1, browsers );
     int index = browsers.indexOf( AmarokConfig::externalBrowser() );
     if( index >= 0 )
-        kComboBox_browser->setCurrentItem( AmarokConfig::externalBrowser() );
+        kcfg_ExternalBrowser->setCurrentItem( index );
     else if( AmarokConfig::externalBrowser() ==
 #ifdef Q_WS_MAC
-            "open"
+             "open"
 #else
-            "xdg-open"
+             "xdg-open"
 #endif
-      )
+           )
     {
-        kComboBox_browser->setCurrentItem( 0 );
-    }
-    else
-    {
-        checkBox_customBrowser->setChecked( true );
+        kcfg_ExternalBrowser->setCurrentItem( 0 );
+    } else {
+        kcfg_ExternalBrowser->addItem( AmarokConfig::externalBrowser() );
+        kcfg_ExternalBrowser->setCurrentItem( kcfg_ExternalBrowser->count() - 1 );
     }
 
-    connect( kComboBox_browser, SIGNAL( activated( int ) ), parent, SLOT( updateButtons() ) );
-    connect( kLineEdit_customBrowser, SIGNAL( textChanged( const QString& ) ), parent, SLOT( updateButtons() ) );
+
+    connect( kcfg_ExternalBrowser, SIGNAL( textChanged( int ) ), parent, SLOT( updateButtons() ) );
+    //connect( kLineEdit_customBrowser, SIGNAL( textChanged( const QString& ) ), parent, SLOT( updateButtons() ) );
 }
 
 GeneralConfig::~GeneralConfig()
@@ -103,40 +99,8 @@ GeneralConfig::updateSettings() //SLOT
 {
     Amarok::setUseScores( kcfg_UseScores->isChecked() );
     Amarok::setUseRatings( kcfg_UseRatings->isChecked() );
-
-    // The following makes everything with a moodbar redraw itself.
-    Amarok::setMoodbarPrefs( kcfg_ShowMoodbar->isChecked(),
-                             kcfg_MakeMoodier->isChecked(),
-                             kcfg_AlterMood->currentIndex(),
-                             kcfg_MoodsWithMusic->isChecked() );
 }
 
 
-///////////////////////////////////////////////////////////////
-// SLOTS 
-///////////////////////////////////////////////////////////////
-
-void
-GeneralConfig::slotUpdateMoodFrame() //SLOT
-{
-    if( /*Moodbar::executableExists()*/ false /*FIXME: PORT 2.0*/)
-      {
-        moodbarHelpLabel->hide();
-        moodFrame->setEnabled(true);
-
-        kcfg_MakeMoodier->setEnabled(kcfg_ShowMoodbar->isChecked());
-        kcfg_AlterMood->setEnabled(kcfg_ShowMoodbar->isChecked() && kcfg_MakeMoodier->isChecked());
-        kcfg_MoodsWithMusic->setEnabled(kcfg_ShowMoodbar->isChecked());
-      }
-
-    else
-      {
-        moodbarHelpLabel->show();
-        kcfg_ShowMoodbar->setChecked(false);
-        moodFrame->setEnabled(false);
-        moodFrame->hide();
-      }
-}
-
 #include "GeneralConfig.moc"
 
