@@ -15,12 +15,28 @@
 #define AMAROK_APPLET_H
 
 #include "amarok_export.h"
-#include <plasma/applet.h>
+#include "plasma/applet.h"
+
+#include <QFont>
+#include <QRectF>
+#include <QString>
+
 
 namespace Context
 {
 
-typedef Plasma::Applet Applet;
+class AMAROK_EXPORT Applet : public Plasma::Applet
+{
+
+    public:
+
+        explicit Applet( QObject* parent, const QVariantList& args = QVariantList() );
+
+        //helper functions
+        QFont shrinkTextSizeToFit( const QString& text, const QRectF& bounds );
+        QString truncateTextToFit( QString text, const QFont& font, const QRectF& bounds );
+
+};
 
 } // Context namespace
 
