@@ -18,12 +18,15 @@
 #include "Debug.h"
 #include "EngineController.h"
 #include "context/Svg.h"
+#include "context/popupdropper/PopupDropperAction.h"
+#include "meta/CurrentTrackActionsCapability.h"
 #include "meta/MetaUtility.h"
 
-
 #include <plasma/theme.h>
 
-#include <KIconLoader>
+#include <KApplication>
+#include <KIcon>
+#include <KMessageBox>
 
 #include <QPainter>
 #include <QBrush>
@@ -46,13 +49,12 @@ CurrentTrack::CurrentTrack( QObject* parent, const QVariantList& args )
 }
 
 CurrentTrack::~CurrentTrack()
-{
-}
+{}
 
 void CurrentTrack::init()
 {
+    DEBUG_BLOCK
     setBackgroundHints( Plasma::Applet::NoBackground );
-    createMenu();
 
     m_theme = new Context::Svg( this );
     m_theme->setImagePath( "widgets/amarok-currenttrack" );
@@ -60,8 +62,6 @@ void CurrentTrack::init()
  
     m_width = globalConfig().readEntry( "width", 500 );
 
-    KIconLoader *iconLoader = KIconLoader::global();
-
 //     const QColor textColor = Plasma::Theme::defaultTheme()->color( Plasma::Theme::TextColor );
     const QColor textColor( Qt::white );
     QFont labelFont;
@@ -70,8 +70,10 @@ void CurrentTrack::init()
     labelFont.setStyleHint( QFont::Times );
     labelFont.setStyleStrategy( QFont::PreferAntialias );
 
-    QFont textFont = QFont( labelFont );
-    textFont.setBold( false );
+    m_ratingWidget = new RatingWidget( this );
+
+    connect( m_ratingWidget, SIGNAL( ratingChanged( int ) ), SLOT( changeTrackRating( int ) ) );
+    
 
     m_title        = new QGraphicsSimpleTextItem( this );
     m_artist       = new QGraphicsSimpleTextItem( this );
@@ -79,13 +81,22 @@ void CurrentTrack::init()
     m_score        = new QGraphicsSimpleTextItem( this );
     m_numPlayed    = new QGraphicsSimpleTextItem( this );
     m_playedLast   = new QGraphicsSimpleTextItem( this );
-    m_albumCover   = new QGraphicsPixmapItem( this );
+    m_noTrack      = new QGraphicsSimpleTextItem( this );
+    m_albumCover   = new QGraphicsPixmapItem( this ); 
+
 //     m_sourceEmblem = new QGraphicsPixmapItem( this );
 
+    QFont bigFont = QFont( labelFont );
+    bigFont.setPointSize( bigFont.pointSize() +  3 );
+    
+    QFont textFont = QFont( labelFont );    
+    textFont.setBold( false );
+    
     QFont tinyFont( textFont );
     tinyFont.setPointSize( tinyFont.pointSize() - 5 );
     tinyFont.setBold( true );
-    
+
+    m_noTrack->setFont( bigFont );
     m_title->setFont( textFont );
     m_artist->setFont( textFont );
     m_album->setFont( textFont );
@@ -94,6 +105,7 @@ void CurrentTrack::init()
     m_numPlayed->setFont( tinyFont );
     m_playedLast->setFont( tinyFont );
 
+    m_noTrack->setBrush( textColor );
     m_title->setBrush( textColor );
     m_artist->setBrush( textColor );
     m_album->setBrush( textColor );
@@ -105,54 +117,88 @@ void CurrentTrack::init()
     m_theme->resize();
     m_aspectRatio = (qreal)m_theme->size().height() / (qreal)m_theme->size().width();
     resize( m_width, m_aspectRatio );
+    
+    m_noTrackText = "No track playing";
+    m_noTrack->setText( m_noTrackText );
+    
+    connect( dataEngine( "amarok-current" ), SIGNAL( sourceAdded( const QString& ) ),
+            this, SLOT( connectSource( const QString& ) ) );
 
-    dataEngine( "amarok-current" )->connectSource( "current", this );
-    dataUpdated( "current", dataEngine("amarok-current" )->query( "current" ) ); // get data initally
 }
 
-void CurrentTrack::createMenu()
+void
+CurrentTrack::connectSource( const QString &source )
 {
-    QAction *showCoverAction  = new QAction( i18n( "Show Fullsize" ), this );
-    QAction *fetchCoverAction = new QAction( i18n( "Fetch Cover" ), this );
-    QAction *unsetCoverAction = new QAction( i18n( "Unset Cover" ), this );
+    if( source == "current" )
+    {
+        dataEngine( "amarok-current" )->connectSource( source, this );
+        dataUpdated( source, dataEngine("amarok-current" )->query( "current" ) ); // get data initally
+    }
+}
 
-    connect( showCoverAction,  SIGNAL( triggered() ), this, SLOT( showItemImage() ) );
-    connect( fetchCoverAction, SIGNAL( triggered() ), this, SLOT( fetchItemImage() ) );
-    connect( unsetCoverAction, SIGNAL( triggered() ), this, SLOT( unsetItemImage() ) );
+void CurrentTrack::changeTrackRating( int rating )
+{
+    DEBUG_BLOCK
+    Meta::TrackPtr track = The::engineController()->currentTrack();
+    track->setRating( rating );
+    debug() << "change rating to: " << rating;
+}
 
-    m_contextActions.append( showCoverAction );
-    m_contextActions.append( fetchCoverAction );
-    m_contextActions.append( unsetCoverAction );
+QList<QAction*>
+CurrentTrack::contextualActions()
+{
+    QList<QAction*> actions;
+
+    Meta::TrackPtr track = The::engineController()->currentTrack();
+    Meta::AlbumPtr album = track->album();
+
+    if( album )
+    {
+        Meta::CustomActionsCapability *cac = album->as<Meta::CustomActionsCapability>();
+        if( cac )
+        {
+            QList<PopupDropperAction *> pudActions = cac->customActions();
+             
+            foreach( PopupDropperAction *action, pudActions )
+                actions.append( action );
+        }
+    }
+    return actions;
 }
 
 void CurrentTrack::constraintsEvent( Plasma::Constraints constraints )
 {
+    Q_UNUSED( constraints )
+
     prepareGeometryChange();
 
     /*if( constraints & Plasma::SizeConstraint )
          m_theme->resize(size().toSize());*/
 
     //bah! do away with trying to get postions from an svg as this is proving wildly inaccurate
-    qreal margin = 14.0;
-    qreal albumWidth = size().toSize().height() - 2.0 * margin;
+    const qreal margin = 14.0;
+    const qreal albumWidth = size().toSize().height() - 2.0 * margin;
     resizeCover( m_bigCover, margin, albumWidth );
 
-    qreal labelX = albumWidth + margin + 14.0;
-    qreal labelWidth = 15;
-    qreal textX = labelX + labelWidth + margin;
+    const qreal labelX = albumWidth + margin + 14.0;
+    const qreal labelWidth = 15;
+    const qreal textX = labelX + labelWidth + margin;
 
-    qreal textHeight = ( ( size().toSize().height() - 3 * margin )  / 5.0 ) ;
-    qreal textWidth = size().toSize().width() - ( textX + margin );
+    const qreal textHeight = ( ( size().toSize().height() - 3 * margin )  / 5.0 ) ;
+    const qreal textWidth = size().toSize().width() - ( textX + margin + 23 ); // add 23 to ensure that we do not paint into the small labels
+    
 
     // here we put all of the text items into the correct locations
+
+    m_noTrack->setPos( size().toSize().width() / 2 - m_noTrack->boundingRect().width() / 2,
+                       size().toSize().height() / 2  - 30 );
+    
     m_artist->setPos( QPointF( textX, margin ) );
-    m_title->setPos(  QPointF( textX, margin * 2 + textHeight ) );
-    m_album->setPos( QPointF( textX, margin * 3 + textHeight * 2.0 ) );
-
-
-
-    int runningX = labelX;    
+    m_album->setPos(  QPointF( textX, margin * 2 + textHeight ) );
+    m_title->setPos( QPointF( textX, margin * 3 + textHeight * 2.0 ) );
+    
 
+    
     m_score->setPos( QPointF( contentsRect().width() - 6, margin + 4 ) );
     m_numPlayed->setPos( QPointF( contentsRect().width() - 5, margin + 31 ) );
     m_playedLast->setPos( QPointF( contentsRect().width() - 6, margin + 58 ) );
@@ -173,8 +219,9 @@ void CurrentTrack::constraintsEvent( Plasma::Constraints constraints )
     
     tinyFont.setBold( true );
     labeFont.setBold( true );
-    
-    m_maxTextWidth = size().toSize().width() - m_title->pos().x() - 14;
+
+    m_maxTextWidth = textWidth;
+    //m_maxTextWidth = size().toSize().width() - m_title->pos().x() - 14;
 
 
     m_title->setFont( textFont );
@@ -188,6 +235,15 @@ void CurrentTrack::constraintsEvent( Plasma::Constraints constraints )
     m_artist->setText( truncateTextToFit( artist, m_artist->font(), QRectF( 0, 0, textWidth, 30 ) ) );
     m_title->setText( truncateTextToFit( title, m_title->font(), QRectF( 0, 0, textWidth, 30 ) ) );    
     m_album->setText( truncateTextToFit( album, m_album->font(), QRectF( 0, 0, textWidth, 30 ) ) );
+    
+    if( m_noTrackText != QString() )
+        m_noTrack->setText( truncateTextToFit( m_noTrackText, m_noTrack->font(), QRectF( 0, 0, textWidth, 30 ) ) );
+
+    m_ratingWidget->setPos( labelX + 25, margin * 4.0 + textHeight * 3.0 - 5.0 );
+    m_ratingWidget->setMinimumSize( contentsRect().width() / 5, textHeight );
+    m_ratingWidget->setMaximumSize( contentsRect().width() / 5, textHeight );
+    m_ratingWidget->setSpacing( 2 );
+    m_ratingWidget->show();
 
     dataEngine( "amarok-current" )->setProperty( "coverWidth", m_theme->elementRect( "albumart" ).size().width() );
 }
@@ -203,6 +259,20 @@ void CurrentTrack::dataUpdated( const QString& name, const Plasma::DataEngine::D
 
     QRect textRect( 0, 0, m_maxTextWidth, 30 );
 
+    m_noTrackText = data[ "notrack" ].toString();
+
+    if( m_noTrackText != QString() )
+    {
+        QRect rect( 0, 0, size().toSize().width(), 30 );
+        m_noTrack->setText( truncateTextToFit( m_noTrackText, m_noTrack->font(), rect ) );
+        m_noTrack->setPos( size().toSize().width() / 2 - m_noTrack->boundingRect().width() / 2,
+                       size().toSize().height() / 2  - 30 );
+        update();
+        return;
+    }
+
+    m_noTrack->setText( QString() );
+    
     m_currentInfo = data[ "current" ].toMap();
     m_title->setText( truncateTextToFit( m_currentInfo[ Meta::Field::TITLE ].toString(), m_title->font(), textRect ) );
     QString artist = m_currentInfo.contains( Meta::Field::ARTIST ) ? m_currentInfo[ Meta::Field::ARTIST ].toString() : QString();
@@ -217,6 +287,8 @@ void CurrentTrack::dataUpdated( const QString& name, const Plasma::DataEngine::D
     m_playedLast->setText( Amarok::conciseTimeSince( m_currentInfo[ Meta::Field::LAST_PLAYED ].toUInt() ) );
     m_numPlayed->setText( m_currentInfo[ Meta::Field::PLAYCOUNT ].toString() );
 
+    m_ratingWidget->setRating( m_rating );
+
     //scale pixmap on demand
     //store the big cover : avoid blur when resizing the applet
     m_bigCover = data[ "albumart" ].value<QPixmap>();
@@ -235,13 +307,12 @@ void CurrentTrack::dataUpdated( const QString& name, const Plasma::DataEngine::D
 QSizeF 
 CurrentTrack::sizeHint( Qt::SizeHint which, const QSizeF & constraint) const
 {
+    Q_UNUSED( which )
+
     if( constraint.height() == -1 && constraint.width() > 0 ) // asking height for given width basically
-    {
         return QSizeF( constraint.width(), m_aspectRatio * constraint.width() );
-    } else
-    {
-        return constraint;
-    }
+
+    return constraint;
 }
 
 void CurrentTrack::paintInterface( QPainter *p, const QStyleOptionGraphicsItem *option, const QRect &contentsRect )
@@ -259,9 +330,9 @@ void CurrentTrack::paintInterface( QPainter *p, const QStyleOptionGraphicsItem *
     else
     {
         foreach ( QGraphicsItem * childItem, QGraphicsItem::children () )
-            childItem->show();
+            childItem->show();        
     }
-
+    
     p->save();
     m_theme->paint( p, contentsRect.adjusted( 0, -10, 0, 10 ) , "background" );
     QRect leftBorder( 0, 0, 14, contentsRect.height() + 20 );
@@ -269,16 +340,25 @@ void CurrentTrack::paintInterface( QPainter *p, const QStyleOptionGraphicsItem *
     QRect rightBorder( contentsRect.width() + 5, 0, 14, contentsRect.height() + 20 );
     m_theme->paint( p, rightBorder, "right-border" );
     p->restore();
+    
+    if( m_noTrack->text() != QString() )
+    {
+        DEBUG_LINE_INFO
+        foreach ( QGraphicsItem * childItem, QGraphicsItem::children() )
+            childItem->hide();
+        m_noTrack->show();
+        return;
+    }
 
-    qreal margin = 14.0;
-    qreal albumWidth = size().toSize().height() - 2.0 * margin;
+    m_noTrack->hide();
+    
+    const qreal margin = 14.0;
+    const qreal albumWidth = size().toSize().height() - 2.0 * margin;
 
-    qreal labelX = albumWidth + margin + 14.0;
-    qreal labelWidth = size().toSize().width() / 6.0;
-    qreal textX = labelX + labelWidth + margin;
+    const qreal labelX = albumWidth + margin + 14.0;
+    //const qreal labelWidth = size().toSize().width() / 6.0;
 
-    qreal textHeight = ( ( size().toSize().height() - 3 * margin )  / 5.0 );
-    qreal textWidth = size().toSize().width() - ( textX + margin );
+    const qreal textHeight = ( ( size().toSize().height() - 3 * margin )  / 5.0 );
 
     p->save();
     
@@ -288,8 +368,8 @@ void CurrentTrack::paintInterface( QPainter *p, const QStyleOptionGraphicsItem *
         m_theme->paint( p, QRect( margin - 5, margin, albumWidth + 12, albumWidth ), "cd-box" );
 
     m_theme->paint( p, QRectF( labelX, margin + 1, 16, 16 ), "artist" );
-    m_theme->paint( p, QRectF( labelX, margin * 2.0 + textHeight + 1 , 16, 16 ), "track" );
-    m_theme->paint( p, QRectF( labelX, margin * 3.0 + textHeight * 2.0 + 1, 16, 16 ), "album" );
+    m_theme->paint( p, QRectF( labelX, margin * 2.0 + textHeight + 1 , 16, 16 ), "album" );
+    m_theme->paint( p, QRectF( labelX, margin * 3.0 + textHeight * 2.0 + 1, 16, 16 ), "track" );
 
     m_theme->paint( p, QRectF( contentsRect.width() - 12, margin, 23, 23 ), "score" );
     m_theme->paint( p, QRectF( contentsRect.width() - 12, margin + 26, 23, 23 ), "times-played" );
@@ -297,31 +377,15 @@ void CurrentTrack::paintInterface( QPainter *p, const QStyleOptionGraphicsItem *
 
     p->restore();
 
-    // Let the stars for convenience for now before setting up a proper rating widget
-    p->save();
-    int stars = m_rating / 2;
-    for( int i = 0; i < stars; i++ )
-    {
-        m_theme->paint( p, QRectF( labelX + 25 + i * 20.0, margin * 4.0 + textHeight * 3.0 - 5.0, 18, 18 ), "star-white" );
-    }
-    for( int i = stars; i < 5; i++ )
-    {
-        m_theme->paint( p, QRectF( labelX + 25 + i * 20.0, margin * 4.0 + textHeight * 3.0 - 5.0, 18, 18 ), "star-dark" );
-    }
-    p->restore();
-
     // TODO get, and then paint, album pixmap
-//     constraintsEvent();
-
+    // constraintsEvent();
 }
 
 void CurrentTrack::showConfigurationInterface()
-{
-}
+{}
 
 void CurrentTrack::configAccepted() // SLOT
-{
-}
+{}
 
 
 bool CurrentTrack::resizeCover( QPixmap cover,qreal margin, qreal width )
