@@ -18,6 +18,7 @@
 #include <context/Applet.h>
 #include <context/DataEngine.h>
 #include <context/Svg.h>
+#include <context/widgets/RatingWidget.h>
 
 #include <KDialog>
 
@@ -50,11 +51,10 @@ public slots:
 
 private slots:
     void configAccepted();
-
+    void changeTrackRating( int rating );
+    void connectSource( const QString &source );
 private:
-    void createMenu();
-    QList<QAction*> contextualActions() const { return m_contextActions; }
-    QList<QAction*> m_contextActions;
+    QList<QAction*> contextualActions();
 
     QHBoxLayout* m_configLayout;
     QSpinBox* m_spinWidth;
@@ -77,6 +77,7 @@ private:
     QGraphicsSimpleTextItem* m_score;
     QGraphicsSimpleTextItem* m_numPlayed;
     QGraphicsSimpleTextItem* m_playedLast;
+    QGraphicsSimpleTextItem* m_noTrack;
 
     int m_rating;
     int m_trackLength;
@@ -86,6 +87,10 @@ private:
     QPixmap m_bigCover;
     QPixmap m_sourceEmblemPixmap;
 
+    RatingWidget* m_ratingWidget;
+
+    QString m_noTrackText;
+
     bool resizeCover( QPixmap cover, qreal margin, qreal width );
 
     int m_maxTextWidth;
