@@ -41,8 +41,6 @@ LyricsApplet::~ LyricsApplet()
 
 void LyricsApplet::init()
 {
-
-
     m_lyricsProxy = new QGraphicsProxyWidget( this );
     m_lyrics = new QTextEdit;
     m_lyrics->setReadOnly( true );
@@ -50,11 +48,21 @@ void LyricsApplet::init()
     m_lyricsProxy->setWidget( m_lyrics );
     m_lyrics->setPlainText( i18n( "Hello, World" ) );
 
-    dataEngine( "amarok-lyrics" )->connectSource( "lyrics", this );
+    connect( dataEngine( "amarok-lyrics" ), SIGNAL( sourceAdded( const QString& ) ), this, SLOT( connectSource( const QString& ) ) );
 
     constraintsEvent();
 }
 
+void LyricsApplet::connectSource( const QString& source )
+{
+    DEBUG_BLOCK
+
+    if( source == "lyrics" ) {
+        dataEngine( "amarok-lyrics" )->connectSource( source, this );
+        dataUpdated( source, dataEngine("amarok-lyrics" )->query( "lyrics" ) ); // get data initally
+    }
+}
+
 void LyricsApplet::constraintsEvent( Plasma::Constraints constraints )
 {
     prepareGeometryChange();
@@ -65,8 +73,9 @@ void LyricsApplet::constraintsEvent( Plasma::Constraints constraints )
 
 void LyricsApplet::dataUpdated( const QString& name, const Plasma::DataEngine::Data& data )
 {
-    kDebug() << "LyricsApplet::dataUpdated";
     Q_UNUSED( name )
+    DEBUG_BLOCK
+
     if( data.size() == 0 ) return;
 
     if( data.contains( "noscriptrunning" ) )
