@@ -16,6 +16,7 @@
 #include "Amarok.h"
 #include "Debug.h"
 #include "context/Svg.h"
+#include "EngineController.h"
 #include <plasma/theme.h>
 
 #include <QGraphicsTextItem>
@@ -30,7 +31,7 @@ WikipediaApplet::WikipediaApplet( QObject* parent, const QVariantList& args )
     , m_headerAspectRatio( 0.0 )
     , m_size( QSizeF() )
     , m_wikipediaLabel( 0 )
-    , m_wikiPage( 0 )
+    , m_webView( 0 )
 {
 
     setHasConfigurationInterface( false );
@@ -40,15 +41,15 @@ WikipediaApplet::WikipediaApplet( QObject* parent, const QVariantList& args )
 WikipediaApplet::~ WikipediaApplet()
 {
     //hacky stuff to keep QWebView from causing a crash
-    m_wikiPage->setWidget( 0 );
+   /* m_wikiPage->setWidget( 0 );
     delete m_wikiPage;
     m_wikiPage = 0;
+    delete m_webView;*/
     delete m_webView;
 }
 
 void WikipediaApplet::init()
 {
-
     m_header = new Context::Svg( this );
     m_header->setImagePath( "widgets/amarok-wikipedia" );
     m_header->setContainsMultipleImages( false );
@@ -60,9 +61,23 @@ void WikipediaApplet::init()
 
     m_wikipediaLabel = new QGraphicsSimpleTextItem( this );
 
-    m_webView = new QWebView();
-    m_wikiPage = new QGraphicsProxyWidget( this );
-    m_wikiPage->setWidget( m_webView );
+    m_webView = new Plasma::WebContent( this );
+
+
+    //make background transparent
+
+    QPalette p = m_webView->palette();
+    p.setColor( QPalette::Dark, QColor( 255, 255, 255, 0)  );
+    m_webView->setPalette( p );
+
+    
+    p = m_webView->page()->palette();
+    p.setColor( QPalette::Window, QColor( 255, 255, 255, 0)  );
+    m_webView->page()->setPalette( p );
+
+
+    //m_wikiPage = new QGraphicsProxyWidget( this );
+    //m_wikiPage->setWidget( m_webView );
 
     QFont labelFont;
     labelFont.setBold( true );
@@ -71,12 +86,24 @@ void WikipediaApplet::init()
     m_wikipediaLabel->setFont( labelFont );
     m_wikipediaLabel->setText( i18n( "Wikipedia" ) );
 
-    dataEngine( "amarok-wikipedia" )->connectSource( "wikipedia", this );
+    if( The::engineController()->state() == Phonon::PlayingState  )
+        dataEngine( "amarok-wikipedia" )->connectSource( "wikipedia", this );
+    else
+        connect( dataEngine( "amarok-wikipedia" ), SIGNAL( sourceAdded( const QString & ) ),
+                 this, SLOT( connectSource( const QString & ) ) );
     
     constraintsEvent();
 
 }
 
+
+void
+WikipediaApplet::connectSource( const QString &source )
+{
+    if( source == "wikipedia" )
+        dataEngine( "amarok-wikipedia" )->connectSource( "wikipedia", this );
+}
+
 void WikipediaApplet::constraintsEvent( Plasma::Constraints constraints )
 {
     prepareGeometryChange();
@@ -92,17 +119,16 @@ void WikipediaApplet::constraintsEvent( Plasma::Constraints constraints )
     m_wikipediaLabel->setPos( offsetX, m_header->elementRect( "wikipedialabel" ).topLeft().y() );
     m_wikipediaLabel->setFont( shrinkTextSizeToFit( "Wikipedia", m_header->elementRect( "wikipedialabel" ) ) );
 
-    m_wikiPage->setPos( m_header->elementRect( "wikipediainformation" ).topLeft() );
+    m_webView->setPos( m_header->elementRect( "wikipediainformation" ).topLeft() );
 
     QSizeF infoSize( m_header->elementRect( "wikipediainformation" ).bottomRight().x() - m_header->elementRect( "wikipediainformation" ).topLeft().x(), m_header->elementRect( "wikipediainformation" ).bottomRight().y() - m_header->elementRect( "wikipediainformation" ).topLeft().y() );
 
     if ( infoSize.isValid() ) {
-        m_wikiPage->setMinimumSize( infoSize );
-        m_wikiPage->setMaximumSize( infoSize );
+        m_webView->resize( infoSize );
     }
 
-    m_wikiPage->show();
-}
+        //m_webView->show();
+    }
 
 bool WikipediaApplet::hasHeightForWidth() const
 {
@@ -124,9 +150,10 @@ void WikipediaApplet::dataUpdated( const QString& name, const Plasma::DataEngine
     if( data.size() == 0 ) return;
 
     if( data.contains( "page" ) ) {
-        m_webView->setHtml( data[ "page" ].toString() );
+        m_webView->setHtml( data[ "page" ].toString(), KUrl( QString() ) );
     } else {
-        m_webView->setHtml( data[ data.keys()[ 0 ] ].toString() ); // set data
+        m_webView->setHtml( data[ data.keys()[ 0 ] ].toString(), KUrl( QString() ) ); // set data
+
     }
 
     if( data.contains( "label" ) )
