@@ -21,6 +21,9 @@
 #include <QGraphicsProxyWidget>
 #include <qwebview.h>
 
+#include "context/plasma/widgets/webcontent.h"
+
+
 class QGraphicsSimpleTextItem;
 class QGraphicsTextItem;
 
@@ -56,12 +59,14 @@ private:
     //QGraphicsSimpleTextItem* m_currentLabel;
     //QGraphicsSimpleTextItem* m_currentTitle;
 
-    QGraphicsProxyWidget* m_wikiPage;
-    QWebView * m_webView;
+    //QGraphicsProxyWidget* m_wikiPage;
+    Plasma::WebContent * m_webView;
 
     QString m_label;
     QString m_title;
-
+    
+private slots:
+    void connectSource( const QString &source );
 };
 
 K_EXPORT_AMAROK_APPLET( wikipedia, WikipediaApplet )
