@@ -1,5 +1,6 @@
 /***************************************************************************
  * copyright            : (C) 2007 Leo Franchi <lfranchi@gmail.com>        *
+ * copyright            : (C) 2008 Mark Kretschmann <kretschmann@kde.org>  *
  **************************************************************************/
 
 /***************************************************************************
@@ -13,11 +14,11 @@
 
 #include "WikipediaEngine.h"
 
-#include "amarok.h"
-#include "debug.h"
+#include "Amarok.h"
+#include "Debug.h"
 #include "ContextObserver.h"
 #include "ContextView.h"
-#include "enginecontroller.h"
+#include "EngineController.h"
 
 using namespace Context;
 
@@ -25,31 +26,39 @@ WikipediaEngine::WikipediaEngine( QObject* parent, const QList<QVariant>& /*args
     : DataEngine( parent )
     , ContextObserver( ContextView::self() )
     , m_wikiJob( 0 )
+    , m_currentSelection( "artist" )
+    , m_wikiLocale( "en" )
+    , m_requested( true )
+    , m_sources( "current" )
+{
+    update();
+}
+
+WikipediaEngine::~WikipediaEngine()
 {
     DEBUG_BLOCK
-    m_requested = true; // testing
-    m_wikiLocale = "en";
-    m_currentSelection = "artist";
 }
 
 QStringList WikipediaEngine::sources() const
 {
-    return QStringList();
+    return m_sources;
 }
 
 bool WikipediaEngine::sourceRequested( const QString& name )
 {
+    DEBUG_BLOCK
     Q_UNUSED( name )
+
     m_requested = true; // someone is asking for data, so we turn ourselves on :)
-    setData( "wikipedia", QVariant() );
+    removeAllData( name );
+    setData( name, QVariant());
     update();
-    //FIXME return something!
+
     return true;
 }
 
 void WikipediaEngine::message( const ContextState& state )
 {
-    DEBUG_BLOCK
     if( state == Current && m_requested )
         update();
 }
@@ -57,100 +66,149 @@ void WikipediaEngine::message( const ContextState& state )
 void WikipediaEngine::update()
 {
     DEBUG_BLOCK
-    QString tmpWikiStr;
     
+    QString tmpWikiStr;
+    Meta::TrackPtr currentTrack = The::engineController()->currentTrack();
 
-    if( selection() == "artist" ) // default, or applet told us to fetch artist 
-    {
-        if ( (EngineController::instance()->currentTrack()->playableUrl().protocol() == "lastfm") ||
-             (EngineController::instance()->currentTrack()->playableUrl().protocol() == "daap") ||
-             !EngineController::engine()->isStream() )
-        {
-            tmpWikiStr = EngineController::instance()->currentTrack()->artist()->name();
-            tmpWikiStr += wikiArtistPostfix();
-        } else
-            tmpWikiStr = EngineController::instance()->currentTrack()->prettyName();
-    } else if( selection() == "title" )
-        tmpWikiStr = EngineController::instance()->currentTrack()->prettyName();
-    else if( selection() == "album" )
-    {
-        if ( (EngineController::instance()->currentTrack()->playableUrl().protocol() == "lastfm") ||
-             (EngineController::instance()->currentTrack()->playableUrl().protocol() == "daap") ||
-             !EngineController::engine()->isStream() )
-        {
-            tmpWikiStr = EngineController::instance()->currentTrack()->album ()->name();
-            tmpWikiStr += wikiAlbumPostfix();
-        }
+    if ( !currentTrack ) {
+        return;
     }
     
+    DataEngine::Data data;
+
+    if( selection() == "artist" ) // default, or applet told us to fetch artist
+    {
+        data["wikipedia"] = "label, artist";
+        if( currentTrack->artist() )
+        {
+            data["wikipedia"] = "title", currentTrack->artist()->prettyName();
+
+            if ( ( currentTrack->playableUrl().protocol() == "lastfm" ) ||
+                ( currentTrack->playableUrl().protocol() == "daap" ) ||
+                !The::engineController()->isStream() )
+            {
+                tmpWikiStr = currentTrack->artist()->name();
+                tmpWikiStr += wikiArtistPostfix(); //makes wikipedia bail out
+
+                debug() << "tmpWikiStr: " << tmpWikiStr;
+            }
+            else
+            {
+                tmpWikiStr = currentTrack->artist()->prettyName();
+                tmpWikiStr += wikiArtistPostfix(); //makes wikipedia bail out
+            }
+        }
+    }
+    else if( selection() == "title" )
+    {
+        tmpWikiStr = currentTrack->prettyName();
+        data["wikipedia"] = QString( "label" ), QString( "Title" );
+        data["wikipedia"] = "title", currentTrack->prettyName();
+    }
+    else if( selection() == "album" )
+    {
+        if( currentTrack->album() )
+        {
+            data["wikipedia"] = QString( "label" ), QString( "Album" );
+            data["wikipedia"] = "title", currentTrack->album()->prettyName();
+            if ( ( currentTrack->playableUrl().protocol() == "lastfm" ) ||
+                ( currentTrack->playableUrl().protocol() == "daap" ) ||
+                !The::engineController()->isStream() )
+            {
+                tmpWikiStr = currentTrack->album()->name();
+                tmpWikiStr += wikiAlbumPostfix();
+            }
+        }
+    }
+
     //Hack to make wiki searches work with magnatune preview tracks
-    
+
     if ( tmpWikiStr.contains( "PREVIEW: buy it at www.magnatune.com" ) ) {
         tmpWikiStr = tmpWikiStr.remove(" (PREVIEW: buy it at www.magnatune.com)" );
+
         int index = tmpWikiStr.indexOf( '-' );
         if ( index != -1 ) {
             tmpWikiStr = tmpWikiStr.left (index - 1);
         }
-        
     }
+
+    if( m_wikiCurrentEntry == tmpWikiStr ) {
+        debug() << "Same entry requested again. Ignoring.";
+        return;
+    }
+
+    removeAllData( "wikipedia" );
+
+    foreach( QString key, data.keys() )
+        setData( key, data[key] );
+
     m_wikiCurrentEntry = tmpWikiStr;
-    
-    m_wikiCurrentUrl = wikiURL( tmpWikiStr );
-    
-    setData( "wikipedia", "message", "fetching" );
+    m_wikiCurrentUrl = wikiUrl( tmpWikiStr );
+
+    debug() << "wiki url: " << m_wikiCurrentUrl;
+
+    setData( "wikipedia", "message", i18n( "Fetching content.." ) );
     m_wikiJob = KIO::storedGet( m_wikiCurrentUrl, KIO::NoReload, KIO::HideProgressInfo );
     connect( m_wikiJob, SIGNAL( result( KJob* ) ), SLOT( wikiResult( KJob* ) ) );
 }
 
-void WikipediaEngine::wikiResult( KJob* job )
+void
+WikipediaEngine::wikiResult( KJob* job )
 {
     DEBUG_BLOCK
-    if( !m_wikiJob ) return; //track changed while we were fetching
     
-    if ( !job->error() == 0 && job == m_wikiJob )
+    if( !m_wikiJob ) return; //track changed while we were fetching
+
+    if( !job->error() == 0 && job == m_wikiJob )
     { // make sure its not the wrong job (e.g. wiki request for now changed song
         setData( "wikipedia", "error" );
         m_wikiJob = 0; // clear job
         return;
     }
-    if ( job != m_wikiJob )
+    if( job != m_wikiJob )
         return; //not the right job, so let's ignore it
-    
+
     KIO::StoredTransferJob* const storedJob = static_cast<KIO::StoredTransferJob*>( job );
-    m_wiki = QString( storedJob->data() );
-    
+    m_wiki = storedJob->data();
+
+    //debug() << "reply: " << m_wiki;
+
     // FIXME: Get a safer Regexp here, to match only inside of <head> </head> at least.
     if ( m_wiki.contains( "charset=utf-8"  ) ) {
         m_wiki = QString::fromUtf8( storedJob->data().data(), storedJob->data().size() );
     }
-    
-    if( m_wiki.indexOf( "var wgArticleId = 0" ) != -1 )
+
+    if( m_wiki.contains( "var wgArticleId = 0" ) )
     {
+        QString entry;
+        debug() << "Article not found. Retrying with refinements.";
+
         // article was not found
         if( m_wikiCurrentEntry.endsWith( wikiArtistPostfix() ) )
         {
-            m_wikiCurrentEntry = m_wikiCurrentEntry.left( m_wikiCurrentEntry.length() - wikiArtistPostfix().length() );
-            reloadWikipedia();
-            return;
+            debug() << "m_wikiCurrentEntry.endsWith( wikiArtistPostfix() )";
+            entry = m_wikiCurrentEntry.left( m_wikiCurrentEntry.length() - wikiArtistPostfix().length() );
         }
         else if( m_wikiCurrentEntry.endsWith( wikiAlbumPostfix() ) )
         {
-            m_wikiCurrentEntry = m_wikiCurrentEntry.left( m_wikiCurrentEntry.length() - wikiAlbumPostfix().length() );
-            reloadWikipedia();
-            return;
+            entry = m_wikiCurrentEntry.left( m_wikiCurrentEntry.length() - wikiAlbumPostfix().length() );
         }
         else if( m_wikiCurrentEntry.endsWith( wikiTrackPostfix() ) )
         {
-            m_wikiCurrentEntry = m_wikiCurrentEntry.left( m_wikiCurrentEntry.length() - wikiTrackPostfix().length() );
-            reloadWikipedia();
-            return;
+            entry = m_wikiCurrentEntry.left( m_wikiCurrentEntry.length() - wikiTrackPostfix().length() );
         }
+
+        m_wikiCurrentUrl = wikiUrl( entry );
+        reloadWikipedia();
+        return;
     }
-    
+
+    debug() << "Even better";
+
     //remove the new-lines and tabs(replace with spaces IS needed).
     m_wiki.replace( "\n", " " );
     m_wiki.replace( "\t", " " );
-    
+
     m_wikiLanguages.clear();
     // Get the available language list
     if ( m_wiki.indexOf("<div id=\"p-lang\" class=\"portlet\">") != -1 )
@@ -159,7 +217,7 @@ void WikipediaEngine::wikiResult( KJob* job )
         m_wikiLanguages = m_wikiLanguages.mid( m_wikiLanguages.indexOf("<ul>") );
         m_wikiLanguages = m_wikiLanguages.mid( 0, m_wikiLanguages.indexOf( "</div>" ) );
     }
-    
+
     QString copyright;
     QString copyrightMark = "<li id=\"f-copyright\">";
     if ( m_wiki.indexOf( copyrightMark ) != -1 )
@@ -170,7 +228,7 @@ void WikipediaEngine::wikiResult( KJob* job )
         //only one br at the beginning
         copyright.prepend( "<br />" );
     }
-    
+
     // Ok lets remove the top and bottom parts of the page
     m_wiki = m_wiki.mid( m_wiki.indexOf( "<h1 class=\"firstHeading\">" ) );
     m_wiki = m_wiki.mid( 0, m_wiki.indexOf( "<div class=\"printfooter\">" ) );
@@ -178,19 +236,19 @@ void WikipediaEngine::wikiResult( KJob* job )
     m_wiki += copyright;
     m_wiki.append( "</div>" );
     m_wiki.replace( QRegExp("<h3 id=\"siteSub\">[^<]*</h3>"), QString() );
-    
+
     m_wiki.replace( QRegExp( "<span class=\"editsection\"[^>]*>[^<]*<[^>]*>[^<]*<[^>]*>[^<]*</span>" ), QString() );
-    
+
     m_wiki.replace( QRegExp( "<a href=\"[^\"]*\" class=\"new\"[^>]*>([^<]*)</a>" ), "\\1" );
-    
+
     // Remove anything inside of a class called urlexpansion, as it's pointless for us
     m_wiki.replace( QRegExp( "<span class= *'urlexpansion'>[^(]*[(][^)]*[)]</span>" ), QString() );
-    
+
     // Remove hidden table rows as well
     QRegExp hidden( "<tr *class= *[\"\']hiddenStructure[\"\']>.*</tr>", Qt::CaseInsensitive );
     hidden.setMinimal( true ); //greedy behaviour wouldn't be any good!
     m_wiki.replace( hidden, QString() );
-    
+
     // we want to keep our own style (we need to modify the stylesheet a bit to handle things nicely)
     m_wiki.replace( QRegExp( "style= *\"[^\"]*\"" ), QString() );
     m_wiki.replace( QRegExp( "class= *\"[^\"]*\"" ), QString() );
@@ -202,37 +260,60 @@ void WikipediaEngine::wikiResult( KJob* job )
     m_wiki.replace( "</option>\n" , QString() );
     m_wiki.replace( QRegExp( "<textarea[^>]*>" ), QString() );
     m_wiki.replace( "</textarea>" , QString() );
-    
+
     //first we convert all the links with protocol to external, as they should all be External Links.
     m_wiki.replace( QRegExp( "href= *\"http:" ), "href=\"externalurl:" );
     //m_wiki.replace( QRegExp( "href= *\"/" ), "href=\"" +m_wikiBaseUrl );
     m_wiki.replace( QRegExp( "href= *\"#" ), "href=\"" +m_wikiCurrentUrl + '#' );
-    
+
     QString m_wikiHTMLSource = "<html><body>\n";
     m_wikiHTMLSource.append( m_wiki );
     if ( !m_wikiLanguages.isEmpty() )
     {
-        m_wikiHTMLSource.append( i18n( "Wikipedia Other Languages: <br>" )+ m_wikiLanguages );
+        m_wikiHTMLSource.append( i18n( "Wikipedia Other Languages: <br/>" )+ m_wikiLanguages );
     }
     m_wikiHTMLSource.append( "</body></html>\n" );
-    
-    clearData( "wikipedia" );
-//     debug() << "sending wiki page:" << m_wikiHTMLSource;
-    setData( "wikipedia", selection(), m_wikiHTMLSource );
-    
+
+    //debug() << "wikidata: " << m_wikiHTMLSource;
+
+    removeAllData( "wikipedia" );
+    setData( "wikipedia", "page", m_wikiHTMLSource );
+
+    Meta::TrackPtr currentTrack = The::engineController()->currentTrack();
+    if( selection() == "artist" ) // default, or applet told us to fetch artist
+    {
+        if( currentTrack->artist() )
+        {
+            setData( "wikipedia", "label", "Artist" );
+            setData( "wikipedia", "title", currentTrack->artist()->prettyName() );
+        }
+    }
+    else if( selection() == "title" )
+    {
+        setData( "wikipedia", "label", "Title" );
+        setData( "wikipedia", "title", currentTrack->prettyName() );
+    }
+    else if( selection() == "album" )
+    {
+        if( currentTrack->album() )
+        {
+            setData( "wikipedia", "label", "Album" );
+            setData( "wikipedia", "title", currentTrack->album()->prettyName() );
+        }
+    }
+
     m_wikiJob = 0;
 }
 
 QString
-WikipediaEngine::wikiLocale()
+WikipediaEngine::wikiLocale() const
 {
     if( m_wikiLocale.isEmpty() )
         return QString( "en" );
-    
+
     return m_wikiLocale;
 }
 
-
 QString
 WikipediaEngine::wikiArtistPostfix()
 {
@@ -249,8 +330,8 @@ WikipediaEngine::wikiAlbumPostfix()
 {
     if( wikiLocale() == "en" )
         return " (album)";
-    else
-        return "";
+
+    return QString();
 }
 
 QString
@@ -258,22 +339,32 @@ WikipediaEngine::wikiTrackPostfix()
 {
     if( wikiLocale() == "en" )
         return " (song)";
-    else
-        return "";
+
+    return QString();
 }
 
 QString
-WikipediaEngine::wikiURL( const QString &item )
+WikipediaEngine::wikiUrl( const QString &item ) const
 {
-    return QString( "http://%1.wikipedia.org/wiki/" ).arg( wikiLocale() )
-        + KUrl::toPercentEncoding( item, "/" );
+    /*return QString( "http://www.google.com/search?q=site:%1.wikipedia.org " )
+            .arg( wikiLocale() )
+            + KUrl::toPercentEncoding( item, "/" )
+            + "&btnI=Lucky";*/
+
+
+    return QString( "http://%1.wikipedia.org/wiki/" ).arg( wikiLocale() ) + KUrl::toPercentEncoding( item, "/" );
 }
 
 void
 WikipediaEngine::reloadWikipedia()
 {
-    m_wikiJob = NULL;
-//     showWikipediaEntry( m_wikiCurrentEntry, true );
+    DEBUG_BLOCK
+        
+    debug() << "wiki url: " << m_wikiCurrentUrl;
+
+    setData( "wikipedia", "message", i18n( "Fetching content.." ) );
+    m_wikiJob = KIO::storedGet( m_wikiCurrentUrl, KIO::NoReload, KIO::HideProgressInfo );
+    connect( m_wikiJob, SIGNAL( result( KJob* ) ), SLOT( wikiResult( KJob* ) ) );
 }
 
 #include "WikipediaEngine.moc"
