@@ -38,6 +38,7 @@
 #include "applet_p.h"
 #include "containment.h"
 #include "corona.h"
+#include "paintutils.h"
 #include "theme.h"
 #include "view.h"
 
@@ -46,7 +47,7 @@ namespace Plasma
 
 qreal _k_angleForPoints(const QPointF &center, const QPointF &pt1, const QPointF &pt2);
 
-AppletHandle::AppletHandle(Containment *parent, Applet *applet)
+AppletHandle::AppletHandle(Containment *parent, Applet *applet, const QPointF &hoverPos)
     : QObject(),
       QGraphicsItem(parent),
       m_pressedButton(NoButton),
@@ -61,12 +62,15 @@ AppletHandle::AppletHandle(Containment *parent, Applet *applet)
       m_scaleHeight(1.0),
       m_buttonsOnRight(false),
       m_pendingFade(false),
-      m_topview(0)
+      m_topview(0),
+      m_entryPos(hoverPos)
 {
     KColorScheme colorScheme(QPalette::Active, KColorScheme::View, Theme::defaultTheme()->colorScheme());
     m_gradientColor = colorScheme.background(KColorScheme::NormalBackground).color();
 
     QTransform originalMatrix = m_applet->transform();
+    m_applet->resetTransform();
+
     QRectF rect(m_applet->contentsRect());
     QPointF center = rect.center();
     originalMatrix.translate(center.x(), center.y());
@@ -78,9 +82,6 @@ AppletHandle::AppletHandle(Containment *parent, Applet *applet)
                                 QPointF(1, 0),
                                 QPointF(cosine, sine));
 
-    m_applet->resetTransform();
-
-    calculateSize();
     m_applet->setParentItem(this);
 
     rect = QRectF(m_applet->pos(), m_applet->size());
@@ -90,13 +91,14 @@ AppletHandle::AppletHandle(Containment *parent, Applet *applet)
     matrix.rotateRadians(m_angle);
     matrix.translate(-center.x(), -center.y());
     setTransform(matrix);
+
     m_hoverTimer = new QTimer(this);
     m_hoverTimer->setSingleShot(true);
     m_hoverTimer->setInterval(333);
 
     m_leaveTimer = new QTimer(this);
     m_leaveTimer->setSingleShot(true);
-    m_leaveTimer->setInterval(333);
+    m_leaveTimer->setInterval(500);
 
     connect(m_hoverTimer, SIGNAL(timeout()), this, SLOT(fadeIn()));
     connect(m_leaveTimer, SIGNAL(timeout()), this, SLOT(leaveTimeout()));
@@ -150,7 +152,43 @@ Applet *AppletHandle::applet() const
 
 QRectF Plasma::AppletHandle::boundingRect() const
 {
-    return m_rect;
+    return m_totalRect;
+}
+
+QPainterPath AppletHandle::shape() const
+{
+    //when the containment changes the applet is resetted to 0
+    if (m_applet) {
+        QPainterPath path = PaintUtils::roundedRectangle(m_rect, 10);
+        return path.united(m_applet->mapToParent(m_applet->shape()));
+    } else {
+        return QGraphicsItem::shape();
+    }
+}
+
+QPainterPath handleRect(const QRectF &rect, int radius, bool onRight)
+{
+    QPainterPath path;
+    if (onRight) {
+        // make the left side straight
+        path.moveTo(rect.left(), rect.top());                                            // Top left
+        path.lineTo(rect.right() - radius, rect.top());                                 // Top side
+        path.quadTo(rect.right(), rect.top(), rect.right(), rect.top() + radius);       // Top right corner
+        path.lineTo(rect.right(), rect.bottom() - radius);                              // Right side
+        path.quadTo(rect.right(), rect.bottom(), rect.right() - radius, rect.bottom()); // Bottom right corner
+        path.lineTo(rect.left(), rect.bottom());                                        // Bottom side
+    } else {
+        // make the right side straight
+        path.moveTo(QPointF(rect.left(), rect.top() + radius));
+        path.quadTo(rect.left(), rect.top(), rect.left() + radius, rect.top());         // Top left corner
+        path.lineTo(rect.right(), rect.top());                                          // Top side
+        path.lineTo(rect.right(), rect.bottom());                                       // Right side
+        path.lineTo(rect.left() + radius, rect.bottom());                               // Bottom side
+        path.quadTo(rect.left(), rect.bottom(), rect.left(), rect.bottom() - radius);   // Bottom left corner
+    }
+
+    path.closeSubpath();
+    return path;
 }
 
 void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget)
@@ -162,35 +200,37 @@ void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
     painter->setOpacity(m_opacity);
 
     painter->save();
-    painter->setOpacity(m_opacity * 0.4);
+    painter->setOpacity(m_opacity * 0.8);
     painter->setPen(Qt::NoPen);
     painter->setRenderHints(QPainter::Antialiasing);
-    QLinearGradient gr(boundingRect().topLeft(), boundingRect().bottomRight());
-    gr.setColorAt(0, m_gradientColor);
-    gr.setColorAt(0.1, KColorScheme::shade(m_gradientColor, KColorScheme::LightShade));
-    gr.setColorAt(1, KColorScheme::shade(m_gradientColor, KColorScheme::DarkShade));
-    painter->setBrush(gr);
-    QPainterPath path = Plasma::roundedRectangle(boundingRect(), 10);
 
-    if (m_applet) {
-        QPainterPath shape = m_applet->shape();
+    QPainterPath path = handleRect(m_rect, 10, m_buttonsOnRight);
+    painter->strokePath(path, m_gradientColor);
 
-        if (!shape.isEmpty()) {
-            path = path.subtracted(m_applet->mapToParent(m_applet->shape()));
-        }
+    int minHeight = minimumHeight();
+    qreal h = m_rect.height();
+    if (h > minHeight * 1.25) {
+        QLinearGradient g(m_rect.topLeft(), m_rect.bottomLeft());
+        // where the top icons stop
+        qreal firstStop = (ICON_SIZE + ICON_MARGIN) * 3 + ICON_MARGIN * 2;
+        // now between that and where the close icon is
+        firstStop = firstStop + (((h - (ICON_SIZE + ICON_MARGIN * 2)) - firstStop) * 0.7);
+        // now the ratio of the height
+        firstStop /= h;
+
+        g.setColorAt(0.0, m_gradientColor.lighter());
+        g.setColorAt(firstStop, Qt::transparent);
+        g.setColorAt(1.0, m_gradientColor.lighter());
+        painter->fillPath(path, g);
+    } else {
+        painter->fillPath(path, m_gradientColor.lighter());
     }
-
-    painter->drawPath(path);
     painter->restore();
 
     //XXX this code is duplicated in the next function
-    QPointF basePoint = m_rect.topLeft() + QPointF(HANDLE_WIDTH / 2, HANDLE_WIDTH);
+    QPointF basePoint = m_rect.topLeft() + QPointF((HANDLE_WIDTH - ICON_SIZE) / 2, ICON_MARGIN);
     QPointF step = QPointF(0, ICON_SIZE + ICON_MARGIN);
     QPointF separator = step + QPointF(0, ICON_MARGIN);
-
-    if (m_buttonsOnRight) {
-        basePoint += QPointF(m_rect.width() - ICON_SIZE - HANDLE_WIDTH, 0);
-    }
     //end duplicate code
 
     QPointF shiftC;
@@ -216,7 +256,7 @@ void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
         break;
     }
 
-    painter->drawPixmap(basePoint + shiftM, KIcon("transform-move").pixmap(ICON_SIZE, ICON_SIZE)); //FIXME no transform-resize icon
+    painter->drawPixmap(basePoint + shiftM, KIcon("transform-scale").pixmap(ICON_SIZE, ICON_SIZE)); //FIXME no transform-resize icon
 
     basePoint += step;
     painter->drawPixmap(basePoint + shiftR, KIcon("transform-rotate").pixmap(ICON_SIZE, ICON_SIZE));
@@ -226,7 +266,7 @@ void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
         painter->drawPixmap(basePoint + shiftC, KIcon("configure").pixmap(ICON_SIZE, ICON_SIZE));
     }
 
-    basePoint += separator;
+    basePoint = m_rect.bottomLeft() + QPointF((HANDLE_WIDTH - ICON_SIZE) / 2, 0) - step;
     painter->drawPixmap(basePoint + shiftD, KIcon("edit-delete").pixmap(ICON_SIZE, ICON_SIZE));
 
     painter->restore();
@@ -235,35 +275,31 @@ void AppletHandle::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
 AppletHandle::ButtonType AppletHandle::mapToButton(const QPointF &point) const
 {
     //XXX this code is duplicated in the prev. function
-    QPointF basePoint = m_rect.topLeft() + QPointF(HANDLE_WIDTH / 2, HANDLE_WIDTH);
+    QPointF basePoint = m_rect.topLeft() + QPointF((HANDLE_WIDTH - ICON_SIZE) / 2, ICON_MARGIN);
     QPointF step = QPointF(0, ICON_SIZE + ICON_MARGIN);
     QPointF separator = step + QPointF(0, ICON_MARGIN);
+   //end duplicate code
 
-    if (m_buttonsOnRight) {
-        basePoint += QPointF(m_rect.width() - ICON_SIZE - HANDLE_WIDTH, 0);
-    }
-    //end duplicate code
+    QRectF activeArea = QRectF(basePoint, QSizeF(ICON_SIZE, ICON_SIZE));
 
-    QPolygonF activeArea = QPolygonF(QRectF(basePoint, QSizeF(ICON_SIZE, ICON_SIZE)));
-
-    if (activeArea.containsPoint(point, Qt::OddEvenFill)) {
+    if (activeArea.contains(point)) {
         return ResizeButton;
     }
 
     activeArea.translate(step);
-    if (activeArea.containsPoint(point, Qt::OddEvenFill)) {
+    if (activeArea.contains(point)) {
         return RotateButton;
     }
 
     if (m_applet && m_applet->hasConfigurationInterface()) {
         activeArea.translate(step);
-        if (activeArea.containsPoint(point, Qt::OddEvenFill)) {
+        if (activeArea.contains(point)) {
             return ConfigureButton;
         }
     }
 
-    activeArea.translate(separator);
-    if (activeArea.containsPoint(point, Qt::OddEvenFill)) {
+    activeArea.moveTop(m_rect.bottom() - activeArea.height() - ICON_MARGIN);
+    if (activeArea.contains(point)) {
         return RemoveButton;
     }
 
@@ -274,6 +310,12 @@ AppletHandle::ButtonType AppletHandle::mapToButton(const QPointF &point) const
 
 void AppletHandle::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
+    //containment recently switched?
+    if (!m_applet) {
+        QGraphicsItem::mousePressEvent(event);
+        return;
+    }
+
     if (m_pendingFade) {
         //m_pendingFade = false;
         return;
@@ -284,7 +326,12 @@ void AppletHandle::mousePressEvent(QGraphicsSceneMouseEvent *event)
         //kDebug() << "button pressed:" << m_pressedButton;
         if (m_pressedButton != NoButton) {
             m_applet->raise();
-            setZValue(m_applet->zValue());
+            m_zValue = m_applet->zValue();
+            setZValue(m_zValue);
+        }
+
+        if (m_pressedButton == MoveButton) {
+            m_pos = pos();
         }
         event->accept();
 
@@ -324,7 +371,7 @@ void AppletHandle::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
     //kDebug() << "button pressed:" << m_pressedButton << ", fade pending?" << m_pendingFade;
 
     if (m_pendingFade) {
-        startFading(FadeOut);
+        startFading(FadeOut, m_entryPos);
         m_pendingFade = false;
     }
 
@@ -382,6 +429,7 @@ void AppletHandle::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 
                 //find out if we were dropped on a panel or something
                 if (leaveCurrentView(event->screenPos())) {
+                    startFading(FadeOut, m_entryPos);
                     Plasma::View *v = Plasma::View::topLevelViewAt(event->screenPos());
                     if (v && v != m_containment->view()) {
                         Containment *c = v->containment();
@@ -393,7 +441,7 @@ void AppletHandle::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
                     }
                 } else {
                     // test for containment change
-                    kDebug() << "testing for containment change, sceneBoundingRect = " << m_containment->sceneBoundingRect();
+                    //kDebug() << "testing for containment change, sceneBoundingRect = " << m_containment->sceneBoundingRect();
                     if (!m_containment->sceneBoundingRect().contains(m_applet->scenePos())) {
                         // see which containment it belongs to
                         Corona * corona = qobject_cast<Corona*>(scene());
@@ -408,9 +456,9 @@ void AppletHandle::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 
                                     if (containments[i]->sceneBoundingRect().contains(pos)) {
                                         //kDebug() << "new containment = " << containments[i];
-                                        kDebug() << "rect = " << containments[i]->sceneBoundingRect();
+                                        //kDebug() << "rect = " << containments[i]->sceneBoundingRect();
                                         // add the applet to the new containment and take it from the old one
-                                        kDebug() << "moving to other containment with position" << pos;;
+                                        //kDebug() << "moving to other containment with position" << pos;;
                                         switchContainment(containments[i], pos);
                                         break;
                                     }
@@ -481,7 +529,7 @@ void AppletHandle::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
             QRect screenRect = QRect(event->screenPos() - m_mousePos,
                                      m_applet->screenRect().size());
 
-            kDebug() << "screenRect = " << screenRect;
+            //kDebug() << "screenRect = " << screenRect;
 
             if (!m_topview) { //create a new toplevel view
                 m_topview = new View(m_containment, -1, 0);
@@ -667,10 +715,15 @@ void AppletHandle::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
     m_hoverTimer->start();
 }
 
+void AppletHandle::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
+{
+    Q_UNUSED(event);
+    m_leaveTimer->stop();
+}
+
 void AppletHandle::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
 {
     Q_UNUSED(event);
-    //kDebug() << "hover leave" << m_pressedButton;
     m_hoverTimer->stop();
 
     if (m_pressedButton != NoButton) {
@@ -693,13 +746,9 @@ bool AppletHandle::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
 
 void AppletHandle::fadeAnimation(qreal progress)
 {
-    qreal endOpacity = 1.0;
-    if (m_anim == FadeOut) {
-        endOpacity = 0.0;
-    }
-
+    qreal endOpacity = (m_anim == FadeIn) ? 1.0 : 0.0;
     m_opacity += (endOpacity - m_opacity) * progress;
-
+    //kDebug() << "progress" << progress << "m_opacity" << m_opacity << endOpacity;
     if (progress >= 1.0 && m_anim == FadeOut) {
         emit disappearDone(this);
     }
@@ -709,12 +758,12 @@ void AppletHandle::fadeAnimation(qreal progress)
 
 void AppletHandle::fadeIn()
 {
-    startFading(FadeIn);
+    startFading(FadeIn, m_entryPos);
 }
 
 void AppletHandle::leaveTimeout()
 {
-    startFading(FadeOut);
+    startFading(FadeOut, m_entryPos);
 }
 
 void AppletHandle::appletDestroyed()
@@ -730,65 +779,107 @@ void AppletHandle::appletResized()
     update();
 }
 
-void AppletHandle::startFading(FadeType anim)
+void AppletHandle::startFading(FadeType anim, const QPointF &hoverPos)
 {
     if (m_animId != 0) {
         Animator::self()->stopCustomAnimation(m_animId);
     }
 
-    m_anim = anim;
+    m_hoverTimer->stop();
+    m_leaveTimer->stop();
+
+    m_entryPos = hoverPos;
     qreal time = 250;
 
-    if (anim == FadeOut && m_hoverTimer->isActive()) {
+    if (!m_applet || (anim == FadeOut && m_hoverTimer->isActive())) {
         // fading out before we've started fading in
-        m_hoverTimer->stop();
         fadeAnimation(1.0);
         return;
     }
 
     if (anim == FadeIn) {
+        //kDebug() << m_entryPos.x() << m_applet->pos().x();
+        prepareGeometryChange();
+        bool wasOnRight = m_buttonsOnRight;
+        m_buttonsOnRight = m_entryPos.x() > (m_applet->size().width() / 2);
+        calculateSize();
+        QPolygonF region = mapToParent(m_rect).intersected(parentWidget()->boundingRect());
+        //kDebug() << region << m_rect << mapToParent(m_rect) << parentWidget()->boundingRect();
+        if (region != mapToParent(m_rect)) {
+            // switch sides
+            //kDebug() << "switch sides";
+            m_buttonsOnRight = !m_buttonsOnRight;
+            calculateSize();
+            QPolygonF region2 = mapToParent(m_rect).intersected(parentWidget()->boundingRect());
+            if (region2 != mapToParent(m_rect)) {
+                // ok, both sides failed to be perfect... which one is more perfect?
+                QRectF f1 = region.boundingRect();
+                QRectF f2 = region2.boundingRect();
+                //kDebug() << "still not a perfect world" << f2.width() << f2.height() << f1.width() << f1.height();
+                if ((f2.width() * f2.height()) < (f1.width() * f1.height())) {
+                    //kDebug() << "we did better the first time";
+                    m_buttonsOnRight = !m_buttonsOnRight;
+                    calculateSize();
+                }
+            }
+        }
+
+        if (wasOnRight != m_buttonsOnRight && m_anim == FadeIn && anim == FadeIn && m_opacity <= 1) {
+            m_opacity = 0.0;
+        }
+
         time *= 1.0 - m_opacity;
     } else {
         time *= m_opacity;
     }
 
+    m_anim = anim;
     m_animId = Animator::self()->customAnimation(40, (int)time, Animator::EaseInOutCurve, this, "fadeAnimation");
 }
 
-
 void AppletHandle::forceDisappear()
 {
     setAcceptsHoverEvents(false);
-    startFading(FadeOut);
+    startFading(FadeOut, m_entryPos);
+}
+
+int AppletHandle::minimumHeight()
+{
+    int requiredHeight =  ICON_MARGIN + //first margin
+                          (ICON_SIZE + ICON_MARGIN) * 4 + //XXX remember to update this if the number of buttons changes
+                          ICON_MARGIN;  //blank space before the close button
+
+    if (m_applet && m_applet->hasConfigurationInterface()) {
+        requiredHeight += (ICON_SIZE + ICON_MARGIN);
+    }
+
+    return requiredHeight;
 }
 
 void AppletHandle::calculateSize()
 {
-    m_rect = m_applet->boundingRect();
-    m_rect = m_applet->mapToParent(m_rect).boundingRect();
+    int handleHeight = minimumHeight();
+    int top = m_applet->contentsRect().top();
 
-    //XXX remember to update this if the number of buttons changes
-    const int requiredHeight = (HANDLE_WIDTH * 2) + m_applet->hasConfigurationInterface() ?
-                                                        ((ICON_SIZE + ICON_MARGIN) * 4) :
-                                                        ((ICON_SIZE + ICON_MARGIN) * 3) +
-                               ICON_MARGIN; // that last margin is blank space before the close button
-    if (m_rect.height() < requiredHeight) {
-        float deltaScene = requiredHeight - m_rect.height();
-        deltaScene = deltaScene/2.0;
-        if (deltaScene > 0.0) {
-            m_rect.adjust(0.0, -deltaScene, 0.0, deltaScene);
-        }
-    }
-
-    m_rect.adjust(-HANDLE_WIDTH, -HANDLE_WIDTH, HANDLE_WIDTH, HANDLE_WIDTH);
-    if (m_applet->pos().x() <= ((HANDLE_WIDTH * 2) + ICON_SIZE)) {
-        m_rect.adjust(0.0, 0.0, ICON_SIZE, 0.0);
-        m_buttonsOnRight = true;
+    if (handleHeight > m_applet->contentsRect().height()) {
+        //center the handle if it is higher than the applet
+        top += (m_applet->contentsRect().height() - handleHeight) / 2.0;
     } else {
-        m_rect.adjust(- ICON_SIZE, 0.0, 0.0, 0.0);
+        handleHeight = m_applet->contentsRect().height();
     }
+
+    if (m_buttonsOnRight) {
+        //put the rect on the right of the applet
+        m_rect = QRectF(m_applet->size().width(), top, HANDLE_WIDTH, handleHeight);
+    } else {
+        //put the rect on the left of the applet
+        m_rect = QRectF(-HANDLE_WIDTH, top, HANDLE_WIDTH, handleHeight);
+    }
+
+    m_rect = m_applet->mapToParent(m_rect).boundingRect();
+    m_totalRect = m_rect.united(m_applet->geometry());
 }
 
-}
+} // Plasma Namespace
 
 #include "applethandle_p.moc"
