@@ -40,20 +40,22 @@ class AppletHandle : public QObject, public QGraphicsItem
         enum FadeType { FadeIn, FadeOut };
         enum ButtonType { NoButton, MoveButton, RotateButton, ConfigureButton, RemoveButton, ResizeButton };
 
-        AppletHandle(Containment *parent, Applet *applet);
+        AppletHandle(Containment *parent, Applet *applet, const QPointF &hoverPos);
         virtual ~AppletHandle();
 
         Applet *applet() const;
 
         QRectF boundingRect() const;
+        QPainterPath shape() const;
         void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget = 0);
-        void startFading(FadeType anim);
+        void startFading(FadeType anim, const QPointF &hoverPos);
 
     protected:
         void mousePressEvent(QGraphicsSceneMouseEvent *event);
         void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
         void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
         void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
+        void hoverMoveEvent(QGraphicsSceneHoverEvent *event);
         void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
         QVariant itemChange(GraphicsItemChange change, const QVariant &value);
         bool sceneEventFilter(QGraphicsItem *watched, QEvent *event);
@@ -69,13 +71,15 @@ class AppletHandle : public QObject, public QGraphicsItem
         void leaveTimeout();
 
     private:
-        static const int HANDLE_WIDTH = 5;
+        static const int HANDLE_WIDTH = 22;
         static const int ICON_SIZE = 16;
         static const int ICON_MARGIN = 8;
 
         void calculateSize();
         ButtonType mapToButton(const QPointF &point) const;
         void forceDisappear();
+        int minimumHeight();
+
         /**
          * move our applet to another containment
          * @param containment the containment to move to
@@ -85,6 +89,7 @@ class AppletHandle : public QObject, public QGraphicsItem
         bool leaveCurrentView(const QPoint &pos) const;
 
         QRectF m_rect;
+        QRectF m_totalRect;
         ButtonType m_pressedButton;
         Containment *m_containment;
         Applet *m_applet;
@@ -103,6 +108,7 @@ class AppletHandle : public QObject, public QGraphicsItem
         View *m_topview;
 
         QPoint m_mousePos;  //mousepos relative to applet
+        QPointF m_entryPos; //where the hover in event occurred
         QPointF m_pos;      //current position of applet in sceneCoords
         qreal m_zValue;     //current zValue of the applet, so it can be restored after drag.
 };
