@@ -59,26 +59,31 @@ Containment::StyleOption::StyleOption()
     : QStyleOptionGraphicsItem(),
       view(0)
 {
-
+    version = Version;
+    type = Type;
 }
 
 Containment::StyleOption::StyleOption(const Containment::StyleOption & other)
     : QStyleOptionGraphicsItem(other),
       view(other.view)
 {
+    version = Version;
+    type = Type;
 }
 
 Containment::StyleOption::StyleOption(const QStyleOptionGraphicsItem &other)
     : QStyleOptionGraphicsItem(other),
       view(0)
 {
+    version = Version;
+    type = Type;
 }
 
 Containment::Containment(QGraphicsItem* parent,
                          const QString& serviceId,
                          uint containmentId)
     : Applet(parent, serviceId, containmentId),
-      d(new Private(this))
+      d(new ContainmentPrivate(this))
 {
     // WARNING: do not access config() OR globalConfig() in this method!
     //          that requires a scene, which is not available at this point
@@ -89,7 +94,7 @@ Containment::Containment(QGraphicsItem* parent,
 
 Containment::Containment(QObject* parent, const QVariantList& args)
     : Applet(parent, args),
-      d(new Private(this))
+      d(new ContainmentPrivate(this))
 {
     // WARNING: do not access config() OR globalConfig() in this method!
     //          that requires a scene, which is not available at this point
@@ -157,7 +162,8 @@ void Containment::init()
         d->actions().addAction("lock widgets", lockDesktopAction);
     }
 
-    if (d->type != PanelContainment) {
+    if (d->type != PanelContainment &&
+        d->type != CustomPanelContainment) {
         QAction *zoomAction = new QAction(i18n("Zoom In"), this);
         zoomAction->setIcon(KIcon("zoom-in"));
         connect(zoomAction, SIGNAL(triggered(bool)), this, SLOT(zoomIn()));
@@ -183,7 +189,7 @@ void Containment::init()
         connect(activityAction, SIGNAL(triggered(bool)), this, SLOT(addSiblingContainment()));
         activityAction->setShortcutContext(Qt::WidgetWithChildrenShortcut);
         activityAction->setShortcut(QKeySequence("ctrl+shift+a"));
-        d->actions().addAction("addSiblingContainment", activityAction);
+        d->actions().addAction("add sibling containment", activityAction);
 
         if (d->type == DesktopContainment) {
             d->toolBox->addTool(this->action("add widgets"));
@@ -192,7 +198,7 @@ void Containment::init()
             if (immutability() != SystemImmutable) {
                 d->toolBox->addTool(this->action("lock widgets"));
             }
-            d->toolBox->addTool(this->action("addSiblingContainment"));
+            d->toolBox->addTool(this->action("add sibling containment"));
         }
     }
 
@@ -244,8 +250,13 @@ void Containment::restore(KConfigGroup &group)
     setImmutability((ImmutabilityType)group.readEntry("immutability", (int)Mutable));
 }
 
-void Containment::save(KConfigGroup &group) const
+void Containment::save(KConfigGroup &g) const
 {
+    KConfigGroup group = g;
+    if (!group.isValid()) {
+        group = config();
+    }
+
     // locking is saved in Applet::save
     Applet::save(group);
     group.writeEntry("screen", d->screen);
@@ -298,21 +309,20 @@ Containment::Type Containment::containmentType() const
 
 void Containment::setContainmentType(Containment::Type type)
 {
+    if (d->type == type) {
+        return;
+    }
+
+    delete d->toolBox;
+    d->toolBox = 0;
     d->type = type;
 
-    if (isContainment() && type == DesktopContainment) {
-        if (!d->toolBox) {
-            d->createToolBox();
-        }
-    } else if (isContainment() && type == PanelContainment) {
-        if (!d->toolBox) {
-            d->createToolBox();
-            d->toolBox->setSize(22);
-            d->toolBox->setIconSize(QSize(16, 16));
-        }
-    } else {
-        delete d->toolBox;
-        d->toolBox = 0;
+    if (!isContainment()) {
+        return;
+    }
+
+    if ((type == DesktopContainment || type == PanelContainment)) {
+        d->createToolBox();
     }
 }
 
@@ -448,10 +458,12 @@ void Containment::setFormFactor(FormFactor formFactor)
 
     //kDebug() << "switching FF to " << formFactor;
     FormFactor was = d->formFactor;
-
     d->formFactor = formFactor;
 
-    if (isContainment() && containmentType() == PanelContainment && was != formFactor) {
+    if (isContainment() &&
+        was != formFactor &&
+        (d->type == PanelContainment ||
+         d->type == CustomPanelContainment)) {
         // we are a panel and we have chaged our orientation
         d->positionPanel(true);
     }
@@ -526,6 +538,10 @@ void Containment::addApplet(Applet *applet, const QPointF &pos, bool delayInit)
         return;
     }
 
+    if (d->applets.contains(applet)) {
+        kDebug() << "already have this applet!";
+    }
+
     Containment *currentContainment = applet->containment();
 
     if (containmentType() == PanelContainment) {
@@ -553,6 +569,8 @@ void Containment::addApplet(Applet *applet, const QPointF &pos, bool delayInit)
 
     d->applets << applet;
 
+    connect(applet, SIGNAL(configNeedsSaving()), this, SIGNAL(configNeedsSaving()));
+    connect(applet, SIGNAL(releaseVisualFocus()), this, SIGNAL(releaseVisualFocus()));
     connect(applet, SIGNAL(destroyed(QObject*)), this, SLOT(appletDestroyed(QObject*)));
 
     if (pos != QPointF(-1, -1)) {
@@ -572,7 +590,6 @@ void Containment::addApplet(Applet *applet, const QPointF &pos, bool delayInit)
     applet->updateConstraints(Plasma::AllConstraints | Plasma::StartupCompletedConstraint);
     if (!delayInit) {
         applet->flushPendingConstraintsEvents();
-        emit configNeedsSaving();
     }
 
     emit appletAdded(applet, pos);
@@ -586,7 +603,7 @@ Applet::List Containment::applets() const
 void Containment::setScreen(int screen)
 {
     // screen of -1 means no associated screen.
-    if (containmentType() == DesktopContainment || containmentType() >= CustomContainment) {
+    if (d->type == DesktopContainment || d->type == CustomContainment) {
 #ifndef Q_OS_WIN
         // we want to listen to changes in work area if our screen changes
         if (d->screen < 0 && screen > -1) {
@@ -640,7 +657,8 @@ QPoint Containment::effectiveScreenPos() const
     }
 
     QRect r = QApplication::desktop()->screenGeometry(d->screen);
-    if (containmentType() == PanelContainment) {
+    if (containmentType() == PanelContainment ||
+        containmentType() == CustomPanelContainment) {
         QRectF p = geometry();
 
         switch (d->location) {
@@ -822,13 +840,14 @@ bool Containment::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
     case QEvent::GraphicsSceneHoverEnter:
         //kDebug() << "got hoverenterEvent" << immutability() << " " << applet->immutability();
         if (immutability() == Mutable && applet->immutability() == Mutable) {
+            QGraphicsSceneHoverEvent *he = static_cast<QGraphicsSceneHoverEvent*>(event);
             if (d->handles.contains(applet)) {
-                d->handles[applet]->startFading(AppletHandle::FadeIn);
+                d->handles[applet]->startFading(AppletHandle::FadeIn, he->pos());
             } else {
                 //kDebug() << "generated applet handle";
                 //TODO: there should be a small delay on showing these. they pop up too quickly/easily
                 //      right now
-                AppletHandle *handle = new AppletHandle(this, applet);
+                AppletHandle *handle = new AppletHandle(this, applet, he->pos());
                 d->handles[applet] = handle;
                 connect(handle, SIGNAL(disappearDone(AppletHandle*)),
                         this, SLOT(handleDisappeared(AppletHandle*)));
@@ -842,7 +861,7 @@ bool Containment::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
         if (d->handles.contains(applet)) {
             QGraphicsSceneHoverEvent *he = static_cast<QGraphicsSceneHoverEvent *>(event);
             if (!d->handles[applet]->boundingRect().contains(d->handles[applet]->mapFromScene(he->scenePos()))) {
-                d->handles[applet]->startFading(AppletHandle::FadeOut);
+                d->handles[applet]->startFading(AppletHandle::FadeOut, he->pos());
             }
         }
     default:
@@ -861,6 +880,7 @@ QVariant Containment::itemChange(GraphicsItemChange change, const QVariant &valu
         !d->positioning) {
         switch (containmentType()) {
             case PanelContainment:
+            case CustomPanelContainment:
                 d->positionPanel();
                 break;
             default:
@@ -946,12 +966,12 @@ void Containment::removeAssociatedWidget(QWidget *widget)
     }
 }
 
-KActionCollection& Containment::Private::actions()
+KActionCollection& ContainmentPrivate::actions()
 {
     return static_cast<Applet*>(q)->d->actions;
 }
 
-void Containment::Private::focusApplet(Plasma::Applet *applet)
+void ContainmentPrivate::focusApplet(Plasma::Applet *applet)
 {
     if (focusedApplet == applet) {
         return;
@@ -1018,11 +1038,19 @@ void Containment::destroy()
     }
 
     if (isContainment()) {
+        //don't remove a desktop that's in use
+        //FIXME allow removal of containments for screens that don't currently exist
+        if (d->type != PanelContainment && d->type != CustomPanelContainment &&
+            (d->screen != -1 || d->screen >= QApplication::desktop()->numScreens())) {
+            kDebug() << (QObject*)this << "containment has a screen number?" << d->screen;
+            return;
+        }
+
         //FIXME maybe that %1 should be the containment type not the name
         if (KMessageBox::warningContinueCancel(view(), i18n("Do you really want to remove this %1?", name()),
                     i18n("Remove %1", name()), KStandardGuiItem::remove()) == KMessageBox::Continue ) {
-            clearApplets();
-            corona()->destroyContainment(this);
+            //clearApplets();
+            Applet::destroy();
         }
     } else {
         Applet::destroy();
@@ -1032,7 +1060,7 @@ void Containment::destroy()
 
 // Private class implementation
 
-void Containment::Private::toggleDesktopImmutability()
+void ContainmentPrivate::toggleDesktopImmutability()
 {
     if (q->corona()) {
         if (q->corona()->immutability() == Mutable) {
@@ -1051,49 +1079,52 @@ void Containment::Private::toggleDesktopImmutability()
     //setLockToolText();
 }
 
-void Containment::Private::zoomIn()
+void ContainmentPrivate::zoomIn()
 {
     emit q->zoomRequested(q, Plasma::ZoomIn);
 }
 
-void Containment::Private::zoomOut()
+void ContainmentPrivate::zoomOut()
 {
     emit q->zoomRequested(q, Plasma::ZoomOut);
 }
 
-ToolBox* Containment::Private::createToolBox()
+ToolBox* ContainmentPrivate::createToolBox()
 {
     if (!toolBox) {
         switch (type) {
-        case PanelContainment:
+        case Containment::PanelContainment:
             toolBox = new PanelToolBox(q);
-            connect(toolBox, SIGNAL(toggled()), q, SIGNAL(toolBoxToggled()));
+            toolBox->setSize(22);
+            toolBox->setIconSize(QSize(16, 16));
+            if (q->immutability() != Mutable) {
+                toolBox->hide();
+            }
             break;
-        //defaults to DesktopContainment right now
-        default:
+        case Containment::DesktopContainment:
             toolBox = new DesktopToolBox(q);
-            connect(toolBox, SIGNAL(toggled()), toolBox, SLOT(toggle()));
+            break;
+        default:
             break;
         }
 
-        positionToolBox();
-
-        if (type == PanelContainment && q->immutability() != Mutable) {
-            toolBox->hide();
+        if (toolBox) {
+            QObject::connect(toolBox, SIGNAL(toggled()), q, SIGNAL(toolBoxToggled()));
+            positionToolBox();
         }
     }
 
     return toolBox;
 }
 
-void Containment::Private::positionToolBox()
+void ContainmentPrivate::positionToolBox()
 {
     if (!toolBox) {
         return;
     }
 
     //The placement assumes that the geometry width/height is no more than the screen
-    if (type == PanelContainment) {
+    if (type == Containment::PanelContainment) {
         if (q->formFactor() == Vertical) {
             toolBox->setOrientation(Qt::Vertical);
             toolBox->setPos(q->geometry().width()/2 - toolBox->boundingRect().width()/2, q->geometry().height());
@@ -1117,18 +1148,18 @@ void Containment::Private::positionToolBox()
     }
 }
 
-void Containment::Private::triggerShowAddWidgets()
+void ContainmentPrivate::triggerShowAddWidgets()
 {
     emit q->showAddWidgetsInterface(QPointF());
 }
 
-void Containment::Private::handleDisappeared(AppletHandle *handle)
+void ContainmentPrivate::handleDisappeared(AppletHandle *handle)
 {
     handles.remove(handle->applet());
     handle->deleteLater();
 }
 
-void Containment::Private::containmentConstraintsEvent(Plasma::Constraints constraints)
+void ContainmentPrivate::containmentConstraintsEvent(Plasma::Constraints constraints)
 {
     if (!q->isContainment()) {
         return;
@@ -1146,7 +1177,7 @@ void Containment::Private::containmentConstraintsEvent(Plasma::Constraints const
             action->setEnabled(unlocked);
         }
         //FIXME immutability changes conflict with zoom changes
-        /*action = actions().action("addSiblingContainment");
+        /*action = actions().action("add sibling containment");
         if (action) {
             action->setVisible(unlocked);
             action->setEnabled(unlocked);
@@ -1162,7 +1193,7 @@ void Containment::Private::containmentConstraintsEvent(Plasma::Constraints const
             a->updateConstraints(ImmutableConstraint);
         }
 
-        if (q->isContainment() && type == PanelContainment) {
+        if (q->isContainment() && type == Containment::PanelContainment) {
             if (unlocked) {
                 toolBox->show();
             } else {
@@ -1193,7 +1224,8 @@ void Containment::Private::containmentConstraintsEvent(Plasma::Constraints const
 
     if (constraints & Plasma::SizeConstraint) {
         switch (q->containmentType()) {
-            case PanelContainment:
+            case Containment::PanelContainment:
+            case Containment::CustomPanelContainment:
                 positionPanel();
                 break;
             default:
@@ -1203,7 +1235,7 @@ void Containment::Private::containmentConstraintsEvent(Plasma::Constraints const
     }
 }
 
-Applet* Containment::Private::addApplet(const QString& name, const QVariantList& args,
+Applet* ContainmentPrivate::addApplet(const QString& name, const QVariantList& args,
                                         const QRectF& appletGeometry, uint id, bool delayInit)
 {
     if (!delayInit && q->immutability() != Mutable) {
@@ -1230,13 +1262,11 @@ Applet* Containment::Private::addApplet(const QString& name, const QVariantList&
 
     //kDebug() << applet->name() << "sizehint:" << applet->sizeHint() << "geometry:" << applet->geometry();
 
-    connect(applet, SIGNAL(configNeedsSaving()), q, SIGNAL(configNeedsSaving()));
-    connect(applet, SIGNAL(releaseVisualFocus()), q, SIGNAL(releaseVisualFocus()));
     q->addApplet(applet, appletGeometry.topLeft(), delayInit);
     return applet;
 }
 
-bool Containment::Private::regionIsEmpty(const QRectF &region, Applet *ignoredApplet) const
+bool ContainmentPrivate::regionIsEmpty(const QRectF &region, Applet *ignoredApplet) const
 {
     foreach (Applet *applet, applets) {
         if (applet != ignoredApplet && applet->geometry().intersects(region)) {
@@ -1246,7 +1276,7 @@ bool Containment::Private::regionIsEmpty(const QRectF &region, Applet *ignoredAp
     return true;
 }
 
-void Containment::Private::appletDestroyed(QObject* object)
+void ContainmentPrivate::appletDestroyed(QObject* object)
 {
     // we do a static_cast here since it really isn't an Applet by this
     // point anymore since we are in the qobject dtor. we don't actually
@@ -1261,21 +1291,24 @@ void Containment::Private::appletDestroyed(QObject* object)
     emit q->configNeedsSaving();
 }
 
-void Containment::Private::containmentAppletAnimationComplete(QGraphicsItem *item, Plasma::Animator::Animation anim)
+void ContainmentPrivate::containmentAppletAnimationComplete(QGraphicsItem *item, Plasma::Animator::Animation anim)
 {
     if (anim == Animator::AppearAnimation &&
-        q->containmentType() == DesktopContainment &&
+        q->containmentType() == Containment::DesktopContainment &&
         item->parentItem() == q) {
         Applet *applet = qgraphicsitem_cast<Applet*>(item);
 
         if (applet) {
             applet->installSceneEventFilter(q);
+            KConfigGroup *cg = applet->d->mainConfigGroup();
+            applet->save(*cg);
+            emit q->configNeedsSaving();
             //applet->setWindowFlags(Qt::Window);
         }
     }
 }
 
-void Containment::Private::positionContainment()
+void ContainmentPrivate::positionContainment()
 {
     Corona *c = q->corona();
     if (!c) {
@@ -1289,7 +1322,8 @@ void Containment::Private::positionContainment()
     while (it.hasNext()) {
         Containment *containment = it.next();
         if (containment == q ||
-            containment->containmentType() == PanelContainment) {
+            containment->containmentType() == Containment::PanelContainment ||
+            containment->containmentType() == Containment::CustomPanelContainment) {
             // weed out all containments we don't care about at all
             // e.g. Panels and ourself
             it.remove();
@@ -1380,7 +1414,7 @@ void Containment::Private::positionContainment()
     positioning = false;
 }
 
-void Containment::Private::positionPanel(bool force)
+void ContainmentPrivate::positionPanel(bool force)
 {
     if (!q->scene()) {
         kDebug() << "no scene yet";
@@ -1404,12 +1438,13 @@ void Containment::Private::positionPanel(bool force)
     qreal bottom = horiz ? 0 : VERTICAL_STACKING_OFFSET;
     qreal lastHeight = 0;
 
-    // this should be ok for small numbers of panels, but we ever end
+    // this should be ok for small numbers of panels, but if we ever end
     // up managing hundreds of them, this simplistic alogrithm will
     // likely be too slow.
     foreach (const Containment* other, q->corona()->containments()) {
         if (other == q ||
-            other->containmentType() != PanelContainment ||
+            (other->containmentType() != Containment::PanelContainment &&
+             other->containmentType() != Containment::CustomPanelContainment) ||
             horiz != (other->formFactor() == Plasma::Horizontal)) {
             // only line up with panels of the same orientation
             continue;
