@@ -42,6 +42,7 @@ class DataEngine;
 class Package;
 class Corona;
 class View;
+class ContainmentPrivate;
 
 /**
  * @short The base class for plugins that provide backgrounds and applet grouping containers
@@ -74,6 +75,9 @@ class PLASMA_EXPORT Containment : public Applet
                 explicit StyleOption(const StyleOption &other);
                 explicit StyleOption(const QStyleOptionGraphicsItem &other);
 
+                enum StyleOptionType { Type = SO_CustomBase + 1 };
+                enum StyleOptionVersion { Version = QStyleOptionGraphicsItem::Version + 1 };
+
                 /**
                  * The View, if any, that this containment is currently
                  * being rendered into. Note: this may be NULL, so be
@@ -86,7 +90,8 @@ class PLASMA_EXPORT Containment : public Applet
                     DesktopContainment = 0 /**< A desktop containment */,
                     PanelContainment /**< A desktop panel */,
                     CustomContainment = 127 /**< A containment that is neither a desktop nor a panel,
-                                                 but something application specific */
+                                                 but something application specific */,
+                    CustomPanelContainment = 128 /**< A customized desktop panel */
                   };
 
         /**
@@ -413,8 +418,8 @@ class PLASMA_EXPORT Containment : public Applet
         Q_PRIVATE_SLOT(d, void toggleDesktopImmutability())
 
         friend class Applet;
-        class Private;
-        Private* const d;
+        friend class ContainmentPrivate;
+        ContainmentPrivate* const d;
 };
 
 } // Plasma namespace
