@@ -40,13 +40,13 @@ namespace Plasma
 {
 
 // constant controlling how long between requesting a configuration sync
-// and one happening should occur. currently 2 minutes.
-const int CONFIG_SYNC_TIMEOUT = 120000;
+// and one happening should occur. currently 30 seconds
+const int CONFIG_SYNC_TIMEOUT = 30000;
 
-class Corona::Private
+class CoronaPrivate
 {
 public:
-    Private(Corona *corona)
+    CoronaPrivate(Corona *corona)
         : q(corona),
           immutability(Mutable),
           mimetype("text/x-plasmoidservicename"),
@@ -59,7 +59,7 @@ public:
         }
     }
 
-    ~Private()
+    ~CoronaPrivate()
     {
         qDeleteAll(containments);
     }
@@ -67,7 +67,7 @@ public:
     void init()
     {
         configSyncTimer.setSingleShot(true);
-        connect(&configSyncTimer, SIGNAL(timeout()), q, SLOT(syncConfig()));
+        QObject::connect(&configSyncTimer, SIGNAL(timeout()), q, SLOT(syncConfig()));
     }
 
     void saveLayout(KSharedConfigPtr cg) const
@@ -99,6 +99,7 @@ public:
 
         if (index > -1) {
             containments.removeAt(index);
+            q->requestConfigSync();
         }
     }
 
@@ -119,7 +120,9 @@ public:
         if (pluginName.isEmpty()) {
             // default to the desktop containment
             pluginName = "desktop";
-        } else if (pluginName != "null") {
+        }
+
+        if (pluginName != "null") {
             applet = Applet::load(pluginName, id, args);
             containment = dynamic_cast<Containment*>(applet);
         }
@@ -137,19 +140,22 @@ public:
         }
 
         containment->setIsContainment(true);
+        q->addItem(containment);
 
         if (!delayedInit) {
-            q->addItem(containment);
             containment->init();
             containment->updateConstraints(Plasma::StartupCompletedConstraint);
+            KConfigGroup cg = containment->config();
+            containment->save(cg);
+            q->requestConfigSync();
         }
 
         containments.append(containment);
-        connect(containment, SIGNAL(destroyed(QObject*)), q, SLOT(containmentDestroyed(QObject*)));
-        connect(containment, SIGNAL(configNeedsSaving()), q, SLOT(requestConfigSync()));
-        connect(containment, SIGNAL(releaseVisualFocus()), q, SIGNAL(releaseVisualFocus()));
-        connect(containment, SIGNAL(screenChanged(int,int,Plasma::Containment*)),
-                q, SIGNAL(screenOwnerChanged(int,int,Plasma::Containment*)));
+        QObject::connect(containment, SIGNAL(destroyed(QObject*)), q, SLOT(containmentDestroyed(QObject*)));
+        QObject::connect(containment, SIGNAL(configNeedsSaving()), q, SLOT(requestConfigSync()));
+        QObject::connect(containment, SIGNAL(releaseVisualFocus()), q, SIGNAL(releaseVisualFocus()));
+        QObject::connect(containment, SIGNAL(screenChanged(int,int,Plasma::Containment*)),
+                         q, SIGNAL(screenOwnerChanged(int,int,Plasma::Containment*)));
 
         if (!delayedInit) {
             emit q->containmentAdded(containment);
@@ -169,7 +175,7 @@ public:
 
 Corona::Corona(QObject *parent)
     : QGraphicsScene(parent),
-      d(new Private(this))
+      d(new CoronaPrivate(this))
 {
     d->init();
     //setViewport(new QGLWidget(QGLFormat(QGL::StencilBuffer | QGL::AlphaChannel)));
@@ -269,7 +275,7 @@ void Corona::loadLayout(const QString& configName)
             continue;
         }
 
-        addItem(c);
+        //addItem(c);
         c->init();
         c->restore(containmentConfig);
     }
@@ -324,28 +330,12 @@ KSharedConfigPtr Corona::config() const
 
 Containment* Corona::addContainment(const QString& name, const QVariantList& args)
 {
-    Containment *c = d->addContainment(name, args, 0, false);
-    requestConfigSync();
-    return c;
+    return d->addContainment(name, args, 0, false);
 }
 
-void Corona::destroyContainment(Containment *c)
+Containment* Corona::addContainmentDelayed(const QString& name, const QVariantList& args)
 {
-    if (!d->containments.contains(c)) {
-        return;
-    }
-
-    //don't remove a desktop that's in use
-    //FIXME allow removal of containments for screens that don't currently exist
-    if (c->containmentType() != Containment::PanelContainment && c->screen() != -1) {
-        return;
-    }
-
-    d->containments.removeAll(c);
-    removeItem(c);
-    c->config().deleteGroup();
-    c->deleteLater();
-    requestConfigSync();
+    return d->addContainment(name, args, 0, true);
 }
 
 void Corona::loadDefaultLayout()
