@@ -19,6 +19,8 @@
 
 #include "packages_p.h"
 
+#include <KConfigGroup>
+#include <KDesktopFile>
 #include <KLocale>
 
 namespace Plasma
@@ -52,6 +54,17 @@ PlasmoidPackage::PlasmoidPackage(QObject *parent)
     setRequired("mainscript", true);
 }
 
+void PlasmoidPackage::pathChanged()
+{
+    KDesktopFile config(path() + "/metadata.desktop");
+    KConfigGroup cg = config.desktopGroup();
+    QString mainScript = cg.readEntry("X-Plasma-MainScript", QString());
+    if (!mainScript.isEmpty()) {
+        addFileDefinition("mainscript", mainScript, i18n("Main Script File"));
+        setRequired("mainscript", true);
+    }
+}
+
 ThemePackage::ThemePackage(QObject *parent)
     : Plasma::PackageStructure(parent, QString("Plasma Theme"))
 {
@@ -61,7 +74,7 @@ ThemePackage::ThemePackage(QObject *parent)
     addFileDefinition("dialogs/shutdowndialog", "dialogs/shutdowndialog.svg",
                       i18n("Theme for the logout dialog"));
 
-    addDirectoryDefinition("wallpapers", "wallpapers/", "Wallpapers"); //FIXME 4.2: i18n("Wallpaper Packages"));
+    addDirectoryDefinition("wallpapers", "wallpapers/", i18n("Wallpaper packages"));
 
     addDirectoryDefinition("widgets", "widgets/", i18n("Images for widgets"));
     addFileDefinition("widgets/background", "widgets/background.svg",
