@@ -30,6 +30,9 @@ class PlasmoidPackage : public PackageStructure
     Q_OBJECT
 public:
     explicit PlasmoidPackage(QObject *parent = 0);
+
+protected:
+    void pathChanged();
 };
 
 class ThemePackage : public PackageStructure
