@@ -34,6 +34,8 @@ class KConfigBase;
 namespace Plasma
 {
 
+class PackageStructurePrivate;
+
 /**
  * @brief A description of the expected file structure of a given package type
  *
@@ -204,13 +206,13 @@ public:
     QString path() const;
 
     /**
-      * Read a package structure from a config file.
-      */
+     * Read a package structure from a config file.
+     */
     void read(const KConfigBase *config);
 
     /**
-      * Write this package structure to a config file.
-      */
+     * Write this package structure to a config file.
+     */
     void write(KConfigBase *config) const;
 
     /**
@@ -256,8 +258,7 @@ protected:
     virtual void pathChanged();
 
 private:
-    class Private;
-     Private * const d;
+    PackageStructurePrivate * const d;
 };
 
 /**
