@@ -31,15 +31,15 @@ using namespace Plasma;
 namespace Plasma
 {
 
-class View::Private
+class ViewPrivate
 {
 public:
-    Private(View *view, int uniqueId)
-        : drawWallpaper(true),
+    ViewPrivate(View *view, int uniqueId)
+        : q(view),
+          containment(0),
+          drawWallpaper(true),
           trackChanges(true),
           desktop(-1),
-          containment(0),
-          q(view),
           viewId(0)
     {
         if (uniqueId > s_maxViewId) {
@@ -54,7 +54,7 @@ public:
         }
     }
 
-    ~Private()
+    ~ViewPrivate()
     {
     }
 
@@ -86,20 +86,20 @@ public:
         q->setVerticalScrollBarPolicy(Qt::ScrollBarAlwaysOff);
     }
 
+    Plasma::View *q;
+    Plasma::Containment *containment;
     bool drawWallpaper;
     bool trackChanges;
     int desktop;
     int viewId;
-    Plasma::Containment *containment;
-    Plasma::View *q;
     static int s_maxViewId;
 };
 
-int View::Private::s_maxViewId(0);
+int ViewPrivate::s_maxViewId(0);
 
 View::View(Containment *containment, QWidget *parent)
     : QGraphicsView(parent),
-      d(new Private(this, 0))
+      d(new ViewPrivate(this, 0))
 {
     Q_ASSERT(containment);
     d->initGraphicsView();
@@ -109,7 +109,7 @@ View::View(Containment *containment, QWidget *parent)
 
 View::View(Containment *containment, int viewId, QWidget *parent)
     : QGraphicsView(parent),
-      d(new Private(this, viewId))
+      d(new ViewPrivate(this, viewId))
 {
     Q_ASSERT(containment);
     d->initGraphicsView();
@@ -175,33 +175,45 @@ void View::setContainment(Containment *containment)
         return;
     }
 
-    int screen = -1;
-    Containment *oldContainment = d->containment;
-
     if (d->containment) {
         disconnect(d->containment, SIGNAL(geometryChanged()), this, SLOT(updateSceneRect()));
-        screen = d->containment->screen();
-        //remove all the old containment's actions
         d->containment->removeAssociatedWidget(this);
     }
 
-    d->containment = containment;
     if (!containment) {
+        d->containment = 0;
         return;
     }
 
+    Containment *oldContainment = d->containment;
+
+    int screen = -1;
+    if (oldContainment) {
+        screen = d->containment->screen();
+    }
+
+    d->containment = containment;
+
     //add keyboard-shortcut actions
     d->containment->addAssociatedWidget(this);
 
     int otherScreen = containment->screen();
-    if (oldContainment && otherScreen > -1) {
-        oldContainment->setScreen(otherScreen);
-    }
 
     if (screen > -1) {
         containment->setScreen(screen);
     }
 
+    if (oldContainment && otherScreen > -1) {
+        oldContainment->setScreen(otherScreen);
+    }
+
+    /*
+    if (oldContainment) {
+        kDebug() << (QObject*)oldContainment << screen << oldContainment->screen()
+                 << (QObject*)containment << otherScreen << containment->screen();
+    }
+    */
+
     if (containment->screen() > -1 && d->desktop < -1) {
         // we want to set it to "all desktops" if we get ownership of
         // a screen but don't have a desktop explicitly set
