@@ -140,7 +140,7 @@ CoverManager::CoverManager()
 
     Collection *coll = CollectionManager::instance()->primaryCollection();
     QueryMaker *qm = coll->queryMaker();
-    qm->startArtistQuery();
+    qm->setQueryType( QueryMaker::Artist );
     BlockingQuery bq( qm );
     bq.startQuery();
 
@@ -344,7 +344,8 @@ CoverViewDialog::CoverViewDialog( Meta::AlbumPtr album, QWidget *parent )
 
     kapp->setTopWidget( this );
     setWindowTitle( KDialog::makeStandardCaption( i18n("%1 - %2",
-                    album->albumArtist()->prettyName(), album->prettyName() ) ) );
+                    album->albumArtist()? album->albumArtist()->prettyName() : i18n( "Various Artists" ),
+                    album->prettyName() ) ) );
 
     m_layout = new QHBoxLayout( this );
     m_layout->setSizeConstraint( QLayout::SetFixedSize );
@@ -466,7 +467,7 @@ void CoverManager::slotArtistSelected() //SLOT
     Collection *coll = CollectionManager::instance()->primaryCollection();
 
     QueryMaker *qm = coll->queryMaker();
-    qm->startAlbumQuery();
+    qm->setQueryType( QueryMaker::Album );
     if( item != m_artistView->invisibleRootItem()->child( 0 ) )
         qm->addMatch( artist );
     else
@@ -594,15 +595,16 @@ void CoverManager::slotSetFilterTimeout() //SLOT
 
 void CoverManager::changeView( int id  ) //SLOT
 {
+    DEBUG_BLOCK
+    
     if( m_currentView == id ) return;
 
     //clear the iconview without deleting items
     m_coverView->clearSelection();
-    QListWidgetItem *item = m_coverView->item( 0 );
-    uint i = 0;
-    while ( item ) {
-        m_coverView->takeItem( i );
-        i++;
+    //QListWidgetItem *item = m_coverView->item( 0 );
+
+    while ( m_coverView->count() > 0 ) {
+       m_coverView->takeItem( 0 );
     }
 
 //     m_coverView->setAutoArrange(false );
@@ -617,12 +619,14 @@ void CoverManager::changeView( int id  ) //SLOT
 
         if( id == AllAlbums )    //show all albums
             show = true;
-        else if( id == AlbumsWithCover && coverItem->hasCover() )    //show only albums with cover
+        else if( id == AlbumsWithCover && coverItem->hasCover() ) {    //show only albums with cover
             show = true;
-        else if( id == AlbumsWithoutCover && !coverItem->hasCover() )   //show only albums without cover
+        } else if( id == AlbumsWithoutCover && !coverItem->hasCover() ) {   //show only albums without cover
             show = true;
-
-        if( show )    m_coverView->insertItem( m_coverView->count() - 1, item );
+        }
+        if( show ) {
+            m_coverView->insertItem( m_coverView->count() - 1, item );
+        }
     }
 //     m_coverView->setAutoArrange( true );
 
