@@ -19,20 +19,45 @@
 #ifndef PLAYER_DBUS_HANDLER_H
 #define PLAYER_DBUS_HANDLER_H
 
+#include "meta/Meta.h"
+
 #include <QObject>
 #include <QVariantMap>
+#include <QDBusArgument>
+
+namespace Amarok {
+    class PlayerDBusHandler;
+}
+
+namespace The {
+    AMAROK_EXPORT Amarok::PlayerDBusHandler* playerDBusHandler();
+}
+
+struct DBusStatus
+{
+    int Play; //Playing = 0, Paused = 1, Stopped = 2
+    int Random; //Linearly = 0, Randomly = 1
+    int Repeat; //Go_To_Next = 0, Repeat_Current = 1
+    int RepeatPlaylist; //Stop_When_Finished = 0, Never_Give_Up_Playing = 1
+};
+
+Q_DECLARE_METATYPE(DBusStatus)
+
+// Marshall the DBusStatus data into a D-BUS argument
+QDBusArgument &operator<<(QDBusArgument &argument, const DBusStatus &status);
+// Retrieve the DBusStatus data from the D-BUS argument
+const QDBusArgument &operator>>(const QDBusArgument &argument, DBusStatus &status);
 
 namespace Amarok
 {
-
     class PlayerDBusHandler : public QObject
     {
+        friend Amarok::PlayerDBusHandler* The::playerDBusHandler();
+
         Q_OBJECT
         public:
             PlayerDBusHandler();
 
-            enum DBusStatus { Playing = 0, Paused = 1, Stopped = 2 };
-            //http://wiki.xmms2.xmms.se/index.php/MPRIS#GetCaps
             enum DBusCaps {
                  NONE                  = 0,
                  CAN_GO_NEXT           = 1 << 0,
@@ -43,8 +68,9 @@ namespace Amarok
                  CAN_PROVIDE_METADATA  = 1 << 5,
                  CAN_HAS_TRACKLIST     = 1 << 6
              };
+
         public slots:
-            int GetStatus();
+            DBusStatus GetStatus();
             void Pause();
             void Play();
             void PlayPause();
@@ -57,8 +83,16 @@ namespace Amarok
             QVariantMap GetMetadata();
         signals:
             void CapsChange( int );
+            void TrackChange( QVariantMap );
+            void StatusChange( DBusStatus );
         private slots:
-            void capsChangeSlot();
+            void slotCapsChange();
+            void slotTrackChange();
+            void slotStatusChange();
+        public:
+            QVariantMap GetTrackMetadata( Meta::TrackPtr track );
+        private:
+            static PlayerDBusHandler* s_instance;
     };
 
 } // namespace Amarok
