@@ -24,7 +24,24 @@
 
 #include "RootAdaptor.h"
 
-#define MPRIS_VERSION 1.0
+// Marshall the DBusVersion data into a D-BUS argument
+QDBusArgument &operator<<(QDBusArgument &argument, const Version &version)
+{
+    argument.beginStructure();
+    argument << version.major << version.minor;
+    argument.endStructure();
+    return argument;
+}
+
+// Retrieve the DBusVersion data from the D-BUS argument
+const QDBusArgument &operator>>(const QDBusArgument &argument, Version &version)
+{
+    argument.beginStructure();
+    argument >> version.major >> version.minor;
+    argument.endStructure();
+    return argument;
+}
+
 
 namespace Amarok
 {
@@ -32,6 +49,8 @@ namespace Amarok
     RootDBusHandler::RootDBusHandler()
         : QObject( kapp )
     {
+        qDBusRegisterMetaType<Version>();
+
         new RootAdaptor( this );
         QDBusConnection::sessionBus().registerObject("/", this);
     }
@@ -46,10 +65,12 @@ namespace Amarok
         kapp->closeAllWindows();
     }
 
-    float RootDBusHandler::MprisVersion()
+    Version RootDBusHandler::MprisVersion()
     {
-        //return type wrong here?
-        return MPRIS_VERSION;
+        struct Version version;
+        version.major = 1;
+        version.minor = 0;
+        return version;
     }
 
 }
