@@ -23,6 +23,8 @@
 #include "collection/CollectionManager.h"
 #include "mediabrowser.h"
 #include "playlist/PlaylistModel.h"
+#include "dbus/PlayerDBusHandler.h"
+
 
 #include <KUrl>
 
@@ -36,6 +38,10 @@ namespace Amarok
     {
         new TracklistAdaptor(this);
         QDBusConnection::sessionBus().registerObject( "/TrackList", this );
+        // FIXME: currently The::playlistModel() returns null at this point
+        //        so the signals don't get connected
+        connect( The::playlistModel(), SIGNAL( playlistCountChanged( int ) ), this, SLOT( slotTrackListChange() ) );
+        connect( The::playlistModel(), SIGNAL( rowMoved( int, int ) ), this, SLOT( slotTrackListChange() ) );
     }
 
     int TracklistDBusHandler::AddTrack( const QString& url, bool playImmediately )
@@ -62,7 +68,6 @@ namespace Amarok
     int TracklistDBusHandler::GetCurrentTrack()
     {
         return The::playlistModel()->activeRow();
-        //todo: check this function
     }
 
     int TracklistDBusHandler::GetLength()
@@ -72,8 +77,7 @@ namespace Amarok
 
     QVariantMap TracklistDBusHandler::GetMetadata( int position )
     {
-        //todo: add function
-        return QVariantMap();
+        return The::playerDBusHandler()->GetTrackMetadata( The::playlistModel()->trackForRow( position ) );
     }
 
     void TracklistDBusHandler::SetLoop(bool enable)
@@ -87,6 +91,11 @@ namespace Amarok
         static_cast<KSelectAction*>( Amarok::actionCollection()->action( "random_mode" ) )
         ->setCurrentItem( enable ? AmarokConfig::EnumRandomMode::Tracks : AmarokConfig::EnumRandomMode::Off );
     }
+
+    void TracklistDBusHandler::slotTrackListChange()
+    {
+        emit TrackListChange( The::playlistModel()->rowCount() );
+    }
 }
 
 #include "TracklistDBusHandler.moc"
