@@ -29,12 +29,20 @@ class FilenameLayoutDialog
 
     public:
         FilenameLayoutDialog( QWidget *parent = 0 );
+        QString getParsableScheme();
+        int getCaseOptions();
+        int getWhitespaceOptions();
+        int getUnderscoreOptions();
+        //FilenameLayoutWidget * filenameLayout;
+        //TokenListWidget * tokenPool;
 
     private:
         QList< QRadioButton * > caseEditRadioButtons;
+        
 
     private slots:
         void editStateEnable( bool checked );
+        void onAccept();
 };
 
 #endif    //FILENAMELAYOUTDIALOG_H
