@@ -35,10 +35,11 @@
 #include "Osd.h"
 #include "scriptengine/AmarokCollectionScript.h"
 #include "scriptengine/AmarokEngineScript.h"
+#include "scriptengine/AmarokLyricsScript.h"
 #include "scriptengine/AmarokOSDScript.h"
 #include "scriptengine/AmarokPlaylistScript.h"
 #include "scriptengine/AmarokScript.h"
-#include "scriptengine/AmarokScriptableServiceManagerScript.h"
+#include "scriptengine/AmarokScriptableServiceScript.h"
 #include "scriptengine/AmarokServicePluginManagerScript.h"
 #include "scriptengine/AmarokStatusbarScript.h"
 #include "scriptengine/AmarokTrackInfoScript.h"
@@ -55,6 +56,7 @@
 #include <KMenu>
 #include <KMessageBox>
 #include <knewstuff2/engine.h>
+#include <knewstuff2/core/entry.h>
 #include <KProtocolManager>
 #include <KPushButton>
 #include <KRun>
@@ -111,13 +113,14 @@ namespace Amarok {
 ScriptManager* ScriptManager::s_instance = 0;
 
 
-ScriptManager::ScriptManager( QWidget *parent, const char *name )
+ScriptManager::ScriptManager( QWidget* parent )
         : KDialog( parent )
         , EngineObserver( The::engineController() )
         , m_gui( new Ui::ScriptManagerBase() )
 {
     DEBUG_BLOCK
-    setObjectName( name );
+
+    setObjectName( "ScriptManager" );
     setModal( false );
     setButtons( Close );
     setDefaultButton( Close );
@@ -142,30 +145,18 @@ ScriptManager::ScriptManager( QWidget *parent, const char *name )
     /// Category items
     m_generalCategory    = new QTreeWidgetItem( m_gui->treeWidget );
     m_lyricsCategory     = new QTreeWidgetItem( m_gui->treeWidget );
-    m_scoreCategory      = new QTreeWidgetItem( m_gui->treeWidget );
-    m_transcodeCategory  = new QTreeWidgetItem( m_gui->treeWidget );
-    m_contextCategory    = new QTreeWidgetItem( m_gui->treeWidget );
     m_servicesCategory   = new QTreeWidgetItem( m_gui->treeWidget );
 
     m_generalCategory  ->setText( 0, i18n( "General" ) );
     m_lyricsCategory   ->setText( 0, i18n( "Lyrics" ) );
-    m_scoreCategory    ->setText( 0, i18n( "Score" ) );
-    m_transcodeCategory->setText( 0, i18n( "Transcoding" ) );
-    m_contextCategory  ->setText( 0, i18n( "Context Browser" ) );
     m_servicesCategory ->setText( 0, i18n( "Scripted Services" ) );
 
     m_generalCategory  ->setFlags( Qt::ItemIsEnabled );
     m_lyricsCategory   ->setFlags( Qt::ItemIsEnabled );
-    m_scoreCategory    ->setFlags( Qt::ItemIsEnabled );
-    m_transcodeCategory->setFlags( Qt::ItemIsEnabled );
-    m_contextCategory  ->setFlags( Qt::ItemIsEnabled );
     m_servicesCategory ->setFlags( Qt::ItemIsEnabled );
 
     m_generalCategory  ->setIcon( 0, SmallIcon( "folder-amarok" ) );
     m_lyricsCategory   ->setIcon( 0, SmallIcon( "folder-amarok" ) );
-    m_scoreCategory    ->setIcon( 0, SmallIcon( "folder-amarok" ) );
-    m_transcodeCategory->setIcon( 0, SmallIcon( "folder-amarok" ) );
-    m_contextCategory  ->setIcon( 0, SmallIcon( "folder-amarok" ) );
     m_servicesCategory ->setIcon( 0, SmallIcon( "folder-amarok" ) );
 
 
@@ -173,9 +164,6 @@ ScriptManager::ScriptManager( QWidget *parent, const char *name )
     KConfigGroup config = Amarok::config( "ScriptManager" );
     m_generalCategory  ->setExpanded( config.readEntry( "General category open", false ) );
     m_lyricsCategory   ->setExpanded( config.readEntry( "Lyrics category open", false ) );
-    m_scoreCategory    ->setExpanded( config.readEntry( "Score category State", false ) );
-    m_transcodeCategory->setExpanded( config.readEntry( "Transcode category open", false ) );
-    m_contextCategory  ->setExpanded( config.readEntry( "Context category open", false ) );
     m_servicesCategory ->setExpanded( config.readEntry( "Service category open", false ) );
 
     connect( m_gui->treeWidget, SIGNAL( currentItemChanged( QTreeWidgetItem*, QTreeWidgetItem* ) ), SLOT( slotCurrentChanged( QTreeWidgetItem* ) ) );
@@ -187,21 +175,22 @@ ScriptManager::ScriptManager( QWidget *parent, const char *name )
     connect( m_gui->uninstallButton, SIGNAL( clicked() ), SLOT( slotUninstallScript() ) );
     connect( m_gui->runButton,       SIGNAL( clicked() ), SLOT( slotRunScript() ) );
     connect( m_gui->stopButton,      SIGNAL( clicked() ), SLOT( slotStopScript() ) );
-    connect( m_gui->configureButton, SIGNAL( clicked() ), SLOT( slotConfigureScript() ) );
-    connect( m_gui->aboutButton,     SIGNAL( clicked() ), SLOT( slotAboutScript() ) );
 
     m_gui->installButton  ->setIcon( KIcon( "folder-amarok" ) );
     m_gui->retrieveButton ->setIcon( KIcon( "get-hot-new-stuff-amarok" ) );
     m_gui->uninstallButton->setIcon( KIcon( "edit-delete-amarok" ) );
     m_gui->runButton      ->setIcon( KIcon( "media-playback-start-amarok" ) );
     m_gui->stopButton     ->setIcon( KIcon( "media-playback-stop-amarok" ) );
-    m_gui->configureButton->setIcon( KIcon( "configure-amarok" ) );
-    m_gui->aboutButton    ->setIcon( KIcon( "help-about-amarok" ) );
 
     QSize sz = sizeHint();
     setMinimumSize( qMax( 350, sz.width() ), qMax( 250, sz.height() ) );
     resize( sizeHint() );
 
+    // Center the dialog in the middle of the mainwindow
+    const int x = parentWidget()->width() / 2 - width() / 2;
+    const int y = parentWidget()->height() / 2 - height() / 2;
+    move( x, y );
+
 //FIXME: contex tbrowser changes
 //     connect( this, SIGNAL(lyricsScriptChanged()), ContextBrowser::instance(), SLOT( lyricsScriptChanged() ) );
 
@@ -219,6 +208,7 @@ ScriptManager::~ScriptManager()
     foreach( const QString &key, m_scripts.keys() )
         if( m_scripts[key].running )
             runningScripts << key;
+
     // Save config
     KConfigGroup config = Amarok::config( "ScriptManager" );
     config.writeEntry( "Running Scripts", runningScripts );
@@ -226,10 +216,10 @@ ScriptManager::~ScriptManager()
     // Save the open/closed state of the category items
     config.writeEntry( "General category open", m_generalCategory->isExpanded() );
     config.writeEntry( "Lyrics category open", m_lyricsCategory->isExpanded() );
-    config.writeEntry( "Score category open", m_scoreCategory->isExpanded() );
-    config.writeEntry( "Transcode category open", m_transcodeCategory->isExpanded() );
-    config.writeEntry( "Context category open", m_contextCategory->isExpanded() );
     config.writeEntry( "Service category open", m_servicesCategory->isExpanded() );
+
+    config.sync();
+
     s_instance = 0;
 }
 
@@ -300,39 +290,6 @@ ScriptManager::notifyFetchLyricsByUrl( const QString& url )
 //    notifyScripts( "fetchLyricsByUrl " + url );
 }
 
-
-void ScriptManager::notifyTranscode( const QString& srcUrl, const QString& filetype )
-{
-//    notifyScripts( "transcode " + srcUrl + ' ' + filetype );
-}
-
-
-void
-ScriptManager::requestNewScore( const QString &url, double prevscore, int playcount, int length, float percentage, const QString &reason )
-{
-    const QString script = ensureScoreScriptRunning();
-    if( script.isNull() )
-    {
-    // Scoring is currently disabled, so don't show warning
-#if 0
-        The::statusBar()->longMessage(
-            i18n( "No score scripts were found, or none of them worked. Automatic scoring will be disabled. Sorry." ),
-            KDE::StatusBar::Sorry );
-#endif
-        return;
-    }
-/*
-    m_scripts[script].process->writeStdin(
-        QString( "requestNewScore %6 %1 %2 %3 %4 %5" )
-        .arg( prevscore )
-        .arg( playcount )
-        .arg( length )
-        .arg( percentage )
-        .arg( reason )
-        .arg( QString( QUrl::toPercentEncoding( url ) ) ) ); //last because it might have %s
-*/
-}
-
 ////////////////////////////////////////////////////////////////////////////////
 // private slots
 ////////////////////////////////////////////////////////////////////////////////
@@ -368,8 +325,6 @@ ScriptManager::slotCurrentChanged( QTreeWidgetItem* item )
 {
     const bool isCategory = item == m_generalCategory ||
                             item == m_lyricsCategory ||
-                            item == m_scoreCategory ||
-                            item == m_transcodeCategory ||
                             item == m_servicesCategory;
 
     if( item && !isCategory )
@@ -378,16 +333,12 @@ ScriptManager::slotCurrentChanged( QTreeWidgetItem* item )
         m_gui->uninstallButton->setEnabled( true );
         m_gui->runButton->setEnabled( !m_scripts[name].running );
         m_gui->stopButton->setEnabled( m_scripts[name].running );
-        m_gui->configureButton->setEnabled( m_scripts[name].running );
-        m_gui->aboutButton->setEnabled( true );
     }
     else
     {
         m_gui->uninstallButton->setEnabled( false );
         m_gui->runButton->setEnabled( false );
         m_gui->stopButton->setEnabled( false );
-        m_gui->configureButton->setEnabled( false );
-        m_gui->aboutButton->setEnabled( false );
     }
 }
 
@@ -482,10 +433,13 @@ ScriptManager::slotRetrieveScript()
     KNS::Engine *engine = new KNS::Engine();
     engine->init( "amarok.knsrc" );
     KNS::Entry::List entries = engine->downloadDialogModal();
-
-    qDeleteAll( entries );
+    debug() << "scripts status:" << endl;
+    foreach ( KNS::Entry* entry, entries )
+    {
+//        if ( entry->status() == KNS::Entry::Downloadable )
+            debug() << "script downloadable!" << endl;
+    }
     delete engine;
-    //todo: upgrade?
 }
 
 
@@ -545,14 +499,6 @@ ScriptManager::slotRunScript( bool silent )
                                          "You may only run one lyrics script at a time." ) );
         return false;
     }
-
-    if( m_scripts[name].type == "transcode" && !transcodeScriptRunning().isEmpty() )
-    {
-        if( !silent )
-            KMessageBox::sorry( 0, i18n( "Another transcode script is already running. "
-                                         "You may only run one transcode script at a time." ) );
-        return false;
-    }
     const KUrl url = m_scripts[name].url;
     QTime time;
     //load the wrapper classes
@@ -563,13 +509,11 @@ ScriptManager::slotRunScript( bool silent )
     //todo: setProcessEventsInterval?
     li->setIcon( 0, SmallIcon( "media-playback-start-amarok" ) );
     slotCurrentChanged( m_gui->treeWidget->currentItem() );
-//TODO: use thread to handle scripts?
+
     m_scripts[name].log += time.currentTime().toString() + " Script Started!" + '\n';
     m_scripts[name].engine->evaluate( scriptFile.readAll() );
     scriptFile.close();
     //FIXME: '\n' doesen't work?
-    if( m_scripts[name].type == "service" )
-        The::scriptableServiceManager()->addRunningScript( name );
     if ( m_scripts[name].engine->hasUncaughtException() )
     {
         m_scripts[name].log += time.currentTime().toString() + " " + m_scripts[name].engine->uncaughtException().toString() + " on Line: " + QString::number( m_scripts[name].engine->uncaughtExceptionLineNumber() ) + '\n';
@@ -606,12 +550,6 @@ ScriptManager::slotConfigureScript()
     m_scripts[name].globalPtr->slotConfigured();
 }
 
-void
-ScriptManager::ServiceScriptInit( QString name )
-{
-    m_scripts[name].servicePtr->slotInit();
-}
-
 void
 ScriptManager::ServiceScriptPopulate( QString name, int level, int parent_id, QString path, QString filter )
 {
@@ -653,9 +591,6 @@ ScriptManager::slotShowContextMenu( const QPoint& pos )
 
     const bool isCategory = item == m_generalCategory ||
                             item == m_lyricsCategory ||
-                            item == m_scoreCategory ||
-                            item == m_transcodeCategory ||
-                            item == m_contextCategory ||
                             item == m_servicesCategory;
 
     if( !item || isCategory )
@@ -666,20 +601,37 @@ ScriptManager::slotShowContextMenu( const QPoint& pos )
     foreach( key, m_scripts.keys() )
         if( m_scripts[key].li == item ) break;
 
-    enum { SHOW_LOG, EDIT };
+    enum { CONFIGURE, ABOUT, SHOW_LOG, EDIT };
     KMenu menu;
-    menu.addTitle( i18n( "Debugging" ) );
+    menu.addTitle( i18n( "Properties" ) );
+
+    QAction* configureAction = menu.addAction( KIcon( "configure-amarok" ), i18n( "&Configure" ) );
+    QAction* aboutAction = menu.addAction( KIcon( "help-about-amarok" ), i18n( "&About" ) );
+    menu.addSeparator();
     QAction* logAction = menu.addAction( KIcon( "view-history-amarok" ), i18n( "Show Output &Log" ) );
     QAction* editAction = menu.addAction( KIcon( "document-properties-amarok" ), i18n( "&Edit" ) );
+
+
+    configureAction->setData( CONFIGURE );
+    aboutAction->setData( ABOUT );
     logAction->setData( SHOW_LOG );
     editAction->setData( EDIT );
 
+
     QAction* choice = menu.exec( mapToGlobal( pos ) );
     if( !choice ) return;
     const int id = choice->data().toInt();
 
     switch( id )
     {
+        case CONFIGURE:
+            slotConfigureScript();
+            break;
+
+        case ABOUT:
+            slotAboutScript();
+            break;
+
         case EDIT:
             KRun::runCommand( "kwrite " + m_scripts[key].url.path(), 0 );
             break;
@@ -747,42 +699,6 @@ ScriptManager::scriptRunningOfType( const QString &type ) const
     return QString();
 }
 
-
-QString
-ScriptManager::ensureScoreScriptRunning()
-{
-    AMAROK_NOTIMPLEMENTED
-
-    // FIXME this code sometimes causes a crash:
-    //
-    //#26 0xb5d91b24 in QTreeWidget::setCurrentItem (this=0x8757538, item=0x8941fe0) at itemviews/qtreewidget.cpp:2749
-    //#27 0xb78b78e7 in ScriptManager::runScript (this=0x870bc00, name=@0x8710484, silent=true)
-    //    at /var/tmp/paludis/media-sound-amarok-scm/work/amarok/amarok/src/dialogs/scriptmanager.cpp:236
-    //#28 0xb78b7a94 in ScriptManager::ensureScoreScriptRunning (this=0x870bc00)
-    //    at /var/tmp/paludis/media-sound-amarok-scm/work/amarok/amarok/src/dialogs/scriptmanager.cpp:798
-
-#if 0
-    QString s = scoreScriptRunning();
-    if( !s.isNull() )
-        return s;
-
-    if( runScript( AmarokConfig::lastScoreScript(), true /*silent*/ ) )
-        return AmarokConfig::lastScoreScript();
-
-    const QString def = i18n( "Score" ) + ": " + "Default";
-    if( runScript( def, true ) )
-        return def;
-
-    const QStringList scripts = scoreScripts();
-    QStringList::ConstIterator end = scripts.constEnd();
-    for( QStringList::ConstIterator it = scripts.constBegin(); it != end; ++it )
-        if( runScript( *it, true ) )
-            return *it;
-
-#endif
-    return QString();
-}
-
 void
 ScriptManager::loadScript( const QString& path )
 {
@@ -826,26 +742,11 @@ ScriptManager::loadScript( const QString& path )
                     li = new QTreeWidgetItem( m_lyricsCategory );
                     li->setText( 0, name );
                 }
-                if( type == "transcode" )
-                {
-                    li = new QTreeWidgetItem( m_transcodeCategory );
-                    li->setText( 0, name );
-                }
-                if( type == "score" )
-                {
-                    li = new QTreeWidgetItem( m_scoreCategory );
-                    li->setText( 0, name );
-                }
                 if( type == "service" )
                 {
                     li = new QTreeWidgetItem( m_servicesCategory );
                     li->setText( 0, name );
                 }
-                if( type == "context" )
-                {
-                    li = new QTreeWidgetItem( m_contextCategory );
-                        li->setText( 0, name );
-                }
                 if( type == "generic" )
                 {
                     li = new QTreeWidgetItem( m_generalCategory );
@@ -884,9 +785,6 @@ ScriptManager::startScriptEngine( QString name )
     DEBUG_BLOCK
 
     QScriptEngine* scriptEngine = m_scripts[name].engine;
-//    scriptEngine->importExtension( "qt.core" );
-//    scriptEngine->importExtension( "qt.gui" );
-
     QObject* objectPtr;
     QScriptValue scriptObject;
 
@@ -900,9 +798,9 @@ ScriptManager::startScriptEngine( QString name )
     scriptEngine->globalObject().setProperty( "Amarok", m_global );
     m_scripts[name].wrapperList.append( m_scripts[name].globalPtr );
 
-    m_scripts[name].servicePtr = new Amarok::AmarokScriptableServiceManagerScript( scriptEngine );
+    m_scripts[name].servicePtr = new Amarok::AmarokScriptableServiceScript( scriptEngine );
     scriptObject = scriptEngine->newQObject( m_scripts[name].servicePtr );
-    m_global.setProperty( "ScriptableServiceManager", scriptObject );
+    m_global.setProperty( "ScriptableService", scriptObject );
     m_scripts[name].wrapperList.append( m_scripts[name].servicePtr );
 
     objectPtr = new Amarok::AmarokServicePluginManagerScript( scriptEngine );
@@ -935,6 +833,11 @@ ScriptManager::startScriptEngine( QString name )
     m_global.setProperty( "Playlist", scriptObject );
     m_scripts[name].wrapperList.append( objectPtr );
 
+    objectPtr = new Amarok::AmarokLyricsScript( scriptEngine );
+    scriptObject = scriptEngine->newQObject( objectPtr );
+    m_global.setProperty( "Lyrics", scriptObject );
+    m_scripts[name].wrapperList.append( objectPtr );
+
     objectPtr = new Amarok::AmarokStatusbarScript( scriptEngine );
     scriptObject = scriptEngine->newQObject( objectPtr );
     m_global.property( "Window" ).setProperty( "Statusbar", scriptObject );
