@@ -25,7 +25,7 @@
 #include "EngineObserver.h"   //baseclass
 #include "MainWindow.h"
 #include "scriptengine/AmarokScript.h"
-#include "scriptengine/AmarokScriptableServiceManagerScript.h"
+#include "scriptengine/AmarokScriptableServiceScript.h"
 #include "ui_ScriptManagerBase.h"
 
 #include <KDialog>      //baseclass
@@ -49,11 +49,9 @@ class AMAROK_EXPORT ScriptManager : public KDialog, public EngineObserver
     Q_OBJECT
 
     public:
-        explicit ScriptManager( QWidget *parent = 0, const char *name = 0 );
+        static ScriptManager* instance() { return s_instance ? s_instance : new ScriptManager( The::mainWindow() ); }
         virtual ~ScriptManager();
 
-        static ScriptManager* instance() { return s_instance ? s_instance : new ScriptManager( MainWindow::self() ); }
-
         /**
          * Runs the script with the given name. Used by the DCOP handler.
          * @param name The name of the script.
@@ -86,22 +84,9 @@ class AMAROK_EXPORT ScriptManager : public KDialog, public EngineObserver
         /** Sends a fetchLyrics notification to retrieve lyrics from a specific page */
         void notifyFetchLyricsByUrl( const QString& url );
 
-        /** Return name of the transcode script currently running, or QString::null if none */
-        QString transcodeScriptRunning() const;
-
-        /** Sends a transcode notification to all scripts */
-        void notifyTranscode( const QString& srcUrl, const QString& filetype );
-
-        /** Return name of the scoring script currently running, or QString::null if none */
-        QString scoreScriptRunning() const;
-
-        /** Returns a list of all scoring scripts */
-        QStringList scoreScripts() const;
-
         /** Asks the current score script to give a new score based on the parameters. */
         void requestNewScore( const QString &url, double prevscore, int playcount, int length, float percentage, const QString &reason );
 
-        void ServiceScriptInit( QString name );
         void ServiceScriptPopulate( QString name, int level, int parent_id, QString path, QString filter );
 
     signals:
@@ -126,6 +111,8 @@ class AMAROK_EXPORT ScriptManager : public KDialog, public EngineObserver
         void scriptFinished( QString name );
 
     private:
+        explicit ScriptManager( QWidget* parent );
+
         /** Returns all scripts of the given \p type */
         QStringList scriptsOfType( const QString &type ) const;
 
@@ -150,9 +137,6 @@ class AMAROK_EXPORT ScriptManager : public KDialog, public EngineObserver
 
         QTreeWidgetItem*       m_generalCategory;
         QTreeWidgetItem*       m_lyricsCategory;
-        QTreeWidgetItem*       m_scoreCategory;
-        QTreeWidgetItem*       m_transcodeCategory;
-        QTreeWidgetItem*       m_contextCategory;
         QTreeWidgetItem*       m_servicesCategory;
 
         bool                   m_installSuccess;
@@ -166,7 +150,7 @@ class AMAROK_EXPORT ScriptManager : public KDialog, public EngineObserver
             QTreeWidgetItem*                                li;
             bool                                            running;
             Amarok::AmarokScript*                           globalPtr;
-            Amarok::AmarokScriptableServiceManagerScript*   servicePtr;
+            Amarok::AmarokScriptableServiceScript*          servicePtr;
             QString                                         log;
             QList<QObject*>                                 guiPtrList;
             QList<QObject*>                                 wrapperList;
@@ -185,12 +169,6 @@ inline QStringList ScriptManager::lyricsScripts() const { return scriptsOfType(
 
 inline QString ScriptManager::lyricsScriptRunning() const { return scriptRunningOfType( "lyrics" ); }
 
-inline QString ScriptManager::transcodeScriptRunning() const { return scriptRunningOfType( "transcode" ); }
-
-inline QStringList ScriptManager::scoreScripts() const { return scriptsOfType( "score" ); }
-
-inline QString ScriptManager::scoreScriptRunning() const { return scriptRunningOfType( "score" ); }
-
 #endif /* AMAROK_SCRIPTMANAGER_H */
 
 
