@@ -35,6 +35,7 @@
 #include "TagGuesser.h"
 #include "trackpickerdialog.h"
 #include "ui_tagdialogbase.h"
+#include "UpdateCapability.h"
 
 #include <KApplication>
 #include <KComboBox>
@@ -55,6 +56,7 @@
 #include <QFile>
 #include <QLabel>
 #include <QLayout>
+#include <QMap>
 #include <QPair>
 #include <QPushButton>
 #include <QTimer>
@@ -110,7 +112,7 @@ TagDialog::TagDialog( Meta::TrackPtr track, QWidget *parent )
 }
 
 TagDialog::TagDialog( QueryMaker *qm )
-    :KDialog( MainWindow::self() )
+    :KDialog( The::mainWindow() )
     , m_currentCover()
     , m_tracks()
     , m_currentTrack()
@@ -120,7 +122,7 @@ TagDialog::TagDialog( QueryMaker *qm )
 {
     ui->setupUi( this );
     startDataQuery();
-    qm->startTrackQuery();
+    qm->setQueryType( QueryMaker::Track );
     connect( qm, SIGNAL( newResultReady( QString, Meta::TrackList ) ), this, SLOT( resultReady( QString, Meta::TrackList ) ), Qt::QueuedConnection );
     connect( qm, SIGNAL( queryDone() ), this, SLOT( queryDone() ), Qt::QueuedConnection );
     qm->run();
@@ -131,7 +133,17 @@ TagDialog::~TagDialog()
     DEBUG_BLOCK
 
     Amarok::config( "TagDialog" ).writeEntry( "CurrentTab", ui->kTabWidget->currentIndex() );
-    delete m_labelCloud;
+
+    // NOTE: temporary crash prevention.  TreeView should _always_ be updated
+    // if tags have changed.
+
+    if ( !m_tracks.isEmpty() )
+    {
+        delete m_labelCloud;
+    }
+    else
+        debug() << "Empty tracklist?  Must mean TreeView has not been updated!";
+
     delete ui;
 }
 
@@ -149,8 +161,14 @@ TagDialog::setTab( int id )
 void
 TagDialog::resultReady( const QString &collectionId, const Meta::TrackList &tracks )
 {
+    DEBUG_BLOCK
     Q_UNUSED( collectionId )
     m_tracks << tracks;
+    foreach( Meta::TrackPtr d_track, tracks )
+        {
+            if ( d_track )
+                debug() << "Artist is: " << d_track->artist()->name();
+        }
 }
 
 void
@@ -352,55 +370,78 @@ TagDialog::loadCover()
     ui->pixmap_cover->setMaximumSize( s, s );
 }
 
-
-void
-TagDialog::setFileNameSchemes() //SLOT
-{
-    FilenameLayoutDialog *dialog = new FilenameLayoutDialog(this);
-    dialog->exec();
-    delete dialog;
-}
-
-
 void
 TagDialog::guessFromFilename() //SLOT
 {
-     int cur = 0;
-
-    TagGuesser guesser( m_currentTrack->playableUrl().path() );
-    if( !guesser.title().isNull() )
-        ui->kLineEdit_title->setText( guesser.title() );
-
-    if( !guesser.artist().isNull() )
+    //was: setFilenameSchemes()
+    FilenameLayoutDialog *dialog = new FilenameLayoutDialog(this);
+    int dcode = dialog->exec();
+    QString schemeFromDialog = QString();       //note to self: see where to put it from an old revision
+    debug() << "FilenameLayoutDialog finished.";
+    schemeFromDialog = "";
+    if( dcode == KDialog::Accepted )
     {
-        cur = ui->kComboBox_artist->currentIndex();
-        ui->kComboBox_artist->setItemText( cur, guesser.artist() );
+        schemeFromDialog = dialog->getParsableScheme();
     }
-
-    if( !guesser.album().isNull() )
+    else
     {
-        cur = ui->kComboBox_album->currentIndex();
-        ui->kComboBox_album->setItemText( cur, guesser.album() );
+        debug() << "WARNING: Have not received a new scheme from FilenameLayoutDialog";
     }
-
-    if( !guesser.track().isNull() )
-        ui->qSpinBox_track->setValue( guesser.track().toInt() );
-    if( !guesser.comment().isNull() )
-        ui->kTextEdit_comment->setText( guesser.comment() );
-    if( !guesser.year().isNull() )
-        ui->qSpinBox_year->setValue( guesser.year().toInt() );
-
-    if( !guesser.composer().isNull() )
+    debug() << "I have " << schemeFromDialog << " as filename scheme to use.";
+    //legacy tagguesserconfigdialog code follows, needed to make everything hackishly work
+    //probably not the best solution
+    QStringList schemes;
+    schemes += schemeFromDialog;
+    
+    
+    if( schemeFromDialog == "" )
     {
-        cur = ui->kComboBox_composer->currentIndex();
-        ui->kComboBox_composer->setItemText( cur, guesser.composer() );
+        QMessageBox::warning(this, "No filename scheme to extract tags from", "Please choose a filename scheme to describe the layout of the filename(s) to extract the tags.");
     }
-
-    if( !guesser.genre().isNull() )
+    else
     {
-        cur = ui->kComboBox_genre->currentIndex();
-        ui->kComboBox_genre->setItemText( cur, guesser.genre() );
+        TagGuesser::setSchemeStrings( schemes );
+        debug() << "Sent scheme to TagGuesser, let's see what he does with it...";
+
+    //here starts the old guessFromFilename() code
+        int cur = 0;
+
+        TagGuesser guesser( m_currentTrack->playableUrl().path(), dialog );
+        if( !guesser.title().isNull() )
+            ui->kLineEdit_title->setText( guesser.title() );
+
+        if( !guesser.artist().isNull() )
+        {
+            cur = ui->kComboBox_artist->currentIndex();
+            ui->kComboBox_artist->setItemText( cur, guesser.artist() );
+        }
+
+        if( !guesser.album().isNull() )
+        {
+            cur = ui->kComboBox_album->currentIndex();
+            ui->kComboBox_album->setItemText( cur, guesser.album() );
+        }
+
+        if( !guesser.track().isNull() )
+            ui->qSpinBox_track->setValue( guesser.track().toInt() );
+        if( !guesser.comment().isNull() )
+            ui->kTextEdit_comment->setText( guesser.comment() );
+        if( !guesser.year().isNull() )
+            ui->qSpinBox_year->setValue( guesser.year().toInt() );
+
+        if( !guesser.composer().isNull() )
+        {
+            cur = ui->kComboBox_composer->currentIndex();
+            ui->kComboBox_composer->setItemText( cur, guesser.composer() );
+        }
+
+        if( !guesser.genre().isNull() )
+        {
+            cur = ui->kComboBox_genre->currentIndex();
+            ui->kComboBox_genre->setItemText( cur, guesser.genre() );
+        }
     }
+    delete dialog;
 }
 
 void
@@ -608,7 +649,6 @@ void TagDialog::init()
 #endif
 
     connect( ui->pushButton_guessTags, SIGNAL(clicked()), SLOT( guessFromFilename() ) );
-    connect( ui->pushButton_setFilenameSchemes, SIGNAL(clicked()), SLOT( setFileNameSchemes() ) );
 
     if( m_tracks.count() > 1 )
     {   //editing multiple tracks
@@ -638,10 +678,10 @@ TagDialog::startDataQuery()
     {
         return;
     }
-    QueryMaker *artist = coll->queryMaker()->startArtistQuery();
-    QueryMaker *album = coll->queryMaker()->startAlbumQuery();
-    QueryMaker *composer = coll->queryMaker()->startComposerQuery();
-    QueryMaker *genre = coll->queryMaker()->startGenreQuery();
+    QueryMaker *artist = coll->queryMaker()->setQueryType( QueryMaker::Artist );
+    QueryMaker *album = coll->queryMaker()->setQueryType( QueryMaker::Album );
+    QueryMaker *composer = coll->queryMaker()->setQueryType( QueryMaker::Composer );
+    QueryMaker *genre = coll->queryMaker()->setQueryType( QueryMaker::Genre );
     QList<QueryMaker*> queries;
     queries << artist << album << composer << genre;
     //MetaQueryMaker will run multiple different queries just fine as long as we do not use it
@@ -848,13 +888,11 @@ void TagDialog::readTags()
     {
         ui->pushButton_musicbrainz->show();
         ui->pushButton_guessTags->show();
-        ui->pushButton_setFilenameSchemes->show();
     }
     else
     {
        ui->pushButton_musicbrainz->hide();
        ui->pushButton_guessTags->hide();
-       ui->pushButton_setFilenameSchemes->hide();
     }
 
     // If it's a local file, write the directory to m_path, else disable the "open in konqui" button
@@ -907,7 +945,6 @@ TagDialog::setMultipleTracksMode()
 
     ui->pushButton_musicbrainz->hide();
     ui->pushButton_guessTags->hide();
-    ui->pushButton_setFilenameSchemes->hide();
 
     ui->locationLabel->hide();
     ui->kLineEdit_location->hide();
@@ -927,7 +964,6 @@ TagDialog::setSingleTrackMode()
 
     ui->pushButton_musicbrainz->show();
     ui->pushButton_guessTags->show();
-    ui->pushButton_setFilenameSchemes->show();
 
     ui->locationLabel->show();
     ui->kLineEdit_location->show();
@@ -1420,6 +1456,34 @@ TagDialog::saveTags()
             ec->setDiscNumber( data.value( Meta::Field::DISCNUMBER ).toInt() );
         ec->endMetaDataUpdate();
     }
+
+    // build a map, such that at least one track represents a unique collection
+
+    QMap<QString, Meta::TrackPtr> collectionsToUpdateMap;
+
+    foreach( Meta::TrackPtr track, m_tracks )
+    {
+        Meta::UpdateCapability *uc = track->as<Meta::UpdateCapability>();
+        if( !uc )
+        {
+            continue;
+        }
+
+        QString collId = track->collection()->collectionId();
+        
+        if( !collectionsToUpdateMap.contains( collId ) )
+            collectionsToUpdateMap.insert( collId, track );
+    }
+
+    // use the representative tracks to send updated signals
+
+    foreach( Meta::TrackPtr track, collectionsToUpdateMap.values() )
+    {
+        Meta::UpdateCapability *uc = track->as<Meta::UpdateCapability>();
+
+        uc->collectionUpdated();
+    }
+    
     //TODO: port 2.0
     /*
     QMap<QString, QStringList>::ConstIterator endLabels( newLabels.constEnd() );
