@@ -27,6 +27,12 @@
 #include "DynamicBiasWidgets.h"
 #include "QueryMaker.h"
 
+#include <QMutexLocker>
+
+Dynamic::Bias::Bias()
+    : m_active(true)
+{
+}
 
 QString
 Dynamic::Bias::description() const
@@ -47,6 +53,18 @@ Dynamic::Bias::widget( QWidget* parent )
 }
 
 
+void
+Dynamic::Bias::setActive( bool active )
+{
+    m_active = active;    
+}
+
+bool
+Dynamic::Bias::active()
+{
+    return m_active;
+}
+
 double
 Dynamic::Bias::reevaluate( double oldEnergy, const Meta::TrackList& oldPlaylist,
         Meta::TrackPtr newTrack, int newTrackPos, const Meta::TrackList& context )
@@ -84,21 +102,23 @@ Dynamic::CollectionDependantBias::collectionUpdated()
     m_needsUpdating = true;
 }
 
-Dynamic::GlobalBias::GlobalBias( double weight, QueryMaker* propertyQuery,
+Dynamic::GlobalBias::GlobalBias( double weight, QueryMaker* qm,
         XmlQueryReader::Filter filter )
-    : m_propertyQuery( propertyQuery )
+    : m_propertyQuery(0)
     , m_filter( filter )
 {
     setWeight( weight );
+    setQuery( qm );
 }
 
-Dynamic::GlobalBias::GlobalBias( Collection* coll, double weight, QueryMaker* propertyQuery,
+Dynamic::GlobalBias::GlobalBias( Collection* coll, double weight, QueryMaker* qm,
         XmlQueryReader::Filter filter )
     : CollectionDependantBias( coll )
-    , m_propertyQuery( propertyQuery )
+    , m_propertyQuery(0)
     , m_filter(filter)
 {
     setWeight( weight );
+    setQuery( qm );
 }
 
 PlaylistBrowserNS::BiasWidget*
@@ -130,6 +150,17 @@ Dynamic::GlobalBias::setWeight( double weight )
         m_weight = weight;
 }
 
+void
+Dynamic::GlobalBias::setQuery( QueryMaker* qm )
+{
+    DEBUG_BLOCK
+    QMutexLocker locker( &m_mutex );
+
+    qm->setQueryType( QueryMaker::Track );
+    delete m_propertyQuery;
+    m_propertyQuery = new BlockingQuery( qm );
+    collectionUpdated();
+}
 
 
 double
@@ -151,37 +182,52 @@ Dynamic::GlobalBias::energy( const Meta::TrackList& playlist, const Meta::TrackL
 double Dynamic::GlobalBias::reevaluate( double oldEnergy, const Meta::TrackList& oldPlaylist,
         Meta::TrackPtr newTrack, int newTrackPos, const Meta::TrackList& context )
 {
-    Q_UNUSED( newTrackPos );
-    Q_UNUSED( oldPlaylist );
     Q_UNUSED( context );
 
     double offset = 1.0 / (double)oldPlaylist.size();
 
-    if( trackSatisfies( newTrack ) )
+    bool prevSatisfied = trackSatisfies( oldPlaylist[newTrackPos] );
+
+    if( trackSatisfies( newTrack ) && !prevSatisfied )
+        return oldEnergy - offset;
+    else if( !trackSatisfies( newTrack ) && prevSatisfied )
         return oldEnergy + offset;
     else
-        return oldEnergy - offset;
+        return oldEnergy;
 }
 
 
 bool Dynamic::GlobalBias::trackSatisfies( Meta::TrackPtr t )
 {
+    QMutexLocker locker( &m_mutex );
     return m_property.contains( t );
 }
 
 
 void Dynamic::GlobalBias::update()
 {
+    DEBUG_BLOCK
+
+    QMutexLocker locker( &m_mutex );
+
     if( !m_needsUpdating )
         return;
 
-    m_propertyQuery->startTrackQuery();
-    BlockingQuery bq( m_propertyQuery );
-
-    bq.startQuery();
+    m_propertyQuery->resetResults();
+    m_propertyQuery->startQuery();
 
     m_property.clear();
-    QList<Meta::TrackList> trackLists = bq.tracks().values();
+
+    QHash<QString,Meta::TrackList> trackLists = m_propertyQuery->tracks();
+
+    int size = 0;
+    foreach( Meta::TrackList ts, trackLists )
+    {
+        size += ts.size();
+    }
+
+    m_property.reserve( size );
+
     foreach( Meta::TrackList ts, trackLists )
     {
         foreach( Meta::TrackPtr t, ts )
@@ -192,3 +238,4 @@ void Dynamic::GlobalBias::update()
 
     m_needsUpdating = false;
 }
+
