@@ -24,11 +24,13 @@
 #include "Meta.h"
 #include "collection/support/XmlQueryReader.h"
 
+#include <QMutex>
 #include <QObject>
 #include <QSet>
 
 class Collection;
 class QueryMaker;
+class BlockingQuery;
 
 namespace PlaylistBrowserNS
 {
@@ -46,17 +48,27 @@ namespace Dynamic
     class Bias
     {
         public:
+            Bias();
             virtual ~Bias() {}
 
             QString description() const;
             void setDescription( const QString& );
 
+            /**
+             * Create a widget appropriate for editing the bias.
+             */
             virtual PlaylistBrowserNS::BiasWidget* widget( QWidget* parent = 0 );
 
+            /**
+             * Should the bias be considered or ignored by the playlist?
+             */
+            void setActive( bool );
+            bool active();
+
 
             /**
              * Returns a value in the range [-1,1]. (The sign is not considered,
-             * but it may be usefull to return negative numbers for
+             * but it may be useful to return negative numbers for
              * implementing reevaluate.) Playlist generation is being
              * treated as a minimization problem, so 0 means the bias is completely
              * satisfied, (+/-)1 that it is not satisfied at all. The tracks that
@@ -73,6 +85,7 @@ namespace Dynamic
                     Meta::TrackPtr newTrack, int newTrackPos, const Meta::TrackList& context );
 
         protected:
+            bool m_active;
             QString m_description;
     };
 
@@ -100,6 +113,7 @@ namespace Dynamic
 
         protected:
             bool m_needsUpdating;
+            QMutex m_mutex;
     };
 
 
@@ -116,6 +130,8 @@ namespace Dynamic
             GlobalBias( Collection* coll, double weight, QueryMaker* propertyQuery,
                     XmlQueryReader::Filter filter = XmlQueryReader::Filter() );
 
+            void setQuery( QueryMaker* );
+
             PlaylistBrowserNS::BiasWidget* widget( QWidget* parent = 0 );
             XmlQueryReader::Filter& filter();
 
@@ -133,7 +149,7 @@ namespace Dynamic
         private:
             double m_weight; /// range: [0,1]
             QSet<Meta::TrackPtr> m_property;
-            QueryMaker* m_propertyQuery;
+            BlockingQuery* m_propertyQuery;
             XmlQueryReader::Filter m_filter;
     };
 }
