@@ -20,9 +20,13 @@
 
 
 #include "BiasedPlaylist.h"
+#include "BlockingQuery.h"
 #include "Collection.h"
+#include "CollectionManager.h"
 #include "Debug.h"
+#include "MetaQueryMaker.h"
 #include "playlist/PlaylistModel.h"
+#include "StatusBar.h"
 
 #include <threadweaver/ThreadWeaver.h>
 
@@ -49,6 +53,14 @@ Dynamic::BiasedPlaylist::BiasedPlaylist(
     setTitle( title );
 }
 
+void
+Dynamic::BiasedPlaylist::requestAbort()
+{
+    if( m_solver )
+        m_solver->requestAbort();
+    m_solverLoop.exit( -1 );
+}
+
 
 void
 Dynamic::BiasedPlaylist::setContext( Meta::TrackList context )
@@ -57,17 +69,35 @@ Dynamic::BiasedPlaylist::setContext( Meta::TrackList context )
 }
 
 void
-Dynamic::BiasedPlaylist::startSolver()
+Dynamic::BiasedPlaylist::startSolver( bool withStatusBar )
 {
     DEBUG_BLOCK
 
-    if( m_solver ) return;
+    if( !m_solver )
+    {
+        updateBiases();
+        m_solver = new BiasSolver( 
+                BUFFER_SIZE, m_biases, &m_randomSource, m_context );
+        connect( m_solver, SIGNAL(done(ThreadWeaver::Job*)),
+                this, SLOT(solverFinished(ThreadWeaver::Job*)),
+                Qt::DirectConnection );
 
-    m_solver = new BiasSolver( BUFFER_SIZE, m_biases, &m_randomSource, m_context );
-    connect( m_solver, SIGNAL(done(ThreadWeaver::Job*)),
-            this, SLOT(solverFinished(ThreadWeaver::Job*)),
-            Qt::DirectConnection );
-    ThreadWeaver::Weaver::instance()->enqueue( m_solver );
+        ThreadWeaver::Weaver::instance()->enqueue( m_solver );
+    }
+
+    if( withStatusBar )
+    {
+        The::statusBar()->newProgressOperation( m_solver );
+        The::statusBar()->shortMessage( i18n("Generating playlist...") );
+
+        connect( m_solver, SIGNAL(statusUpdate(int)), SLOT(updateStatus(int)) );
+    }
+}
+
+void
+Dynamic::BiasedPlaylist::updateStatus( int progress )
+{
+    The::statusBar()->setProgress( m_solver, progress );
 }
 
 
@@ -88,9 +118,13 @@ Dynamic::BiasedPlaylist::getTrack()
         if( m_backbuffer.isEmpty() )
         {
             // we need it now !
-            if( m_context.isEmpty() ) getContext();
-            startSolver();
-            m_solverLoop.exec();
+            debug() << "BiasedPlaylist: waiting for results.";
+            if( m_context.isEmpty() )
+                getContext();
+            startSolver( true );
+            int r = m_solverLoop.exec();
+            if( r == -1 )
+                return Meta::TrackPtr();
         }
 
         m_context = m_buffer;
@@ -119,6 +153,7 @@ Dynamic::BiasedPlaylist::recalculate()
     startSolver();
 }
 
+
 QList<Dynamic::Bias*>&
 Dynamic::BiasedPlaylist::biases()
 {
@@ -135,11 +170,31 @@ Dynamic::BiasedPlaylist::biases() const
 void
 Dynamic::BiasedPlaylist::solverFinished( ThreadWeaver::Job* job )
 {
+    bool success;
+    The::statusBar()->endProgressOperation( m_solver );
     m_backbuffer = m_solver->solution();
+    success = m_solver->success();
     ThreadWeaver::Weaver::instance()->dequeue( job );
     job->deleteLater();
     m_solver = 0;
-    m_solverLoop.exit();
+    if( success )
+        m_solverLoop.exit(0);
+    else
+        m_solverLoop.exit(-1);
+}
+
+void
+Dynamic::BiasedPlaylist::updateBiases()
+{
+    CollectionDependantBias* cb;
+    foreach( Bias* b, m_biases )
+    {
+        if( (cb = dynamic_cast<CollectionDependantBias*>( b ) ) )
+        {
+            if( cb->needsUpdating() )
+                cb->update();
+        }
+    }
 }
 
 void
