@@ -22,6 +22,7 @@
 //BEGIN Includes
 #include "FileBrowser.h"
 
+#include "Debug.h"
 #include "collection/CollectionManager.h"
 #include "filebrowser/MyDirOperator.h"
 #include "filebrowser/kbookmarkhandler.h"
@@ -71,8 +72,8 @@ FileBrowser::ToolBar::~ToolBar()
 
 //BEGIN Constructor/destructor
 
-FileBrowser::Widget::Widget( const char * name )
-    : KVBox ( 0 ),
+FileBrowser::Widget::Widget( const char * name , QWidget *parent )
+    : KVBox ( parent ),
       m_toolbar( 0 ),
       m_actionCollection( 0 ),
       m_bookmarkHandler( 0 ),
@@ -84,6 +85,8 @@ FileBrowser::Widget::Widget( const char * name )
       m_filter( 0 ),
       m_btnFilter( 0 )
 {
+  DEBUG_BLOCK
+
   setObjectName(name);
   m_actionCollection = new KActionCollection( this );
 
@@ -118,6 +121,7 @@ FileBrowser::Widget::Widget( const char * name )
   connect( m_btnFilter, SIGNAL( clicked() ), this, SLOT( btnFilterClick() ) );
 
   connect( m_filter, SIGNAL( activated(const QString&) ), SLOT( slotFilterChange(const QString&) ) );
+  connect( m_filter, SIGNAL( editTextChanged(const QString&) ), SLOT( slotFilterChange(const QString&) ) );
   connect( m_filter, SIGNAL( returnPressed(const QString&) ), m_filter, SLOT( addToHistory(const QString&) ) );
 
   m_dir = new MyDirOperator(KUrl(QDir::home().path()), this);
@@ -204,7 +208,10 @@ FileBrowser::Widget::Widget( const char * name )
 }
 
 FileBrowser::Widget::~Widget()
-{}
+{
+    DEBUG_BLOCK
+}
+
 //END Constroctor/Destrctor
 
 //BEGIN Public Methods
@@ -329,6 +336,7 @@ void FileBrowser::Widget::slotFilterChange( const QString & nf )
   }
   else
   {
+    f = "*" + f + "*"; // add regexp matches surrounding the filter
     m_dir->setNameFilter( f );
     lastFilter = f;
     m_btnFilter->setToolTip( i18n("Clear filter") );
