@@ -16,6 +16,8 @@
 */
 
 #include "MyDirOperator.h"
+
+#include "Debug.h"
 #include "MainWindow.h"
 
 #include <KActionCollection>
@@ -23,12 +25,20 @@
 
 #include <QDir>
 
-MyDirOperator::MyDirOperator ( const KUrl &url, QWidget *parent )
+MyDirOperator::MyDirOperator( const KUrl &url, QWidget *parent )
     : KDirOperator( url, parent )
 {
      MyDirLister* dirlister = new MyDirLister( true );
-     dirlister->setMainWindow( MainWindow::self() );
+     dirlister->setMainWindow( The::mainWindow() );
      setDirLister( dirlister );
 }
 
+
+MyDirOperator::~MyDirOperator()
+{
+    DEBUG_BLOCK
+}
+
+
 #include "MyDirOperator.moc"
+
