@@ -17,11 +17,9 @@
 
 #include "Amarok.h"
 #include "App.h"
-#include "CrashHandler.h"
 #include "metadata/tplugins.h"
 
 #include <KAboutData>
-#include <KCrash>
 #include <KCmdLineArgs>
 #include <KDebug>
 
@@ -114,18 +112,17 @@ int main( int argc, char *argv[] )
     App::initCliArgs();
     KUniqueApplication::addCmdLineOptions();
 
-    if (!KUniqueApplication::start()) {
-        fprintf(stderr, "Amarok is already running!\n");
+#ifndef _MSC_VER // Temporary
+    #warning "REMOVE NonUniqueInstance FLAG BEFORE RELEASE!"
+    #warning "It's a convenience hack for developing, so that we can start multiple Amarok instances."
+#endif
+    if( !KUniqueApplication::start() ) {
+    //if( !KUniqueApplication::start( KUniqueApplication::NonUniqueInstance ) ) {
+        fprintf( stderr, "Amarok is already running!\n" );
         return 0;
     }
 
     App app;
-
-#ifdef Q_WS_X11
-    #ifndef AMAROK_USE_DRKONQI
-    KCrash::setCrashHandler( Amarok::Crash::crashHandler );
-    #endif
-#endif
-
     return app.exec();
 }
+
