@@ -24,17 +24,15 @@
 
 AMAROK_EXPORT_PLUGIN( GenericMediaDevice )
 
-#include "amarok.h"
-#include "debug.h"
+#include "Amarok.h"
+#include "Debug.h"
 #include "meta/file/File.h"
-#include "collectiondb.h"
 #include "collectionbrowser/CollectionTreeItemModel.h"
 #include "collection/CollectionManager.h"
+#include "collection/SqlStorage.h"
 #include "k3bexporter.h"
 #include "playlist/PlaylistModel.h"
-#include "podcastbundle.h"
-#include "statusbar/ContextStatusBar.h"
-#include "TheInstances.h"
+#include "statusbar/StatusBar.h"
 #include "transferdialog.h"
 #include "genericmediadeviceconfigdialog.h"
 
@@ -367,7 +365,7 @@ GenericMediaDevice::openDevice( bool /*silent*/ )
     DEBUG_BLOCK
     if( m_mountPoint.isEmpty() )
     {
-        Amarok::ContextStatusBar::instance()->longMessage( i18n( "Devices handled by this plugin must be mounted first.\n"
+        The::statusBar()->longMessage( i18n( "Devices handled by this plugin must be mounted first.\n"
                                                           "Please mount the device and click \"Connect\" again." ),
                                                     KDE::StatusBar::Sorry );
         return false;
@@ -535,7 +533,7 @@ GenericMediaDevice::buildDestination( const QString &format, const Meta::TrackPt
 
     //these additional columns from MetaBundle were used before but haven't
     //been ported yet. Do they need to be?
-    //Bpm,Directory,Type,Length,Bitrate,SampleRate,Rating,Mood,Filesize
+    //Bpm,Directory,Bitrate,SampleRate,Mood
     args["title"] = cleanPath( track->prettyName() );
     args["composer"] = cleanPath( track->composer()->prettyName() );
     args["year"] = cleanPath( track->year()->prettyName() );
@@ -546,7 +544,10 @@ GenericMediaDevice::buildDestination( const QString &format, const Meta::TrackPt
     args["artist"] = artist;
     args["albumartist"] = albumartist;
     args["initial"] = albumartist.mid( 0, 1 ).toUpper();
-    args["filetype"] = track->url().section( ".", -1 ).toLower();
+    args["filetype"] = track->type();
+    args["rating"] = track->rating();
+    args["filesize"] = track->filesize();
+    args["length"] = track->length();
     QString trackNum;
     if ( track->trackNumber() )
         trackNum = QString("%1").arg( track->trackNumber(), 2, 10, QChar('0') );
@@ -598,15 +599,15 @@ GenericMediaDevice::checkAndBuildLocation( const QString& location )
         }
     }
 }
-
+/* //PORT to meta
 QString
 GenericMediaDevice::buildPodcastDestination( const PodcastEpisodeBundle *bundle )
 {
     QString location = m_podcastLocation.endsWith('/') ? m_podcastLocation : m_podcastLocation + '/';
     // get info about the PodcastChannel
     QString parentUrl = bundle->parent().url();
-    QString sql = "SELECT title,parent FROM podcastchannels WHERE url='" + CollectionDB::instance()->escapeString( parentUrl ) + "';";
-    QStringList values = CollectionDB::instance()->query( sql );
+    QString sql = "SELECT title,parent FROM podcastchannels WHERE url='" + CollectionManager::instance()->sqlStorage()->escape( parentUrl ) + "';";
+    QStringList values = CollectionManager::instance()->sqlStorage()->query( sql );
     QString channelTitle;
     int parent = 0;
     channelTitle = values.first();
@@ -616,7 +617,7 @@ GenericMediaDevice::buildPodcastDestination( const PodcastEpisodeBundle *bundle
     QString name;
     while ( parent > 0 )
     {
-        values = CollectionDB::instance()->query( sql.arg( parent ) );
+        values = CollectionManager::instance()->sqlStorage()->query( sql.arg( parent ) );
         name    =    values.first();
         parent  =   values.last().toInt();
         location += cleanPath( name ) + '/';
@@ -624,7 +625,7 @@ GenericMediaDevice::buildPodcastDestination( const PodcastEpisodeBundle *bundle
     location += cleanPath( channelTitle ) + '/' + cleanPath( bundle->localUrl().fileName() );
     return location;
 }
-
+*/
 
 MediaItem *
 GenericMediaDevice::copyTrackToDevice( const Meta::TrackPtr track )
@@ -857,7 +858,8 @@ GenericMediaDevice::addTrackToList( int type, KUrl url, int /*size*/ )
         if( baseName.endsWith( "mp3", Qt::CaseInsensitive ) || baseName.endsWith( "wma", Qt::CaseInsensitive ) ||
             baseName.endsWith( "wav", Qt::CaseInsensitive ) || baseName.endsWith( "ogg", Qt::CaseInsensitive ) ||
             baseName.endsWith( "asf", Qt::CaseInsensitive ) || baseName.endsWith( "flac", Qt::CaseInsensitive ) ||
-            baseName.endsWith( "aac", Qt::CaseInsensitive ) || baseName.endsWith( "m4a", Qt::CaseInsensitive ) )
+            baseName.endsWith( "aac", Qt::CaseInsensitive ) || baseName.endsWith( "m4a", Qt::CaseInsensitive ) ||
+            baseName.endsWith( "oga", Qt::CaseInsensitive ) )
 
             newItem->getViewItem()->setType( MediaItem::TRACK );
 
@@ -930,7 +932,7 @@ GenericMediaDevice::rmbPressed( Q3ListViewItem* qitem, const QPoint& point, int
     if ( item )
     {
         K3PopupMenu menu( m_view );
-        menu.insertItem( KIcon( "view-media-playlist-amarok" ), i18n( "&Load" ), LOAD );
+        menu.insertItem( KIcon( "view-media-playlist-amarok" ), i18nc( "Replace the current playlist with this","&Load" ), LOAD );
         menu.insertItem( KIcon( "1downarrow" ), i18n( "&Append to Playlist" ), APPEND );
         menu.insertItem( KIcon( "media-seek-forward-amarok" ), i18n( "&Queue Tracks" ), QUEUE );
         menu.insertSeparator();
