@@ -24,27 +24,27 @@
 
 #define DEBUG_PREFIX "IpodMediaDevice"
 
-#include "config-amarok.h"
 #include "ipodmediadevice.h"
+#include <config-amarok.h>
 //Added by qt3to4:
 #include <Q3PtrList>
 
 AMAROK_EXPORT_PLUGIN( IpodMediaDevice )
 
-#include <debug.h>
+#include <Debug.h>
 #include <metabundle.h>
 #include <collectiondb.h>
-#include <statusbar/ContextStatusBar.h>
+#include <statusbar/StatusBar.h>
 #include <k3bexporter.h>
 #include <playlist.h>
 #include <playlistbrowser.h>
-#include <tagdialog.h>
+#include <TagDialog.h>
 #include <threadmanager.h>
 #include <metadata/tplugins.h>
 #include <metadata/tfile_helper.h>
 #include <hintlineedit.h>
 
-#include <kactionclasses.h>
+#include <kActionClasses.h>
 #include <kapplication.h>
 #include <kmountpoint.h>
 #include <kpushbutton.h>
@@ -315,14 +315,14 @@ IpodMediaDevice::IpodMediaDevice()
                             gen );
                 }
                 if( info->capacity > 0.f )
-                    gen->insertItem( i18n( "%1 GB %2 (x%3)" )
-                            .arg( QString::number( info->capacity ),
+                    gen->insertItem( i18n( "%1 GB %2 (x%3)",
+                                QString::number( info->capacity ),
                                 itdb_info_get_ipod_model_name_string( info->ipod_model ),
                                 info->model_number ),
                             index );
                 else
-                    gen->insertItem( i18n( "%1 (x%2)" )
-                            .arg( itdb_info_get_ipod_model_name_string( info->ipod_model ),
+                    gen->insertItem( i18n( "%1 (x%2)",
+                                itdb_info_get_ipod_model_name_string( info->ipod_model ),
                                 info->model_number ),
                             index );
             }
@@ -384,21 +384,22 @@ IpodMediaDevice::slotIpodAction( int id )
                     {
                         g_error_free(err);
                         //FIXME: update i18n files for next message
-                        Amarok::ContextStatusBar::instance()->longMessage( 
-                                i18n( "Could not write SysInfo file to iPod (check the permissions of the file \"%1\" on your iPod)" ).arg( itunesDir( "Device:SysInfo" ) ) );
+                        The::statusBar()->longMessage( 
+                                i18n( "Could not write SysInfo file to iPod (check the permissions of the file \"%1\" on your iPod)",
+                                      itunesDir( "Device:SysInfo" ) ) );
 
                         //FIXME: update i18n files for next message
-                        Amarok::ContextStatusBar::instance()->shortMessage(
-                                i18n( "Unable to set iPod model to %1 GB %2 (x%3)" )
-                                .arg( QString::number( table[index].capacity ),
+                        The::statusBar()->shortMessage(
+                                i18n( "Unable to set iPod model to %1 GB %2 (x%3)",
+                                    QString::number( table[index].capacity ),
                                     itdb_info_get_ipod_model_name_string( table[index].ipod_model ),
                                     table[index].model_number ) );
                     } 
                     else
                     {
-                        Amarok::ContextStatusBar::instance()->shortMessage(
-                                i18n( "Setting iPod model to %1 GB %2 (x%3)" )
-                                .arg( QString::number( table[index].capacity ),
+                        The::statusBar()->shortMessage(
+                                i18n( "Setting iPod model to %1 GB %2 (x%3)",
+                                    QString::number( table[index].capacity ),
                                     itdb_info_get_ipod_model_name_string( table[index].ipod_model ),
                                     table[index].model_number ) );
                     }
@@ -565,7 +566,7 @@ IpodMediaDevice::updateTrackInDB( IpodMediaItem *item, const QString &pathname,
 
         track->flag4 = 0x01; // also show description on iPod
         QString plaindesc = podcastInfo->description;
-        plaindesc.replace( QRegExp("<[^>]*>"), "" );
+        plaindesc.remove( QRegExp("<[^>]*>") );
         track->description = g_strdup( plaindesc.toUtf8() );
         track->subtitle = g_strdup( plaindesc.toUtf8() );
         track->podcasturl = g_strdup( podcastInfo->url.toUtf8() );
@@ -683,7 +684,7 @@ IpodMediaDevice::copyTrackToDevice(const MetaBundle &bundle)
     }
     if ( !dir.exists() )
     {
-        Amarok::ContextStatusBar::instance()->longMessage(
+        The::statusBar()->longMessage(
                 i18n( "Media Device: Creating directory for file %1 failed", url.path() ),
                 KDE::StatusBar::Error );
         return NULL;
@@ -723,11 +724,11 @@ void
 IpodMediaDevice::synchronizeDevice()
 {
     debug() << "Syncing iPod!";
-    Amarok::ContextStatusBar::instance()->newProgressOperation( this )
+    The::statusBar()->newProgressOperation( this )
         .setDescription( i18n( "Flushing iPod filesystem transfer cache" ) )
         .setTotalSteps( 1 );
     writeITunesDB();
-    Amarok::ContextStatusBar::instance()->endProgressOperation( this );
+    The::statusBar()->endProgressOperation( this );
 }
 
 MediaItem *
@@ -996,8 +997,8 @@ IpodMediaDevice::createLockFile( bool silent )
                         KGuiItem(i18n("&Remove"), "editdelete"), QString(), KMessageBox::Dangerous )
                     == KMessageBox::Continue )
             {
-                msg = i18n( "Media Device: removing lockfile %1 failed: %2. " )
-                    .arg( lockFilePath, m_lockFile->errorString() );
+                msg = i18n( "Media Device: removing lockfile %1 failed: %2. ",
+                          lockFilePath, m_lockFile->errorString() );
                 ok = m_lockFile->remove();
             }
             else
@@ -1010,8 +1011,10 @@ IpodMediaDevice::createLockFile( bool silent )
     if( ok && !m_lockFile->open( QIODevice::WriteOnly ) )
     {
         ok = false;
-        msg = i18n( "Media Device: failed to create lockfile on iPod mounted at %1: %2" )
-            .arg(mountPoint(), m_lockFile->errorString());
+        msg = i18n( "Media Device: failed to create lockfile on iPod mounted at %1: %2",
+                    mountPoint(),
+                    m_lockFile->errorString()
+                  );
     }
 
     if( ok )
@@ -1021,7 +1024,7 @@ IpodMediaDevice::createLockFile( bool silent )
     m_lockFile = 0;
 
     if( !msg.isEmpty() )
-        Amarok::ContextStatusBar::instance()->longMessage( msg, KDE::StatusBar::Sorry );
+        The::statusBar()->longMessage( msg, KDE::StatusBar::Sorry );
     return false;
 }
 
@@ -1031,7 +1034,7 @@ IpodMediaDevice::initializeIpod()
     QDir dir( mountPoint() );
     if( !dir.exists() )
     {
-        Amarok::ContextStatusBar::instance()->longMessage(
+        The::statusBar()->longMessage(
                 i18n("Media device: Mount point %1 does not exist", mountPoint() ),
                 KDE::StatusBar::Error );
         return false;
@@ -1084,7 +1087,7 @@ IpodMediaDevice::initializeIpod()
     if( !writeITunesDB( false ) )
         return false;
 
-    Amarok::ContextStatusBar::instance()->longMessage(
+    The::statusBar()->longMessage(
             i18n("Media Device: Initialized iPod mounted at %1", mountPoint() ),
             KDE::StatusBar::Information );
 
@@ -1105,7 +1108,7 @@ IpodMediaDevice::openDevice( bool silent )
 
     if( m_itdb )
     {
-        Amarok::ContextStatusBar::instance()->longMessage(
+        The::statusBar()->longMessage(
                 i18n("Media Device: iPod at %1 already opened", mountPoint() ),
                 KDE::StatusBar::Sorry );
         return false;
@@ -1168,7 +1171,7 @@ IpodMediaDevice::openDevice( bool silent )
     {
         if( !silent )
         {
-            Amarok::ContextStatusBar::instance()->longMessage(
+            The::statusBar()->longMessage(
                     i18n("Media Device: No mounted iPod found" ),
                     KDE::StatusBar::Sorry );
         }
@@ -1192,7 +1195,7 @@ IpodMediaDevice::openDevice( bool silent )
                     m_itdb = 0;
                 }
 
-                Amarok::ContextStatusBar::instance()->longMessage(
+                The::statusBar()->longMessage(
                         i18n("Media Device: Failed to initialize iPod mounted at %1", mountPoint() ),
                         KDE::StatusBar::Sorry );
 
@@ -1228,7 +1231,7 @@ IpodMediaDevice::openDevice( bool silent )
             if( !dir.exists() )
             {
                 debug() << "failed to create hash dir " << real;
-                Amarok::ContextStatusBar::instance()->longMessage(
+                The::statusBar()->longMessage(
                         i18n( "Media device: Failed to create directory %1", real ),
                         KDE::StatusBar::Error );
                 return false;
@@ -1362,8 +1365,8 @@ IpodMediaDevice::detectModel()
             gchar *fwid = itdb_device_get_sysinfo( m_itdb->device, "FirewireGuid" );
             if( !fwid )
             {
-                Amarok::StatusBar::instance()->longMessage(
-                        i18n("Your iPod's Firewire GUID is required for correctly updating its music database, but it is not known. See %1 for more information.").arg( "http://amarok.kde.org/wiki/Media_Device:IPod" ) );
+                The::statusBar()->longMessage(
+                                            i18n("Your iPod's Firewire GUID is required for correctly updating its music database, but it is not known. See http://amarok.kde.org/wiki/Media_Device:IPod for more information." ) );
             }
             else
                g_free( fwid );
@@ -1372,7 +1375,7 @@ IpodMediaDevice::detectModel()
     else
     {
         debug() << "iPod type detection failed, no video support";
-        Amarok::ContextStatusBar::instance()->longMessage(
+        The::statusBar()->longMessage(
                 i18n("iPod type detection failed: no support for iPod Shuffle, for artwork or video") );
         guess = true;
     }
@@ -1474,7 +1477,7 @@ IpodMediaDevice::updateArtwork()
         }
     }
 
-    Amarok::ContextStatusBar::instance()->shortMessage(
+    The::statusBar()->shortMessage(
             i18np( "Updated artwork for one track", "Updated artwork for %1 tracks", updateCount ) );
 
     if(!m_dbChanged)
@@ -1538,7 +1541,7 @@ IpodMediaDevice::checkIntegrity()
 
     updateRootItems();
 
-    Amarok::ContextStatusBar::instance()->shortMessage(
+    The::statusBar()->shortMessage(
             i18n( "Scanning for stale and orphaned tracks finished" ) );
 
     return true;
@@ -1970,7 +1973,7 @@ IpodMediaDevice::writeITunesDB( bool threaded )
         }
         else
         {
-            Amarok::ContextStatusBar::instance()->longMessage(
+            The::statusBar()->longMessage(
                     i18n("Media device: failed to write iPod database"),
                     KDE::StatusBar::Error );
         }
@@ -2233,8 +2236,8 @@ IpodMediaDevice::rmbPressed( Q3ListViewItem* qitem, const QPoint& point, int )
         }
         else
         {
-            menu.insertItem( SmallIconSet( "view-media-playlist-amarok" ), i18n( "&Load" ), LOAD );
-            menu.insertItem( SmallIconSet( "list-add-amarok" ), i18n( "&Append to Playlist" ), APPEND );
+            menu.insertItem( SmallIconSet( "view-media-playlist-amarok" ), i18nc( "Replace current playlist with this", "&Load" ), LOAD );
+            menu.insertItem( SmallIconSet( "media-track-add-amarok" ), i18n( "&Append to Playlist" ), APPEND );
             menu.insertItem( SmallIconSet( "media-seek-forward-amarok" ), i18n( "&Queue Tracks" ), QUEUE );
         }
         menu.insertSeparator();
@@ -2481,7 +2484,7 @@ IpodMediaDevice::rmbPressed( Q3ListViewItem* qitem, const QPoint& point, int )
                     }
 
                     if( dupes > 0 )
-                        Amarok::ContextStatusBar::instance()->shortMessage( i18np(
+                        The::statusBar()->shortMessage( i18np(
                                     "One duplicate track not added to database",
                                     "%1 duplicate tracks not added to database", dupes ) );
                 }
