@@ -42,7 +42,8 @@ namespace Meta
                         , Organisable = 7
                         , SourceInfo = 8
                         , CurrentTrackActions = 9
-                        , StreamInfo = 10};
+                        , StreamInfo = 10
+                        , Updatable = 11};
 
             virtual ~Capability();
 
