@@ -1,5 +1,6 @@
-/* This file is part of the KDE project
+/* This file is part of the Amarok project
    Copyright (C) 2007 Maximilian Kossick <maximilian.kossick@googlemail.com>
+   Copyright (C) 2008 Mark Kretschmann <kretschmann@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -46,26 +47,37 @@ namespace Meta
     class Composer;
     class Year;
 
-
     typedef KSharedPtr<MetaBase> DataPtr;
-    typedef QList<DataPtr > DataList;
-
+    typedef QList<DataPtr> DataList;
     typedef KSharedPtr<Track> TrackPtr;
-    typedef QList<TrackPtr > TrackList;
+    typedef QList<TrackPtr> TrackList;
     typedef KSharedPtr<Artist> ArtistPtr;
-    typedef QList<ArtistPtr > ArtistList;
+    typedef QList<ArtistPtr> ArtistList;
     typedef KSharedPtr<Album> AlbumPtr;
-    typedef QList<AlbumPtr > AlbumList;
+    typedef QList<AlbumPtr> AlbumList;
     typedef KSharedPtr<Composer> ComposerPtr;
     typedef QList<ComposerPtr> ComposerList;
     typedef KSharedPtr<Genre> GenrePtr;
-    typedef QList<GenrePtr > GenreList;
+    typedef QList<GenrePtr> GenreList;
     typedef KSharedPtr<Year> YearPtr;
-    typedef QList<YearPtr > YearList;
+    typedef QList<YearPtr> YearList;
 
     class AMAROK_EXPORT Observer
     {
         public:
+            void subscribeTo( TrackPtr );
+            void unsubscribeFrom( TrackPtr );
+            void subscribeTo( ArtistPtr );
+            void unsubscribeFrom( ArtistPtr );
+            void subscribeTo( AlbumPtr );
+            void unsubscribeFrom( AlbumPtr );
+            void subscribeTo( ComposerPtr );
+            void unsubscribeFrom( ComposerPtr );
+            void subscribeTo( GenrePtr );
+            void unsubscribeFrom( GenrePtr );
+            void subscribeTo( YearPtr );
+            void unsubscribeFrom( YearPtr );
+
             /** This method is called when the metadata of a track has changed.
                 The called class may not cache the pointer */
             virtual void metadataChanged( Track *track );
@@ -75,21 +87,39 @@ namespace Meta
             virtual void metadataChanged( Composer *composer );
             virtual void metadataChanged( Year *year );
             virtual ~Observer();
+
+        private:
+            QSet<TrackPtr> m_trackSubscriptions;
+            QSet<ArtistPtr> m_artistSubscriptions;
+            QSet<AlbumPtr> m_albumSubscriptions;
+            QSet<ComposerPtr> m_composerSubscriptions;
+            QSet<GenrePtr> m_genreSubscriptions;
+            QSet<YearPtr> m_yearSubscriptions;
     };
 
     class AMAROK_EXPORT MetaBase : public QSharedData
     {
+        friend class Observer;
+
+        Q_PROPERTY( QString name READ name )
+        Q_PROPERTY( QString prettyName READ prettyName )
+        Q_PROPERTY( QString fullPrettyName READ fullPrettyName )
+        Q_PROPERTY( QString sortableName READ sortableName )
+
         public:
+            MetaBase() {}
             virtual ~MetaBase() {}
             virtual QString name() const = 0;
             virtual QString prettyName() const = 0;
             virtual QString fullPrettyName() const { return prettyName(); }
             virtual QString sortableName() const { return prettyName(); }
 
-            virtual void addMatchTo( QueryMaker *qm ) = 0;
+            /**used for showing a fixed name in the tree view. Needed for items that change
+             * their name occasionally such as some streams. These should overwrite this
+             */
+            virtual QString fixedName() const { return prettyName(); }
 
-            virtual void subscribe( Observer *observer );
-            virtual void unsubscribe( Observer *observer );
+            virtual void addMatchTo( QueryMaker *qm ) = 0;
 
             virtual bool hasCapabilityInterface( Meta::Capability::Type type ) const;
 
@@ -119,10 +149,15 @@ namespace Meta
             }
 
         protected:
+            virtual void subscribe( Observer *observer );
+            virtual void unsubscribe( Observer *observer );
+
             virtual void notifyObservers() const = 0;
 
-        protected:
             QSet<Meta::Observer*> m_observers;
+
+        private: // no copy allowed, since it's not safe with observer list
+            Q_DISABLE_COPY(MetaBase)
     };
 
     class AMAROK_EXPORT Track : public MetaBase
@@ -155,7 +190,7 @@ namespace Meta
             /** Returns the score of this track */
             virtual double score() const = 0;
             virtual void setScore( double newScore ) = 0;
-            /** Returns the ratint of this track */
+            /** Returns the rating of this track */
             virtual int rating() const = 0;
             virtual void setRating( int newRating ) = 0;
             /** Returns the length of this track in seconds, or 0 if unknown */
@@ -210,6 +245,8 @@ namespace Meta
 
     class AMAROK_EXPORT Artist : public MetaBase
     {
+        Q_PROPERTY( TrackList tracks READ tracks )
+        Q_PROPERTY( AlbumList albums READ albums )
         public:
 
             virtual ~Artist() {}
@@ -229,6 +266,12 @@ namespace Meta
 
     class AMAROK_EXPORT Album : public MetaBase
     {
+        Q_PROPERTY( bool compilation READ isCompilation )
+        Q_PROPERTY( bool hasAlbumArtist READ hasAlbumArtist )
+        Q_PROPERTY( ArtistPtr albumArtist READ albumArtist )
+        Q_PROPERTY( TrackList tracks READ tracks )
+        Q_PROPERTY( bool hasImage READ hasImage )
+        Q_PROPERTY( QPixmap image READ image WRITE setImage )
         public:
 
             virtual ~Album() {}
@@ -242,7 +285,7 @@ namespace Meta
             virtual TrackList tracks() = 0;
 
             /** returns true if the album has a cover set */
-            virtual bool hasImage( int size = 1) const { Q_UNUSED( size ); return false; }
+            virtual bool hasImage( int size = 1 ) const { Q_UNUSED( size ); return false; }
             /** returns the cover of the album */
             virtual QPixmap image( int size = 1, bool withShadow = false );
             /** Returns true if it is possible to update the cover of the album */
@@ -262,6 +305,7 @@ namespace Meta
 
     class AMAROK_EXPORT Composer : public MetaBase
     {
+        Q_PROPERTY( TrackList tracks READ tracks )
         public:
 
             virtual ~Composer() {}
@@ -278,6 +322,7 @@ namespace Meta
 
     class AMAROK_EXPORT Genre : public MetaBase
     {
+        Q_PROPERTY( TrackList tracks READ tracks )
         public:
 
             virtual ~Genre() {}
@@ -294,6 +339,7 @@ namespace Meta
 
     class AMAROK_EXPORT Year : public MetaBase
     {
+        Q_PROPERTY( TrackList tracks READ tracks )
         public:
 
             virtual ~Year() {}
