@@ -27,6 +27,9 @@
 
 #include <KSharedPtr>
 
+// Taglib
+#include <taglib/fileref.h>
+
 namespace Meta
 {
     class Track;
@@ -60,6 +63,8 @@ namespace Meta
 
         AMAROK_EXPORT QVariantMap mapFromTrack( const Meta::Track *track );
         AMAROK_EXPORT void updateTrack( Meta::Track *track, const QVariantMap &metadata );
+        AMAROK_EXPORT void writeFields( const QString &filename, const QVariantMap &changes );
+        AMAROK_EXPORT void writeFields( TagLib::FileRef fileref, const QVariantMap &changes );
         AMAROK_EXPORT QString xesamPrettyToFullFieldName( const QString &name );
         AMAROK_EXPORT QString xesamFullToPrettyFieldName( const QString &name );
     }
@@ -67,6 +72,11 @@ namespace Meta
 
     AMAROK_EXPORT QString msToPrettyTime( int ms );
     AMAROK_EXPORT QString secToPrettyTime( int seconds );
+
+    AMAROK_EXPORT QString prettyFilesize( int size );
+    AMAROK_EXPORT QString prettyBitrate( int bitrate );
+
+    AMAROK_EXPORT QString prettyRating( int rating );
 }
 
 #endif
