@@ -19,18 +19,13 @@
 #include "File.h"
 #include "File_p.h"
 
-#include "debug.h"
 #include "Meta.h"
 #include "meta/EditCapability.h"
 #include "MetaUtility.h"
 
-#include <QFile>
 #include <QPointer>
 #include <QString>
 
-#include <kfilemetainfo.h>
-#include <kfilemetainfoitem.h>
-
 using namespace MetaFile;
 
 class EditCapabilityImpl : public Meta::EditCapability
@@ -38,8 +33,9 @@ class EditCapabilityImpl : public Meta::EditCapability
     Q_OBJECT
     public:
         EditCapabilityImpl( MetaFile::Track *track )
-    : Meta::EditCapability()
-                , m_track( track ) {}
+            : Meta::EditCapability()
+            , m_track( track )
+        {}
 
         virtual bool isEditable() const { return m_track->isEditable(); }
         virtual void setAlbum( const QString &newAlbum ) { m_track->setAlbum( newAlbum ); }
@@ -63,8 +59,19 @@ Track::Track( const KUrl &url )
     : Meta::Track()
     , d( new Track::Private( this ) )
 {
+#ifdef COMPLEX_TAGLIB_FILENAME
+    const wchar_t * encodedName = reinterpret_cast<const wchar_t *>(url.path().utf16());
+#else
+    QByteArray fileName = QFile::encodeName( url.path() );
+    const char * encodedName = fileName.constData(); // valid as long as fileName exists
+#endif
     d->url = url;
-    d->metaInfo = KFileMetaInfo( url.path() );
+    d->fileRef = TagLib::FileRef( encodedName, true, TagLib::AudioProperties::Fast );
+    if( !d->fileRef.isNull() )
+    {
+        d->tag = d->fileRef.tag();
+    }
+    d->readMetaData();
     d->album = Meta::AlbumPtr( new MetaFile::FileAlbum( QPointer<MetaFile::Track::Private>( d ) ) );
     d->artist = Meta::ArtistPtr( new MetaFile::FileArtist( QPointer<MetaFile::Track::Private>( d ) ) );
     d->genre = Meta::GenrePtr( new MetaFile::FileGenre( QPointer<MetaFile::Track::Private>( d ) ) );
@@ -80,16 +87,21 @@ Track::~Track()
 QString
 Track::name() const
 {
-    DEBUG_BLOCK
-    KFileMetaInfoItem item = d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::TITLE ) );
-    if( item.isValid() && !item.value().toString().isEmpty() ) {
-        debug() << "NOT Here!";
-        return item.value().toString();
-    } else {
-        debug() << "Here!";
-        //lets use the filename, or it will look really dull in the playlist
-        return d->url.fileName();
+    if( d )
+    {
+        const QString trackName = d->m_data.title;
+        if( !trackName.isEmpty() )
+        {
+            return trackName;
+        }
+        else
+        {
+            //lets use the filename, or it will look really dull in the playlist
+            return d->url.fileName();
+        }
     }
+    else
+        return "This is a bug!";
 }
 
 QString
@@ -176,10 +188,13 @@ Track::year() const
 void
 Track::setAlbum( const QString &newAlbum )
 {
-    d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::ALBUM ) ).setValue( newAlbum );
+    DEBUG_BLOCK
+    d->changes.insert( Meta::Field::ALBUM, QVariant( newAlbum ) );
+    debug() << "CHANGES HERE: " << d->changes;
     if( !d->batchUpdate )
     {
-        d->metaInfo.applyChanges();
+        d->m_data.album = newAlbum;
+        d->writeMetaData();
         notifyObservers();
     }
 }
@@ -187,10 +202,11 @@ Track::setAlbum( const QString &newAlbum )
 void
 Track::setArtist( const QString& newArtist )
 {
-    d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::ARTIST ) ).setValue( newArtist );
+    d->changes.insert( Meta::Field::ARTIST, QVariant( newArtist ) );
     if( !d->batchUpdate )
     {
-        d->metaInfo.applyChanges();
+        d->m_data.artist = newArtist;
+        d->writeMetaData();
         notifyObservers();
     }
 }
@@ -198,10 +214,10 @@ Track::setArtist( const QString& newArtist )
 void
 Track::setGenre( const QString& newGenre )
 {
-    d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::GENRE ) ).setValue( newGenre );
+    d->changes.insert( Meta::Field::GENRE, QVariant( newGenre ) );
     if( !d->batchUpdate )
     {
-        d->metaInfo.applyChanges();
+        d->writeMetaData();
         notifyObservers();
     }
 }
@@ -209,21 +225,26 @@ Track::setGenre( const QString& newGenre )
 void
 Track::setComposer( const QString& newComposer )
 {
+    AMAROK_NOTIMPLEMENTED
+    Q_UNUSED( newComposer );
+    #if 0
     d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::COMPOSER ) ).setValue( newComposer );
     if( !d->batchUpdate )
     {
         d->metaInfo.applyChanges();
         notifyObservers();
     }
+    #endif
 }
 
 void
 Track::setYear( const QString& newYear )
 {
-    d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::YEAR ) ).setValue( newYear );
+    d->changes.insert( Meta::Field::YEAR, QVariant( newYear ) );
     if( !d->batchUpdate )
     {
-        d->metaInfo.applyChanges();
+        d->m_data.year = newYear.toInt();
+        d->writeMetaData();
         notifyObservers();
     }
 }
@@ -231,10 +252,11 @@ Track::setYear( const QString& newYear )
 void
 Track::setTitle( const QString &newTitle )
 {
-    d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::TITLE ) ).setValue( newTitle );
+    d->changes.insert( Meta::Field::TITLE, QVariant( newTitle ) );
     if( !d->batchUpdate )
     {
-        d->metaInfo.applyChanges();
+        d->m_data.title = newTitle;
+        d->writeMetaData();
         notifyObservers();
     }
 }
@@ -242,20 +264,25 @@ Track::setTitle( const QString &newTitle )
 QString
 Track::comment() const
 {
-    KFileMetaInfoItem item = d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::COMMENT ) );
-    if( item.isValid() )
-        return item.value().toString();
-    else
-        return QString();
+    if( d && d->tag )
+    {
+        const QString commentName = d->m_data.comment;
+        if( !commentName.isEmpty() )
+            return commentName;
+        else
+            return QString();
+    }
+    return QString();
 }
 
 void
 Track::setComment( const QString& newComment )
 {
-    d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::COMMENT ) ).setValue( newComment );
+    d->changes.insert( Meta::Field::COMMENT, QVariant( newComment ) );
     if( !d->batchUpdate )
     {
-        d->metaInfo.applyChanges();
+        d->m_data.comment = newComment;
+        d->writeMetaData();
         notifyObservers();
     }
 }
@@ -287,20 +314,21 @@ Track::setRating( int newRating )
 int
 Track::trackNumber() const
 {
-    KFileMetaInfoItem item = d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::TRACKNUMBER ) );
-    if( item.isValid() )
-        return item.value().toInt();
-    else
-        return 0;
+    if( d && d->tag )
+    {
+        return d->m_data.trackNumber;
+    }
+    return 0;
 }
 
 void
 Track::setTrackNumber( int newTrackNumber )
 {
-    d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::TRACKNUMBER ) ).setValue( newTrackNumber );
+    d->changes.insert( Meta::Field::TRACKNUMBER, QVariant( newTrackNumber ) );
     if( !d->batchUpdate )
     {
-        d->metaInfo.applyChanges();
+        d->m_data.trackNumber = newTrackNumber;
+        d->writeMetaData();
         notifyObservers();
     }
 }
@@ -308,62 +336,71 @@ Track::setTrackNumber( int newTrackNumber )
 int
 Track::discNumber() const
 {
-    KFileMetaInfoItem item = d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::DISCNUMBER ) );
-    if( item.isValid() )
-        return item.value().toInt();
-    else
-        return 0;
+    if( d && d->tag )
+    {
+        return d->m_data.discNumber;
+    }
+    return 0;
 }
 
 void
 Track::setDiscNumber( int newDiscNumber )
 {
+    AMAROK_NOTIMPLEMENTED
+    Q_UNUSED( newDiscNumber );
+    #if 0
     d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::DISCNUMBER ) ).setValue( newDiscNumber );
     if( !d->batchUpdate )
     {
         d->metaInfo.applyChanges();
         notifyObservers();
     }
+    #endif
 }
 
 int
 Track::length() const
 {
-    KFileMetaInfoItem item = d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::LENGTH ) );
-    if( item.isValid() )
-        return item.value().toInt();
-    else
-        return 0;
+    if( d && !d->fileRef.isNull() )
+    {
+        int length = d->m_data.length;
+        if( length == -2 /*Undetermined*/ )
+            length = 0;
+        return length;
+    }
+    return 0;
 }
 
 int
 Track::filesize() const
 {
-    KFileMetaInfoItem item = d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::FILESIZE ) );
-    if( item.isValid() )
-        return item.value().toInt();
-    else
-        return 0;
+    return d->m_data.fileSize;
 }
 
 int
 Track::sampleRate() const
 {
-    KFileMetaInfoItem item = d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::SAMPLERATE ) );
-    if( item.isValid() )
-        return item.value().toInt();
-    else
-        return 0;
+    if( d && !d->fileRef.isNull() )
+    {
+        int sampleRate = d->m_data.sampleRate;
+        if( sampleRate == -2 /*Undetermined*/ )
+            sampleRate = 0;
+        return sampleRate;
+    }
+    return 0;
 }
 
 int
 Track::bitrate() const
 {
-    KFileMetaInfoItem item = d->metaInfo.item( Meta::Field::xesamPrettyToFullFieldName( Meta::Field::BITRATE ) );
-    if( item.isValid() )
-        return item.value().toInt();
-    else
-        return 0;
+    if( d && !d->fileRef.isNull() )
+    {
+        int bitrate = d->m_data.bitRate;
+        if( bitrate == -2 /*Undetermined*/ )
+            bitrate = 0;
+        return bitrate;
+    }
+    return 0;
 }
 
 uint
@@ -393,18 +430,17 @@ Track::beginMetaDataUpdate()
 void
 Track::endMetaDataUpdate()
 {
-    d->metaInfo.applyChanges();
+ DEBUG_LINE_INFO
+    debug() << "CHANGES HERE: " << d->changes;
+    d->writeMetaData();
     d->batchUpdate = false;
     notifyObservers();
-
-
 }
 
 void
 Track::abortMetaDataUpdate()
 {
-    //KFileMetaInfo does not have a method to reset the items
-    d->metaInfo = KFileMetaInfo( d->url.path() );
+    d->changes.clear();
     d->batchUpdate = false;
 }
 
