@@ -24,6 +24,8 @@
 
 #include <QObject>
 
+class TrackProvider;
+
 namespace MetaProxy
 {
     class Track : public Meta::Track
@@ -36,6 +38,7 @@ namespace MetaProxy
 
         //methods inherited from Meta::MetaBase
             virtual QString name() const;
+            virtual void setName( const QString &name );
             virtual QString prettyName() const;
             virtual QString fullPrettyName() const;
             virtual QString sortableName() const;
@@ -48,10 +51,15 @@ namespace MetaProxy
             virtual bool isPlayable() const;
 
             virtual Meta::AlbumPtr album() const;
+            virtual void setAlbum( const QString &album );
             virtual Meta::ArtistPtr artist() const;
+            virtual void setArtist( const QString &artist );
             virtual Meta::GenrePtr genre() const;
+            virtual void setGenre( const QString &genre );
             virtual Meta::ComposerPtr composer() const;
+            virtual void setComposer( const QString &composer );
             virtual Meta::YearPtr year() const;
+            virtual void setYear( const QString &year );
 
             virtual QString comment() const;
 
@@ -62,7 +70,9 @@ namespace MetaProxy
             virtual void setRating( int newRating );
 
             virtual int trackNumber() const;
+            virtual void setTrackNumber( int number );
             virtual int discNumber() const;
+            virtual void setDiscNumber( int discNumber );
 
             virtual int length() const;
             virtual int filesize() const;
@@ -85,8 +95,20 @@ namespace MetaProxy
             virtual Meta::Capability* asCapabilityInterface( Meta::Capability::Type type );
 
             virtual bool operator==( const Meta::Track &track ) const;
+		
+		protected:
+		/**
+		 * allows subclasses to create an instance if trackprovider which will only check the TrackProvider
+		 * passed to lookupTrack(TrackProvider*) for the real track.
+		 */
+		Track( const KUrl &url, bool awaitLookupNotification);
+		/**
+		 * MetaProxy wil check the given trackprovider if it can provide the track for the proxy's url.
+		 */
+		void lookupTrack(TrackProvider *provider);
 
         private:
+			void init( const KUrl &url, bool awaitLookupNotification );
             Private * const d;
     };
 
