@@ -19,9 +19,9 @@
 #ifndef AMAROK_METAPROXY_P_H
 #define AMAROK_METAPROXY_P_H
 
-#include "debug.h"
+#include "Debug.h"
 
-#include "amarok.h"
+#include "Amarok.h"
 #include "amarokconfig.h"
 #include "Collection.h"
 #include "CollectionManager.h"
@@ -54,7 +54,12 @@ class MetaProxy::Track::Private : public QObject, public Meta::Observer
         QString cachedArtist;
         QString cachedAlbum;
         QString cachedName;
+        QString cachedGenre;
+        QString cachedComposer;
+        QString cachedYear;
         int cachedLength;
+        int cachedTrackNumber;
+        int cachedDiscNumber;
 
         Meta::ArtistPtr artistPtr;
         Meta::AlbumPtr albumPtr;
@@ -68,7 +73,7 @@ class MetaProxy::Track::Private : public QObject, public Meta::Observer
             foreach( Meta::Observer *observer, observers )
                 observer->metadataChanged( proxy );
         }
-
+        using Observer::metadataChanged;
         void metadataChanged( Meta::Track *track )
         {
             Q_UNUSED( track )
@@ -76,17 +81,22 @@ class MetaProxy::Track::Private : public QObject, public Meta::Observer
         }
 
     public slots:
-        void slotNewCollection( Collection *newCollection )
+        void slotNewTrackProvider( TrackProvider *newTrackProvider )
         {
-            if( newCollection->possiblyContainsTrack( url ) )
+            if ( !newTrackProvider )
             {
-                Meta::TrackPtr track = newCollection->trackForUrl( url );
+                return;
+            }
+
+            if( newTrackProvider->possiblyContainsTrack( url ) )
+            {
+                Meta::TrackPtr track = newTrackProvider->trackForUrl( url );
                 if( track )
                 {
-                    track->subscribe( this );
+                    subscribeTo( track );
                     realTrack = track;
                     notifyObservers();
-                    disconnect( CollectionManager::instance(), SIGNAL( collectionAdded( Collection* ) ), this, SLOT( slotNewCollection( Collection* ) ) );
+                    disconnect( CollectionManager::instance(), SIGNAL( trackProviderAdded( TrackProvider* ) ), this, SLOT( slotNewTrackProvider( TrackProvider* ) ) );
                 }
             }
         }
@@ -189,7 +199,7 @@ public:
 
     Meta::ArtistPtr albumArtist() const
     {
-        if( d && d->realTrack )
+        if( d && d->realTrack && d->realTrack->album() )
             return d->realTrack->album()->albumArtist();
         else
             return Meta::ArtistPtr();
@@ -205,11 +215,15 @@ public:
 
     QString name() const
     {
-        if( d && d->realTrack ) {
+        if( d && d->realTrack )
+        {
             if ( d->realTrack->album() )
                 return d->realTrack->album()->name();
             return QString();
-        } else
+        }
+        else if ( d )
+              return d->cachedAlbum;
+        else
             return QString();
     }
 
@@ -218,7 +232,7 @@ public:
         if( d && d->realTrack && d->realTrack->album() )
             return d->realTrack->album()->prettyName();
         else
-            return QString();
+            return name();
     }
 
     QPixmap image( int size, bool withShadow )
@@ -259,6 +273,8 @@ public:
     {
         if( d && d->realTrack && d->realTrack->genre() )
             return d->realTrack->genre()->name();
+        else if( d )
+            return d->cachedGenre;
         else
             return QString();
     }
@@ -307,6 +323,8 @@ public:
     {
         if( d && d->realTrack && d->realTrack->composer() )
             return d->realTrack->composer()->name();
+        else if ( d )
+            return d->cachedComposer;
         else
             return QString();
     }
@@ -316,7 +334,7 @@ public:
         if( d && d->realTrack && d->realTrack->composer())
             return d->realTrack->composer()->prettyName();
         else
-            return QString();
+            return name();
     }
 
     Meta::TrackList tracks()
@@ -355,6 +373,8 @@ public:
     {
         if( d && d->realTrack && d->realTrack->year() )
             return d->realTrack->year()->name();
+        else if( d )
+            return d->cachedYear;
         else
             return QString();
     }
@@ -364,7 +384,7 @@ public:
         if( d && d->realTrack && d->realTrack->year() )
             return d->realTrack->year()->prettyName();
         else
-            return QString();
+            return name();
     }
 
     Meta::TrackList tracks()
