@@ -37,6 +37,8 @@
 #include <threadweaver/Job.h>
 #include <threadweaver/ThreadWeaver.h>
 
+#include <QDesktopServices>
+#include <QDir>
 #include <QFile>
 #include <QList>
 #include <QStringList>
@@ -44,12 +46,17 @@
 
 typedef Medium::List MediumList;
 
+
+K_GLOBAL_STATIC( MountPointManager, s_mountPointManager );
+
 MountPointManager::MountPointManager()
     : QObject( 0 )
 {
     AMAROK_NOTIMPLEMENTED
     setObjectName( "MountPointManager" );
 
+    qAddPostRoutine( s_mountPointManager.destroy );  // Ensures that the dtor gets called when QApplication destructs
+
     if ( !Amarok::config( "Collection" ).readEntry( "DynamicCollection", true ) )
     {
         debug() << "Dynamic Collection deactivated in amarokrc, not loading plugins, not connecting signals";
@@ -91,7 +98,6 @@ MountPointManager::~MountPointManager()
     m_handlerMapMutex.unlock();
 }
 
-K_GLOBAL_STATIC( MountPointManager, s_mountPointManager );
 
 MountPointManager * MountPointManager::instance()
 {
@@ -422,13 +428,33 @@ MountPointManager::collectionFolders( )
                 result.append( absPath );
         }
     }
+    if( result.isEmpty() )
+    {
+        QDesktopServices ds;
+        const QString musicDir = ds.storageLocation( QDesktopServices::MusicLocation );
+        if( !musicDir.isEmpty() )
+        {
+            QDir dir( musicDir );
+            if( dir.exists() )
+            {
+                result << musicDir;
+            }
+        }
+    }
     return result;
 }
 
 void
 MountPointManager::setCollectionFolders( const QStringList &folders )
 {
-    //TODO max: cache data
+    if( folders.size() == 1 )
+    {
+        QDesktopServices ds;
+        if( folders[0] == ds.storageLocation( QDesktopServices::MusicLocation ) )
+        {
+            return;
+        }
+    }
     typedef QMap<int, QStringList> FolderMap;
     KConfigGroup folderConf = Amarok::config( "Collection Folders" );
     FolderMap folderMap;
