@@ -412,11 +412,12 @@ Playlist::GraphicsItem::findArtistForCurrentAlbum() const
         //that means we have to execute the loop at least once
         QModelIndex idx;
         int row = m_currentRow + 1;
+
         do
         {
             idx = The::playlistModel()->index( row++, 0 );
             Meta::TrackPtr track = idx.data( TrackRole ).value< Meta::TrackPtr >();
-            if( track->artist() )
+            if( track && track->artist() )
             {
                 if( artist != track->artist()->name() )
                     return QString();
@@ -606,8 +607,11 @@ Playlist::GraphicsItem::dropEvent( QGraphicsSceneDragDropEvent * event )
 void
 Playlist::GraphicsItem::refresh()
 {
-    if( m_items && m_items->track )
+
+    if( m_items && m_items->track ) {
+        debug() << "refreshing " << m_items->track->name();
         resize( m_items->track,m_items->lastWidth );
+    }
 }
 
 void Playlist::GraphicsItem::mouseReleaseEvent( QGraphicsSceneMouseEvent *event )
@@ -682,7 +686,7 @@ void Playlist::GraphicsItem::setRow(int row)
                 m_height =  qMax( ALBUM_WIDTH, s_fm->height() * 2 ) + MARGIN + s_fm->height() + 6;
                 break;
             case Head_Collapsed:
-                //debug() << "Collapsed head";
+                debug() << "Collapsed head";
                 m_height =  qMax( ALBUM_WIDTH, s_fm->height() * 2 ) + MARGIN * 2 + s_fm->height() + 16;
                 if ( !m_items )
                 {
@@ -692,6 +696,7 @@ void Playlist::GraphicsItem::setRow(int row)
                     init( track );
                 }
                 m_items->groupedTracks = index.data( GroupedTracksRole ).toInt();
+                debug() << "I have this many hidden tracks: " << m_items->groupedTracks;
                 break;
             case Body:
                 //debug() << "Body";
