@@ -32,9 +32,10 @@
 #include "DynamicTrackNavigator.h"
 #include "EngineController.h"
 #include "PlaylistItem.h"
-#include "PlaylistGraphicsView.h"
 #include "PlaylistFileSupport.h"
+#include "RandomAlbumNavigator.h"
 #include "RandomTrackNavigator.h"
+#include "RepeatAlbumNavigator.h"
 #include "RepeatPlaylistNavigator.h"
 #include "RepeatTrackNavigator.h"
 #include "StandardTrackNavigator.h"
@@ -79,10 +80,6 @@ namespace Amarok
 }
 
 
-
-
-
-
 Playlist::Model *Playlist::Model::s_instance = 0;
 
 Playlist::Model::Model( QObject* parent )
@@ -136,7 +133,8 @@ Playlist::Model::~Model()
         }
         The::playlistManager()->exportPlaylist( list, defaultPlaylistPath() );
     }
-    delete m_advancer;
+
+    m_advancer->deleteLater();
 }
 
 
@@ -374,10 +372,12 @@ Playlist::Model::insertTracks( int row, Meta::TrackList tracks )
             }
 
             Meta::PlaylistPtr playlist =  The::playlistManager()->expand( tracks.at( playlistIndex ) );
-            m_undoStack->push( new AddTracksCmd( 0, row + playlistIndex + offset, playlist->tracks() ) );
-            offset += playlist->tracks().size();
+            if( playlist ) {
+                m_undoStack->push( new AddTracksCmd( 0, row + playlistIndex + offset, playlist->tracks() ) );
+                offset += playlist->tracks().size();
 
-            lastIndex = playlistIndex + 1;
+                lastIndex = playlistIndex + 1;
+            }
         }
     }
 }
@@ -392,7 +392,7 @@ Playlist::Model::removeRows( int position, int rows, const QModelIndex& /*parent
 void
 Playlist::Model::insertTracks( int row, QueryMaker *qm )
 {
-    qm->startTrackQuery();
+    qm->setQueryType( QueryMaker::Track );
     connect( qm, SIGNAL( queryDone() ), SLOT( queryDone() ) );
     connect( qm, SIGNAL( newResultReady( QString, Meta::TrackList ) ), SLOT( newResultReady( QString, Meta::TrackList ) ) );
     m_queryMap.insert( qm, row );
@@ -424,7 +424,11 @@ Playlist::Model::play( const QModelIndex& index )
 void
 Playlist::Model::play( int row )
 {
-    The::engineController()->play( m_items[ row ]->track() );
+    if( m_items.size() > row )
+    {
+        m_nextRowCandidate = row;
+        The::engineController()->play( m_items[ row ]->track() );
+    }
 }
 
 void
@@ -513,8 +517,7 @@ Playlist::Model::playlistModeChanged()
 {
     DEBUG_BLOCK
 
-    delete m_advancer;
-    m_advancer = 0;
+    m_advancer->deleteLater();
 
     int options = Playlist::StandardPlayback;
 
@@ -527,24 +530,33 @@ Playlist::Model::playlistModeChanged()
 
     if( AmarokConfig::dynamicMode() )
     {
-        PlaylistBrowserNS::DynamicModel* dm = PlaylistBrowserNS::DynamicModel::instance();
+        PlaylistBrowserNS::DynamicModel* dm =
+            PlaylistBrowserNS::DynamicModel::instance();
 
-        Dynamic::DynamicPlaylistPtr playlist = 
-            dm->retrievePlaylist( AmarokConfig::lastDynamicMode() );
-        if( !playlist ) playlist = dm->retrieveDefaultPlaylist();
+        Dynamic::DynamicPlaylistPtr playlist = dm->activePlaylist();
+
+        if( !playlist )
+            playlist = dm->retrieveDefaultPlaylist();
+
+        const bool wasNull = m_advancer == 0; 
 
-        const bool wasNull = m_advancer == 0;
         m_advancer = new DynamicTrackNavigator( this, playlist );
 
+        // wasNull == true indicates that Amarok is just starting up.
+        // Because of some quirk in the construction order it
+        // will crash if we if try adding tracks now.
         if( !wasNull )
         {
-            ( (DynamicTrackNavigator*) m_advancer)->appendUpcoming();
-            if( activeRow() < 0 && rowCount() > 0 ) play( 0 );
+            ((DynamicTrackNavigator*) m_advancer)->appendUpcoming();
+            if( activeRow() < 0 && rowCount() > 0 )
+                play( 0 );
         }
 
         return;
     }
 
+    m_advancer = 0;
+
     if( Amarok::repeatEnabled() )
         options |= Playlist::RepeatPlayback;
     if( Amarok::randomEnabled() )
@@ -567,14 +579,15 @@ Playlist::Model::playlistModeChanged()
             m_advancer = new RepeatTrackNavigator( this );
         else if( options & Playlist::PlaylistPlayback )
             m_advancer = new RepeatPlaylistNavigator( this );
+        else if( options & Playlist::AlbumPlayback )
+            m_advancer = new RepeatAlbumNavigator( this );
     }
     else if( options & Playlist::RandomPlayback )
-    // TODO: implement RandomAlbumNavigator
     {
         if( options & Playlist::TrackPlayback )
             m_advancer = new RandomTrackNavigator( this );
         else if( options & Playlist::AlbumPlayback )
-            m_advancer = new StandardTrackNavigator( this ); 
+            m_advancer = new RandomAlbumNavigator( this );
     }
 
     if( m_advancer == 0 )
@@ -611,6 +624,17 @@ Playlist::Model::setActiveRow( int row )
     }
 }
 
+Meta::TrackPtr
+Playlist::Model::activeTrack() const
+{
+    if( m_activeRow > -1 )
+        return m_items.at( m_activeRow )->track();
+    else if( rowCount() > 0 )
+        return m_items.at( 0 )->track();
+
+    return Meta::TrackPtr();
+}
+
 void
 Playlist::Model::metadataChanged( Meta::Track *track )
 {
@@ -659,7 +683,6 @@ Playlist::Model::clear()
     removeRows( 0, m_items.size() );
     m_albumGroups.clear();
     m_lastAddedTrackAlbum = Meta::AlbumPtr();
-    The::playlistView()->scene()->setSceneRect( The::playlistView()->scene()->itemsBoundingRect() );
 //    m_activeRow = -1;
 }
 
@@ -704,7 +727,7 @@ Playlist::Model::insertOptioned( Meta::TrackList list, int options )
         firstItemAdded = 0;
         insertTracks( 0, list );
 
-        for( int i = 0; i < list.size(); ++i )
+        for( int i = 0; i < list.size() && m_items.size() > i; ++i )
         {
             m_newlyAdded.append( i );
             m_items[i]->setState( Item::NewlyAdded );
@@ -715,7 +738,7 @@ Playlist::Model::insertOptioned( Meta::TrackList list, int options )
         firstItemAdded = rowCount();
         insertTracks( firstItemAdded, list );
 
-        for( int i = 0; i < list.size(); ++i )
+        for( int i = 0; i < list.size() && ( m_items.size() > firstItemAdded + i ); ++i )
         {
             m_newlyAdded.append( firstItemAdded + i );
             m_items[firstItemAdded + i]->setState( Item::NewlyAdded );
@@ -800,7 +823,7 @@ Playlist::Model::insertOptioned( QueryMaker *qm, int options )
     {
         return;
     }
-    qm->startTrackQuery();
+    qm->setQueryType( QueryMaker::Track );
     connect( qm, SIGNAL( queryDone() ), SLOT( queryDone() ) );
     connect( qm, SIGNAL( newResultReady( QString, Meta::TrackList ) ), SLOT( newResultReady( QString, Meta::TrackList ) ) );
     m_optionedQueryMap.insert( qm, options );
@@ -847,17 +870,17 @@ Playlist::Model::engineNewTrackPlaying()
 
     if( track )
     {
-        if( rowExists( m_nextRowCandidate ) &&
+        if( rowExists( m_nextRowCandidate  ) &&
                 track == m_items.at( m_nextRowCandidate )->track() )
         {
-            debug() << "engineNewTrackPlaying:: HIT";
             setActiveRow( m_nextRowCandidate );
 
             emit activeRowChanged( oldActiveRow, activeRow() );
         }
         else
         {
-            debug() << "engineNewTrackPlaying:: MISS";
+            warning() << "engineNewTrackPlaying:: MISS";
+
             foreach( Item* item, itemList() )
             {
                 if( item->track() == track )
@@ -867,7 +890,7 @@ Playlist::Model::engineNewTrackPlaying()
                 }
             }
 
-            emit activeRowExplicitlyChanged( oldActiveRow, activeRow() );
+            emit activeRowChanged( oldActiveRow, activeRow() );
         }
     }
 
@@ -988,6 +1011,18 @@ Playlist::Model::dropMimeData ( const QMimeData * data, Qt::DropAction action, i
     return false;
 }
 
+Meta::TrackPtr
+Playlist::Model::trackForRow( int row ) const
+{
+    if( row >= 0 && row < itemList().size() )
+    {
+        return itemList().at( row )->track();
+    }
+    else
+        return Meta::TrackPtr( 0 );
+}
+
+
 ////////////
 //Private Methods
 ///////////
@@ -1058,9 +1093,8 @@ Playlist::Model::insertTracksCommand( int row, Meta::TrackList list )
     }
     dataChanged( createIndex( row, 0 ), createIndex( rowCount() - 1, 0 ) );
 
-    The::playlistView()->scene()->setSceneRect( The::playlistView()->scene()->itemsBoundingRect() );
-
     Amarok::actionCollection()->action( "playlist_clear" )->setEnabled( !m_items.isEmpty() );
+    Amarok::actionCollection()->action( "play_pause" )->setEnabled( !activeTrack().isNull() );
 
     emit playlistCountChanged( rowCount() );
 }
@@ -1099,7 +1133,7 @@ Playlist::Model::removeTracksCommand( int position, int rows )
         dataChanged( createIndex( oldActiveRow, 0 ), createIndex( oldActiveRow, columnCount() -1 ) );
         dataChanged( createIndex( m_activeRow, 0 ), createIndex( m_activeRow, columnCount() -1 ) );
     }
-    dataChanged( createIndex( position, 0 ), createIndex( rowCount(), 0 ) );
+    //dataChanged( createIndex( position, 0 ), createIndex( rowCount(), 0 ) );
 
 
     //we need to regroup everything below this point as all the index changes
@@ -1108,9 +1142,8 @@ Playlist::Model::removeTracksCommand( int position, int rows )
 
     endRemoveRows();
 
-    The::playlistView()->scene()->setSceneRect( The::playlistView()->scene()->itemsBoundingRect() );
-
     Amarok::actionCollection()->action( "playlist_clear" )->setEnabled( !m_items.isEmpty() );
+    Amarok::actionCollection()->action( "play_pause" )->setEnabled( !activeTrack().isNull() );
 
     emit playlistCountChanged( rowCount() );
 
@@ -1193,11 +1226,6 @@ Playlist::Model::moveRow(int row, int to)
 void
 Playlist::Model::regroupAlbums( int firstRow, int lastRow, OffsetMode offsetMode, int offset )
 {
-    DEBUG_BLOCK
-
-    debug() << "first row: " << firstRow << ", last row: " << lastRow;
-
-
     int area1Start = -1;
     int area1End = -1;
     int area2Start = -1;
