@@ -137,7 +137,7 @@ namespace Playlist
     };
 
 
-    class Model : public QAbstractListModel, public Meta::Observer, public Meta::PlaylistObserver, public EngineObserver
+    class AMAROK_EXPORT Model : public QAbstractListModel, public Meta::Observer, public Meta::PlaylistObserver, public EngineObserver
     {
         friend class AddTracksCmd;
         friend class AddPlaylistsCmd;
@@ -177,8 +177,10 @@ namespace Playlist
 
             bool savePlaylist( const QString &path ) const;
 
-            ///Return list of items in playlist
+            //Return list of items in playlist
             QList<Item*> itemList() const { return m_items; }
+            //Return TrackPtr for a given row in the playlist
+            Meta::TrackPtr trackForRow( int row ) const;
 
             inline const QString defaultPlaylistPath() const { return Amarok::saveLocation() + "current.xspf"; }
 
@@ -188,9 +190,9 @@ namespace Playlist
              * @param list tracks to add
              * @param options valid values are Unique || (Append xor Queue xor Replace) || ( DirectPlay xor StartPlay )
              **/
-            AMAROK_EXPORT void insertOptioned( Meta::TrackList list, int options );
-            AMAROK_EXPORT void insertOptioned( Meta::TrackPtr track, int options ); //convenience method
-            AMAROK_EXPORT void insertOptioned( QueryMaker *qm, int options );
+            void insertOptioned( Meta::TrackList list, int options );
+            void insertOptioned( Meta::TrackPtr track, int options ); //convenience method
+            void insertOptioned( QueryMaker *qm, int options );
             void insertTrack( int row, Meta::TrackPtr track ); //convenience method
             void insertTracks( int row, Meta::TrackList list );
             void insertTracks( int row, QueryMaker *qm );
@@ -200,14 +202,14 @@ namespace Playlist
              * @param list Playlist to add
              * @param options valid values are Unique || (Append xor Queue xor Replace) || ( DirectPlay xor StartPlay )
              **/
-            AMAROK_EXPORT void insertOptioned( Meta::PlaylistList list, int options );
-            AMAROK_EXPORT void insertOptioned( Meta::PlaylistPtr playlist, int options ); //convenience method
+            void insertOptioned( Meta::PlaylistList list, int options );
+            void insertOptioned( Meta::PlaylistPtr playlist, int options ); //convenience method
             void insertPlaylist( int row, Meta::PlaylistPtr playlist ); //convenience method
             void insertPlaylists( int row, Meta::PlaylistList playlists );
 
             int activeRow() const { return m_activeRow; }
             void setActiveRow( int row );
-            Meta::TrackPtr activeTrack() const { return m_activeRow > -1 ? m_items.at( m_activeRow )->track() : Meta::TrackPtr(); }
+            Meta::TrackPtr activeTrack() const;
             void setActiveItem( Playlist::Item* active) { setActiveRow( m_items.lastIndexOf(active) ); }
             bool rowExists( int row ) { return 0 <= row && row < rowCount(); }
 
@@ -253,7 +255,6 @@ namespace Playlist
             void rowsChanged( int startRow );
             void rowMoved( int from, int to );
             void activeRowChanged( int from, int to );
-            void activeRowExplicitlyChanged( int from, int to );
             void repopulate();
 
         protected:
