@@ -34,8 +34,9 @@ namespace Amarok
             void slotConfigured();
 
         public slots:
-            virtual QString  Version();
-            virtual void     Quit();
+            QString  Version();
+            void     Quit();
+            int      alert( QString type, QString text );
 
         signals:
             void configured();
