@@ -1,4 +1,5 @@
-Importer.load("debug.js");
+Importer.loadQtBinding( "qt.core" );
+Importer.load( "debug.js" );
 
 print ( "this is main.js" );
 
@@ -49,12 +50,41 @@ if ( TrackInfo.Artist || TrackInfo.Album )
     OSD.setText( "Hey, this is " + TrackInfo.Artist );
     OSD.show();
 
-    StatusBar.shortMessage( "You are listening to album: " + TrackInfo.Album );
+    StatusBar.longMessage( "You are listening to album: " + TrackInfo.Album );
 }
 
-function Configured()
+function onConfigure()
 {
-    print( "Configure Button Clicked!" );
+    Amarok.alert( "sorry", "This script does not require any configuration." );
 }
 
-Amarok.configured.connect( Configured );
\ No newline at end of file
+function TrackChanged()
+{
+    print( "Track Changed!" );
+}
+
+function TrackSeeked()
+{
+    print( "Track Seeked!" );
+}
+
+function TrackFinished()
+{
+    print( "Track Finished!" );
+}
+
+function PlaylistCountChanged( count )
+{
+    print( count );
+}
+
+Amarok.configured.connect( onConfigure );
+Amarok.Engine.trackChanged.connect( TrackChanged );
+Amarok.Engine.trackSeeked.connect( TrackSeeked );
+Amarok.Engine.trackFinished.connect( TrackFinished );
+Amarok.Playlist.CountChanged.connect( PlaylistCountChanged );
+
+
+var time = QTime.currentTime();
+print( time.hour() );
+print( time.minute() );
\ No newline at end of file
