@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright (c) 2007  Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>    *
+ *   Copyright (c) 2008  Casey Link <unnamedrambler@gmail.com>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +17,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
- 
+
 #include "Mp3tunesConfig.h"
 
 #include <kdebug.h>
@@ -44,6 +45,8 @@ void Mp3tunesConfig::load()
     m_email = config.readEntry( "email", QString() );
     m_password = config.readEntry( "password", QString() );
     m_identifier = config.readEntry( "identifier", QString() );
+    m_pin = config.readEntry( "pin", QString() );
+    m_harmonyEmail = config.readEntry( "harmonyEmail", QString() );
     m_partnerToken = config.readEntry( "partnerToken", QString( "4895500420" ) );
     m_harmonyEnabled = config.readEntry( "harmonyEnabled", false );
 
@@ -55,7 +58,7 @@ void Mp3tunesConfig::load()
             if( addr != "00:00:00:00:00:00" ) {
                 addr.remove( ":" );
                 kDebug( 14310 ) << "Using iface \"" << iface.name() << " addr: " << addr;
-                setIdentifier( addr + "-" + m_partnerToken );
+                setIdentifier( addr + m_partnerToken );
                 save();
                 break;
             }
@@ -73,6 +76,8 @@ void Mp3tunesConfig::save()
         config.writeEntry( "identifier", m_identifier );
         config.writeEntry( "harmonyEnabled", m_harmonyEnabled );
         config.writeEntry( "partnerToken", m_partnerToken );
+        config.writeEntry( "harmonyEmail", m_harmonyEmail );
+        config.writeEntry( "pin", m_pin );
     }
 }
 
@@ -96,13 +101,23 @@ QString Mp3tunesConfig::identifier()
     return m_identifier;
 }
 
+QString Mp3tunesConfig::pin()
+{
+    return m_pin;
+}
+
+QString Mp3tunesConfig::harmonyEmail()
+{
+    return m_harmonyEmail;
+}
+
 bool Mp3tunesConfig::harmonyEnabled()
 {
    return m_harmonyEnabled;
 }
 
 void Mp3tunesConfig::setHarmonyEnabled( bool enabled )
-{    
+{
     kDebug( 14310 ) << "set harmony";
     if ( enabled != m_harmonyEnabled ) {
         m_harmonyEnabled = enabled;
@@ -146,4 +161,20 @@ void Mp3tunesConfig::setPartnerToken( const QString &token )
     }
 }
 
+void Mp3tunesConfig::setPin( const QString &pin )
+{
+    kDebug( 14310 ) << "set pin";
+    if( pin != m_pin ) {
+        m_pin = pin;
+        m_hasChanged = true;
+    }
+}
 
+void Mp3tunesConfig::setHarmonyEmail( const QString &harmonyEmail )
+{
+    kDebug( 14310 ) << "set harmonyEmail";
+    if( harmonyEmail != m_harmonyEmail ) {
+        m_harmonyEmail = harmonyEmail;
+        m_hasChanged = true;
+    }
+}
