@@ -1,7 +1,7 @@
 /***************************************************************************
  *   Copyright (c) 2007  Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>    *
  *             (c) 2007  Adam Pigg <adam@piggz.co.uk>                      *
- *             (c) 2007  Casey Link <unnamedrambler@gmail.com>             *
+ *             (c) 2007, 2008  Casey Link <unnamedrambler@gmail.com>       *
  *                                                                         *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
@@ -121,25 +121,38 @@ void Mp3tunesServiceQueryMaker::run()
 void Mp3tunesServiceQueryMaker::abortQuery()
 {}
 
-QueryMaker * Mp3tunesServiceQueryMaker::startArtistQuery()
+QueryMaker * Mp3tunesServiceQueryMaker::setQueryType( QueryType type )
 {
-    DEBUG_BLOCK
-    d->type = Private::ARTIST;
-    return this;
-}
+    switch( type ) {
+    case QueryMaker::Artist:
+    {
+        DEBUG_BLOCK
+        d->type = Private::ARTIST;
+        return this;
+    }
 
-QueryMaker * Mp3tunesServiceQueryMaker::startAlbumQuery()
-{
-    DEBUG_BLOCK
-    d->type = Private::ALBUM;
-    return this;
-}
+    case QueryMaker::Album:
+    {
+        DEBUG_BLOCK
+        d->type = Private::ALBUM;
+        return this;
+    }
 
-QueryMaker * Mp3tunesServiceQueryMaker::startTrackQuery()
-{
-    DEBUG_BLOCK
-    d->type = Private::TRACK;
-    return this;
+    case QueryMaker::Track:
+    {
+        DEBUG_BLOCK
+        d->type = Private::TRACK;
+        return this;
+    }
+
+    case QueryMaker::Genre:
+    case QueryMaker::Composer:
+    case QueryMaker::Year:
+    case QueryMaker::Custom:
+    case QueryMaker::None:
+        //TODO: Implement.
+        return this;
+    }
 }
 
 
