@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright (c) 2007  Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>    *
+ *   Copyright (c) 2008  Casey Link <unnamedrambler@gmail.com>             *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -16,7 +17,7 @@
  *   Free Software Foundation, Inc.,                                       *
  *   51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.         *
  ***************************************************************************/
- 
+
 #include "Mp3tunesSettingsModule.h"
 
 #include "ui_Mp3tunesConfigWidget.h"
@@ -38,7 +39,7 @@ Mp3tunesSettingsModule::Mp3tunesSettingsModule( QWidget *parent, const QVariantL
     QWidget *w = new QWidget;
     m_configDialog = new Ui::Mp3tunesConfigWidget;
     m_configDialog->setupUi( w );
-    m_configDialog->identifier->setReadOnly( true );
+    m_configDialog->pinEdit->setReadOnly( true );
     l->addWidget( w );
 
     connect ( m_configDialog->emailEdit, SIGNAL( textChanged ( const QString & ) ), this, SLOT( settingsChanged() ) );
@@ -59,7 +60,7 @@ void Mp3tunesSettingsModule::save()
 {
     m_config.setEmail( m_configDialog->emailEdit->text() );
     m_config.setPassword( m_configDialog->passwordEdit->text() );
-    m_config.setIdentifier( m_configDialog->identifier->text() );
+    m_config.setPin( m_configDialog->pinEdit->text() );
     m_config.setHarmonyEnabled( m_configDialog->enableHarmony->isChecked() );
 
     m_config.save();
@@ -71,8 +72,8 @@ void Mp3tunesSettingsModule::load()
     m_configDialog->emailEdit->setText( m_config.email() );
     m_configDialog->passwordEdit->setText( m_config.password() );
     m_configDialog->enableHarmony->setChecked( m_config.harmonyEnabled() );
-    m_configDialog->identifier->setText( m_config.identifier() );
-    
+    m_configDialog->pinEdit->setText( m_config.pin() );
+
     KCModule::load();
 }
 
