@@ -28,10 +28,12 @@
 #include <QDragEnterEvent>
 #include <QDropEvent>
 #include <QMimeData>
-#include <QtGui>
+
 
 FilenameLayoutWidget::FilenameLayoutWidget( QWidget *parent )
     : QFrame( parent )
+    , m_tokenCount( 0 )   //how many tokens have I built, need this to assign unique IDs
+    , m_parsableScheme( "" )
 {
     setAcceptDrops( true );
     layout = new QHBoxLayout;
@@ -40,27 +42,32 @@ FilenameLayoutWidget::FilenameLayoutWidget( QWidget *parent )
     backText = new QLabel;
     backText->setText( i18n( "<div align=center><i>Drag tokens here to define a filename scheme.</i></div>" ) );
     layout->addWidget( backText );
-    tokenCount = 0;     //how many tokens have I built, need this to assign unique IDs
+    tokenList = new QList< Token * >();
 }
 
 void
 FilenameLayoutWidget::addToken( QString text, int index )
 {
-    if( !tokenCount )
+    if( !m_tokenCount )
     {
         backText->hide();
     }
 
-    tokenCount++;
+    m_tokenCount++;
     Token *token = new Token( text, this );
 
-    if( index == 999)
+    debug()<< "I am adding a token, the index I got is " << index << ".";
+    if( index == 0)
     {
         layout->addWidget( token );
+        tokenList->append( token );
+        debug() << "\t\ttokenList action: append";
     }
     else
     {
         layout->insertWidget( index, token );
+        tokenList->insert( index - 1, token );
+        debug()<< "\t\ttokenList action: inserted at " << index - 1 << ".";
     }
     
     token->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Fixed);
@@ -69,12 +76,18 @@ FilenameLayoutWidget::addToken( QString text, int index )
 
     if( token->text() == "<space>" )
     {
-        token->setText( "   " );
+        token->setText( " " );
     }
 
     //testing, remove when done
-   // token->setText( token->text() + " " + QString::number( layout->indexOf( token ) ) );
+    //token->setText( token->text() + " " + QString::number( layout->indexOf( token ) ) );
     //end testing block
+
+    //debug stuff follows
+    foreach(Token *temp, *tokenList)
+    {
+        debug() << tokenList->indexOf( temp ) << " .......... " << layout->indexOf( temp ) << " .......... " << temp->text();
+    }
 }
 
 
@@ -124,8 +137,6 @@ FilenameLayoutWidget::insertOverChild( Token *childUnder, QString &textFromMimeD
     }
 }
 
-
-
 void
 FilenameLayoutWidget::dropEvent( QDropEvent *event )
 {
@@ -136,19 +147,19 @@ FilenameLayoutWidget::dropEvent( QDropEvent *event )
     dataStream >> textFromMimeData;
     if ( source && source != this )
     {
-        debug() << "I'm dragging from the token pool";
+        debug() << "I am dragging from the token pool";
         event->setDropAction( Qt::CopyAction );
     }
     else if ( source && source == this )
     {
-        debug() << "I'm dragging from the layout widget";
+        debug() << "I am dragging from the layout widget";
         event->setDropAction( Qt::MoveAction );
     }
 
     Token *childUnder = qobject_cast< Token * >( childAt( event->pos() ) );
     if( childUnder == 0 )   //if I'm not dropping on an existing token
     {
-        if( !tokenCount )   //if the bar is empty
+        if( !m_tokenCount )   //if the bar is empty
         {
             addToken( textFromMimeData );
         }
@@ -180,12 +191,13 @@ FilenameLayoutWidget::dropEvent( QDropEvent *event )
         insertOverChild( childUnder, textFromMimeData, event );
     }
     event->accept();
+    generateParsableScheme();
 }
 
 unsigned int
 FilenameLayoutWidget::getTokenCount()
 {
-    return tokenCount;
+    return m_tokenCount;
 }
 
 
@@ -195,7 +207,7 @@ FilenameLayoutWidget::mouseMoveEvent( QMouseEvent *event )
 {
     if ( event->buttons() & Qt::LeftButton )
     {
-        int distance = ( event->pos() - startPos ).manhattanLength();
+        int distance = ( event->pos() - m_startPos ).manhattanLength();
         if ( distance >= KApplication::startDragDistance() )
         {
             performDrag( event );
@@ -207,7 +219,7 @@ void
 FilenameLayoutWidget::mousePressEvent( QMouseEvent *event )
 {
     if ( event->button() == Qt::LeftButton )
-        startPos = event->pos();
+        m_startPos = event->pos();
 }
 
 void
@@ -229,52 +241,73 @@ FilenameLayoutWidget::performDrag( QMouseEvent *event )
     drag->setPixmap( QPixmap::grabWidget( child ) );       //need to get pixmap from widget
 
     //child->close();
+    tokenList->removeAt( layout->indexOf( child ) - 1 );
+    debug() << "Deleting at " << layout->indexOf( child ) - 1;
     delete child;
-    tokenCount--;
+    m_tokenCount--;
 
-    if( !tokenCount )
+    if( !m_tokenCount )
     {
         backText->show();
     }
     
     drag->exec(Qt::MoveAction | Qt::CopyAction, Qt:: CopyAction);
-}
-
-//starts implementation of Token : QLabel
-
-Token::Token( const QString &string, QWidget *parent )
-    : QLabel( parent )
-{
-    myCount = qobject_cast<FilenameLayoutWidget *>( parent )->getTokenCount();
-    //TODO: resize the labels according to the text size, smth like this:
-
-    setText( string );
-    setTokenString( string );
-    setAlignment( Qt::AlignHCenter | Qt::AlignVCenter );
-    setStyleSheet( "Token {\
-        color: palette( Base );\
-        background-color: qlineargradient( x1: 0,\
-                                           y1: 0,\
-                                           x2: 1,\
-                                           y2: 1,\
-                                           stop: 0 white,\
-                                           stop: 0.4 gray,\
-                                           stop: 1 blue );\
-    }" );
-
-    QFontMetrics metric( font() );
-    QSize size = metric.size( Qt::TextSingleLine, text() );
-    setMinimumSize( size + QSize( 4, 0 ) );
+    generateParsableScheme();
 }
 
 void
-Token::setTokenString( const QString &string )
+FilenameLayoutWidget::generateParsableScheme()      //invoked on every change of the layout
 {
-    tokenString = string;
+    //with m_parsableScheme
+    m_parsableScheme = "";
+    foreach( Token *token, *tokenList)
+    {
+        QString current = token->text();
+        if( current == "Track" )
+        {
+            m_parsableScheme += "%track";
+        }
+        else if( current == "Title" )
+        {
+            m_parsableScheme += "%title";
+        }
+        else if( current == "Artist" )
+        {
+            m_parsableScheme += "%artist";
+        }
+        else if( current == "Composer" )
+        {
+            m_parsableScheme += "%composer";
+        }
+        else if( current == "Year" )
+        {
+            m_parsableScheme += "%year";
+        }
+        else if( current == "Album" )
+        {
+            m_parsableScheme += "%album";
+        }
+        else if( current == "Comment" )
+        {
+            m_parsableScheme += "%comment";
+        }
+        else if( current == "Genre" )
+        {
+            m_parsableScheme += "%genre";
+        }
+        else
+        {
+            m_parsableScheme += current;
+        }
+    }
+    debug() << "||| PARSABLE SCHEME ||| >>  " << m_parsableScheme;
 }
 
 QString
-Token::getTokenString()
+FilenameLayoutWidget::getParsableScheme()
 {
-    return tokenString;
-}
\ No newline at end of file
+    return m_parsableScheme;
+}
+
+
+
