@@ -20,28 +20,51 @@
 #ifndef MAINTOOLBAR_H
 #define MAINTOOLBAR_H
 
+#include "EngineObserver.h" //baseclass
+
 #include <KHBox>
 
-#include <QSvgRenderer>
+class PopupDropperAction;
+class KToolBar;
+class VolumeWidget;
 
 /**
-A KHBox based toolbar with a nice svg background
+A KHBox based toolbar with a nice svg background and takes care of adding any additional controls needed by individual tracks
 
-	@author Nikolaj Hald Nielsen <nhnFreespirit@gmail.com> 
+	@author Nikolaj Hald Nielsen <nhnFreespirit@gmail.com>
 */
-class MainToolbar : public KHBox
+class MainToolbar : public KHBox, public EngineObserver
 {
 public:
     MainToolbar( QWidget * parent );
 
     ~MainToolbar();
 
+    virtual void engineStateChanged( Phonon::State state, Phonon::State oldState = Phonon::StoppedState );
+    virtual void engineNewMetaData( const QHash<qint64, QString> &newMetaData, bool trackChanged );
+
+    void reRender();
+
 protected:
-      virtual void paintEvent(QPaintEvent *);
+      virtual void paintEvent( QPaintEvent * );
+      virtual void resizeEvent( QResizeEvent * event );
+      virtual bool eventFilter( QObject*, QEvent* );
+      virtual void paletteChange( const QPalette & oldPalette );
+      void handleAddActions();
+      //void centerAddActions();
 
 private:
+    QWidget      *m_insideBox;
+    KToolBar     *m_playerControlsToolbar;
+    KToolBar     *m_addControlsToolbar;
+    VolumeWidget *m_volumeWidget;
 
-    QSvgRenderer * m_svgRenderer;
+    bool m_renderAddControls;
+    int m_addActionsOffsetX;
+
+    bool m_ignoreCache;
+
+    QList<PopupDropperAction *> m_additionalActions;
 };
 
 #endif
