@@ -1,6 +1,6 @@
 /*
   Copyright (c) 2006 Gábor Lehel <illissius@gmail.com>
-  Copyright (c) 2007 Mark Kretschmann <markey@web.de> 
+  Copyright (c) 2007-2008 Mark Kretschmann <kretschmann@kde.org>
 
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Library General Public
@@ -18,18 +18,19 @@
   Boston, MA 02110-1301, USA.
 */
 
-#include "debug.h"
 #include "SidebarWidget.h"
 
-#include <KStandardDirs>
+#include "Debug.h"
+
+#include "SvgTinter.h"
+
+#include <KIconEffect>
 
 #include <QAbstractItemDelegate>
 #include <QAction>
 #include <QApplication>
-#include <QFile>
 #include <QList>
 #include <QPainter>
-#include <QSvgRenderer>
 #include <QTimer>
 #include <QWheelEvent>
 
@@ -188,7 +189,7 @@ void SideBarWidget::updateShortcuts()
 //////////////////////////////////////////////////////////////////////
 
 SideBarButton::SideBarButton( const QIcon &icon, const QString &text, QWidget *parent )
-    : super( parent )
+    : QAbstractButton( parent )
     , m_animCount( 0 )
     , m_animTimer( new QTimer( this ) )
 {
@@ -197,6 +198,8 @@ SideBarButton::SideBarButton( const QIcon &icon, const QString &text, QWidget *p
     setIcon( icon );
     setText( text );
 
+    setForegroundRole( QPalette::HighlightedText );
+
     connect( m_animTimer, SIGNAL( timeout() ), this, SLOT( slotAnimTimer() ) );
 }
 
@@ -264,37 +267,36 @@ void SideBarButton::slotAnimTimer()
 
 void SideBarButton::paintEvent( QPaintEvent* )
 {
-    QFile file( KStandardDirs::locate( "data","amarok/images/sidebar_button.svg" ) );
-    file.open( QIODevice::ReadOnly );
-    QString svg_source( file.readAll() );
-
     QPainter p( this );
-    p.initFrom( this );
+
+    const QColor baseColor = palette().text().color();
+    const int blendPercent = static_cast<int>( m_animCount * 3.5 );
 
     QColor c;
     if( isDown() )
-        c = blendColors( palette().highlight().color().darker( 150 ), palette().window().color(), static_cast<int>( m_animCount * 3.5 ) );
+        c = blendColors( palette().highlight().color().darker( 150 ), baseColor, blendPercent );
     else if( isChecked() && underMouse() )
-        c = blendColors( palette().highlight().color().lighter( 110 ), palette().window().color(), static_cast<int>( m_animCount * 3.5 ) );
+        c = blendColors( palette().highlight().color().lighter( 110 ), baseColor, blendPercent );
     else if( isChecked() )
-        c = blendColors( palette().highlight().color(), palette().highlight().color().lighter(), static_cast<int>( m_animCount * 3.5 ) );
+        c = blendColors( palette().highlight().color(), palette().highlight().color().lighter(), blendPercent );
     else if( underMouse() )
-        c = blendColors( palette().highlight().color().lighter(), palette().highlight().color(), static_cast<int>( m_animCount * 3.5 ) );
+        c = blendColors( baseColor, palette().highlight().color().lighter(), blendPercent );
     else
-        c = blendColors( palette().window().color(), palette().highlight().color().darker( 150 ), static_cast<int>( m_animCount * 3.5 ) );
+        c = blendColors( baseColor, palette().highlight().color().darker( 150 ), blendPercent );
 
-    svg_source.replace( "stop-color:#6193cf", "stop-color:" + c.name() );
-    QSvgRenderer svg( svg_source.toAscii() );
-    svg.render( &p );
-
-    const QString txt = text().replace( "&", "" );
+    QImage background = The::svgHandler()->renderSvg( "sidebar_button", contentsRect().width(), contentsRect().height(), "sidebar_button" ).toImage();
+    KIconEffect::colorize( background, c, 0.7 );
+    p.drawImage( 0, 0, background );
 
     const int pos = qMin( height(), height() / 2 + heightHint() / 2 ) - iconSize().height();
+    const QString txt = text().remove( '&' );
 
     p.translate( 0, pos );
     p.drawPixmap( width() / 2 - iconSize().width() / 2, 0, icon().pixmap( iconSize() ) );
     p.translate( fontMetrics().size( Qt::TextShowMnemonic, txt ).height() - 2, 0 );
     p.rotate( -90 );
+
+    p.setPen( QPen( c ) );
     p.drawText( 10, 0, QAbstractItemDelegate::elidedText( fontMetrics(), pos - 10, Qt::ElideRight, txt ) );
 }
 
@@ -313,5 +315,11 @@ QColor SideBarButton::blendColors( const QColor& color1, const QColor& color2, i
     return result;
 }
 
+void SideBarButton::paletteChange(const QPalette & /*oldPalette*/)
+{
+    The::svgHandler()->reTint();
+    repaint( 0, 0, -1,-1 );
+}
+
 
 #include "SidebarWidget.moc"
